/* A Bison parser, made by GNU Bison 3.8.2.  */

/* Bison implementation for Yacc-like parsers in C

   Copyright (C) 1984, 1989-1990, 2000-2015, 2018-2021 Free Software Foundation,
   Inc.

   This program is free software: you can redistribute it and/or modify
   it under the terms of the GNU General Public License as published by
   the Free Software Foundation, either version 3 of the License, or
   (at your option) any later version.

   This program is distributed in the hope that it will be useful,
   but WITHOUT ANY WARRANTY; without even the implied warranty of
   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
   GNU General Public License for more details.

   You should have received a copy of the GNU General Public License
   along with this program.  If not, see <https://www.gnu.org/licenses/>.  */

/* As a special exception, you may create a larger work that contains
   part or all of the Bison parser skeleton and distribute that work
   under terms of your choice, so long as that work isn't itself a
   parser generator using the skeleton or a modified version thereof
   as a parser skeleton.  Alternatively, if you modify or redistribute
   the parser skeleton itself, you may (at your option) remove this
   special exception, which will cause the skeleton and the resulting
   Bison output files to be licensed under the GNU General Public
   License without this special exception.

   This special exception was added by the Free Software Foundation in
   version 2.2 of Bison.  */

/* C LALR(1) parser skeleton written by Richard Stallman, by
   simplifying the original so-called "semantic" parser.  */

/* DO NOT RELY ON FEATURES THAT ARE NOT DOCUMENTED in the manual,
   especially those whose name start with YY_ or yy_.  They are
   private implementation details that can be changed or removed.  */

/* All symbols defined below should begin with yy or YY, to avoid
   infringing on user name space.  This should be done even for local
   variables, as they might otherwise be expanded by user macros.
   There are some unavoidable exceptions within include files to
   define necessary library symbols; they are noted "INFRINGES ON
   USER NAME SPACE" below.  */

/* Identify Bison output, and Bison version.  */
#define YYBISON 30802

/* Bison version string.  */
#define YYBISON_VERSION "3.8.2"

/* Skeleton name.  */
#define YYSKELETON_NAME "yacc.c"

/* Pure parsers.  */
#define YYPURE 1

/* Push parsers.  */
#define YYPUSH 0

/* Pull parsers.  */
#define YYPULL 1

/* "%code top" blocks.  */
#line 24 "modules/grpc/loki/loki-grammar.y"

#include "loki-parser.h"


#line 73 "modules/grpc/loki/loki-grammar.c"
/* Substitute the type names.  */
#define YYSTYPE         LOKI_STYPE
#define YYLTYPE         LOKI_LTYPE
/* Substitute the variable and function names.  */
#define yyparse         loki_parse
#define yylex           loki_lex
#define yyerror         loki_error
#define yydebug         loki_debug
#define yynerrs         loki_nerrs


# ifndef YY_CAST
#  ifdef __cplusplus
#   define YY_CAST(Type, Val) static_cast<Type> (Val)
#   define YY_REINTERPRET_CAST(Type, Val) reinterpret_cast<Type> (Val)
#  else
#   define YY_CAST(Type, Val) ((Type) (Val))
#   define YY_REINTERPRET_CAST(Type, Val) ((Type) (Val))
#  endif
# endif
# ifndef YY_NULLPTR
#  if defined __cplusplus
#   if 201103L <= __cplusplus
#    define YY_NULLPTR nullptr
#   else
#    define YY_NULLPTR 0
#   endif
#  else
#   define YY_NULLPTR ((void*)0)
#  endif
# endif

/* Use api.header.include to #include this header
   instead of duplicating it here.  */
#ifndef YY_LOKI_MODULES_GRPC_LOKI_LOKI_GRAMMAR_H_INCLUDED
# define YY_LOKI_MODULES_GRPC_LOKI_LOKI_GRAMMAR_H_INCLUDED
/* Debug traces.  */
#ifndef LOKI_DEBUG
# if defined YYDEBUG
#if YYDEBUG
#   define LOKI_DEBUG 1
#  else
#   define LOKI_DEBUG 0
#  endif
# else /* ! defined YYDEBUG */
#  define LOKI_DEBUG 0
# endif /* ! defined YYDEBUG */
#endif  /* ! defined LOKI_DEBUG */
#if LOKI_DEBUG
extern int loki_debug;
#endif

/* Token kinds.  */
#ifndef LOKI_TOKENTYPE
# define LOKI_TOKENTYPE
  enum loki_tokentype
  {
    LOKI_EMPTY = -2,
    LOKI_EOF = 0,                  /* "end of file"  */
    LOKI_error = 256,              /* error  */
    LOKI_UNDEF = 10531,            /* "invalid token"  */
    LL_CONTEXT_ROOT = 1,           /* LL_CONTEXT_ROOT  */
    LL_CONTEXT_DESTINATION = 2,    /* LL_CONTEXT_DESTINATION  */
    LL_CONTEXT_SOURCE = 3,         /* LL_CONTEXT_SOURCE  */
    LL_CONTEXT_PARSER = 4,         /* LL_CONTEXT_PARSER  */
    LL_CONTEXT_REWRITE = 5,        /* LL_CONTEXT_REWRITE  */
    LL_CONTEXT_FILTER = 6,         /* LL_CONTEXT_FILTER  */
    LL_CONTEXT_LOG = 7,            /* LL_CONTEXT_LOG  */
    LL_CONTEXT_BLOCK_DEF = 8,      /* LL_CONTEXT_BLOCK_DEF  */
    LL_CONTEXT_BLOCK_REF = 9,      /* LL_CONTEXT_BLOCK_REF  */
    LL_CONTEXT_BLOCK_CONTENT = 10, /* LL_CONTEXT_BLOCK_CONTENT  */
    LL_CONTEXT_BLOCK_ARG = 11,     /* LL_CONTEXT_BLOCK_ARG  */
    LL_CONTEXT_BLOCK_FUNCARG = 12, /* LL_CONTEXT_BLOCK_FUNCARG  */
    LL_CONTEXT_PRAGMA = 13,        /* LL_CONTEXT_PRAGMA  */
    LL_CONTEXT_FORMAT = 14,        /* LL_CONTEXT_FORMAT  */
    LL_CONTEXT_TEMPLATE_FUNC = 15, /* LL_CONTEXT_TEMPLATE_FUNC  */
    LL_CONTEXT_INNER_DEST = 16,    /* LL_CONTEXT_INNER_DEST  */
    LL_CONTEXT_INNER_SRC = 17,     /* LL_CONTEXT_INNER_SRC  */
    LL_CONTEXT_CLIENT_PROTO = 18,  /* LL_CONTEXT_CLIENT_PROTO  */
    LL_CONTEXT_SERVER_PROTO = 19,  /* LL_CONTEXT_SERVER_PROTO  */
    LL_CONTEXT_OPTIONS = 20,       /* LL_CONTEXT_OPTIONS  */
    LL_CONTEXT_CONFIG = 21,        /* LL_CONTEXT_CONFIG  */
    LL_CONTEXT_TEMPLATE_REF = 22,  /* LL_CONTEXT_TEMPLATE_REF  */
    LL_CONTEXT_MAX = 23,           /* LL_CONTEXT_MAX  */
    KW_ASSIGN = 9000,              /* KW_ASSIGN  */
    KW_OR = 9010,                  /* KW_OR  */
    KW_AND = 9020,                 /* KW_AND  */
    KW_STR_EQ = 9030,              /* KW_STR_EQ  */
    KW_STR_NE = 9031,              /* KW_STR_NE  */
    KW_TA_EQ = 9032,               /* KW_TA_EQ  */
    KW_TA_NE = 9033,               /* KW_TA_NE  */
    KW_TAV_EQ = 9034,              /* KW_TAV_EQ  */
    KW_TAV_NE = 9035,              /* KW_TAV_NE  */
    KW_STR_LT = 9040,              /* KW_STR_LT  */
    KW_STR_LE = 9041,              /* KW_STR_LE  */
    KW_STR_GE = 9042,              /* KW_STR_GE  */
    KW_STR_GT = 9043,              /* KW_STR_GT  */
    KW_TA_LT = 9044,               /* KW_TA_LT  */
    KW_TA_LE = 9045,               /* KW_TA_LE  */
    KW_TA_GE = 9046,               /* KW_TA_GE  */
    KW_TA_GT = 9047,               /* KW_TA_GT  */
    KW_PLUS_ASSIGN = 9050,         /* KW_PLUS_ASSIGN  */
    KW_REGEXP_MATCH = 9060,        /* KW_REGEXP_MATCH  */
    KW_NOT = 9049,                 /* KW_NOT  */
    KW_SOURCE = 10000,             /* KW_SOURCE  */
    KW_FILTER = 10001,             /* KW_FILTER  */
    KW_PARSER = 10002,             /* KW_PARSER  */
    KW_DESTINATION = 10003,        /* KW_DESTINATION  */
    KW_LOG = 10004,                /* KW_LOG  */
    KW_OPTIONS = 10005,            /* KW_OPTIONS  */
    KW_INCLUDE = 10006,            /* KW_INCLUDE  */
    KW_BLOCK = 10007,              /* KW_BLOCK  */
    KW_JUNCTION = 10008,           /* KW_JUNCTION  */
    KW_CHANNEL = 10009,            /* KW_CHANNEL  */
    KW_IF = 10010,                 /* KW_IF  */
    KW_ELSE = 10011,               /* KW_ELSE  */
    KW_ELIF = 10012,               /* KW_ELIF  */
    KW_INTERNAL = 10020,           /* KW_INTERNAL  */
    KW_SYSLOG = 10060,             /* KW_SYSLOG  */
    KW_MARK_FREQ = 10071,          /* KW_MARK_FREQ  */
    KW_STATS_FREQ = 10072,         /* KW_STATS_FREQ  */
    KW_STATS_LEVEL = 10073,        /* KW_STATS_LEVEL  */
    KW_STATS_LIFETIME = 10074,     /* KW_STATS_LIFETIME  */
    KW_FLUSH_LINES = 10075,        /* KW_FLUSH_LINES  */
    KW_SUPPRESS = 10076,           /* KW_SUPPRESS  */
    KW_FLUSH_TIMEOUT = 10077,      /* KW_FLUSH_TIMEOUT  */
    KW_LOG_MSG_SIZE = 10078,       /* KW_LOG_MSG_SIZE  */
    KW_FILE_TEMPLATE = 10079,      /* KW_FILE_TEMPLATE  */
    KW_PROTO_TEMPLATE = 10080,     /* KW_PROTO_TEMPLATE  */
    KW_MARK_MODE = 10081,          /* KW_MARK_MODE  */
    KW_ENCODING = 10082,           /* KW_ENCODING  */
    KW_TYPE = 10083,               /* KW_TYPE  */
    KW_STATS_MAX_DYNAMIC = 10084,  /* KW_STATS_MAX_DYNAMIC  */
    KW_MIN_IW_SIZE_PER_READER = 10085, /* KW_MIN_IW_SIZE_PER_READER  */
    KW_WORKERS = 10086,            /* KW_WORKERS  */
    KW_BATCH_LINES = 10087,        /* KW_BATCH_LINES  */
    KW_BATCH_TIMEOUT = 10088,      /* KW_BATCH_TIMEOUT  */
    KW_TRIM_LARGE_MESSAGES = 10089, /* KW_TRIM_LARGE_MESSAGES  */
    KW_STATS = 10400,              /* KW_STATS  */
    KW_FREQ = 10401,               /* KW_FREQ  */
    KW_LEVEL = 10402,              /* KW_LEVEL  */
    KW_LIFETIME = 10403,           /* KW_LIFETIME  */
    KW_MAX_DYNAMIC = 10404,        /* KW_MAX_DYNAMIC  */
    KW_SYSLOG_STATS = 10405,       /* KW_SYSLOG_STATS  */
    KW_HEALTHCHECK_FREQ = 10406,   /* KW_HEALTHCHECK_FREQ  */
    KW_WORKER_PARTITION_KEY = 10407, /* KW_WORKER_PARTITION_KEY  */
    KW_CHAIN_HOSTNAMES = 10090,    /* KW_CHAIN_HOSTNAMES  */
    KW_NORMALIZE_HOSTNAMES = 10091, /* KW_NORMALIZE_HOSTNAMES  */
    KW_KEEP_HOSTNAME = 10092,      /* KW_KEEP_HOSTNAME  */
    KW_CHECK_HOSTNAME = 10093,     /* KW_CHECK_HOSTNAME  */
    KW_BAD_HOSTNAME = 10094,       /* KW_BAD_HOSTNAME  */
    KW_LOG_LEVEL = 10095,          /* KW_LOG_LEVEL  */
    KW_IDLE_TIMEOUT = 10096,       /* KW_IDLE_TIMEOUT  */
    KW_CHECK_PROGRAM = 10097,      /* KW_CHECK_PROGRAM  */
    KW_KEEP_TIMESTAMP = 10100,     /* KW_KEEP_TIMESTAMP  */
    KW_USE_DNS = 10110,            /* KW_USE_DNS  */
    KW_USE_FQDN = 10111,           /* KW_USE_FQDN  */
    KW_CUSTOM_DOMAIN = 10112,      /* KW_CUSTOM_DOMAIN  */
    KW_DNS_CACHE = 10120,          /* KW_DNS_CACHE  */
    KW_DNS_CACHE_SIZE = 10121,     /* KW_DNS_CACHE_SIZE  */
    KW_DNS_CACHE_EXPIRE = 10130,   /* KW_DNS_CACHE_EXPIRE  */
    KW_DNS_CACHE_EXPIRE_FAILED = 10131, /* KW_DNS_CACHE_EXPIRE_FAILED  */
    KW_DNS_CACHE_HOSTS = 10132,    /* KW_DNS_CACHE_HOSTS  */
    KW_PERSIST_ONLY = 10140,       /* KW_PERSIST_ONLY  */
    KW_USE_RCPTID = 10141,         /* KW_USE_RCPTID  */
    KW_USE_UNIQID = 10142,         /* KW_USE_UNIQID  */
    KW_TZ_CONVERT = 10150,         /* KW_TZ_CONVERT  */
    KW_TS_FORMAT = 10151,          /* KW_TS_FORMAT  */
    KW_FRAC_DIGITS = 10152,        /* KW_FRAC_DIGITS  */
    KW_LOG_FIFO_SIZE = 10160,      /* KW_LOG_FIFO_SIZE  */
    KW_LOG_FETCH_LIMIT = 10162,    /* KW_LOG_FETCH_LIMIT  */
    KW_LOG_IW_SIZE = 10163,        /* KW_LOG_IW_SIZE  */
    KW_LOG_PREFIX = 10164,         /* KW_LOG_PREFIX  */
    KW_PROGRAM_OVERRIDE = 10165,   /* KW_PROGRAM_OVERRIDE  */
    KW_HOST_OVERRIDE = 10166,      /* KW_HOST_OVERRIDE  */
    KW_THROTTLE = 10170,           /* KW_THROTTLE  */
    KW_THREADED = 10171,           /* KW_THREADED  */
    KW_PASS_UNIX_CREDENTIALS = 10180, /* KW_PASS_UNIX_CREDENTIALS  */
    KW_PERSIST_NAME = 10181,       /* KW_PERSIST_NAME  */
    KW_USE_SYSLOGNG_PID = 10182,   /* KW_USE_SYSLOGNG_PID  */
    KW_READ_OLD_RECORDS = 10185,   /* KW_READ_OLD_RECORDS  */
    KW_IGNORE_SAVED_BOOKMARKS = 10186, /* KW_IGNORE_SAVED_BOOKMARKS  */
    KW_DISABLE_BOOKMARKS = 10187,  /* KW_DISABLE_BOOKMARKS  */
    KW_FLAGS = 10190,              /* KW_FLAGS  */
    KW_PAD_SIZE = 10200,           /* KW_PAD_SIZE  */
    KW_TIME_ZONE = 10201,          /* KW_TIME_ZONE  */
    KW_RECV_TIME_ZONE = 10202,     /* KW_RECV_TIME_ZONE  */
    KW_SEND_TIME_ZONE = 10203,     /* KW_SEND_TIME_ZONE  */
    KW_LOCAL_TIME_ZONE = 10204,    /* KW_LOCAL_TIME_ZONE  */
    KW_FORMAT = 10205,             /* KW_FORMAT  */
    KW_MULTI_LINE_MODE = 10206,    /* KW_MULTI_LINE_MODE  */
    KW_MULTI_LINE_PREFIX = 10207,  /* KW_MULTI_LINE_PREFIX  */
    KW_MULTI_LINE_GARBAGE = 10208, /* KW_MULTI_LINE_GARBAGE  */
    KW_TRUNCATE_SIZE = 10209,      /* KW_TRUNCATE_SIZE  */
    KW_TIME_REOPEN = 10210,        /* KW_TIME_REOPEN  */
    KW_TIME_REAP = 10211,          /* KW_TIME_REAP  */
    KW_TIME_SLEEP = 10212,         /* KW_TIME_SLEEP  */
    KW_PARALLELIZE = 10215,        /* KW_PARALLELIZE  */
    KW_PARTITIONS = 10216,         /* KW_PARTITIONS  */
    KW_PARTITION_KEY = 10217,      /* KW_PARTITION_KEY  */
    KW_TMPL_ESCAPE = 10220,        /* KW_TMPL_ESCAPE  */
    KW_LOG_FETCH_DELAY = 10230,    /* KW_LOG_FETCH_DELAY  */
    KW_LOG_FETCH_RETRY_DELAY = 10231, /* KW_LOG_FETCH_RETRY_DELAY  */
    KW_OPTIONAL = 10235,           /* KW_OPTIONAL  */
    KW_CREATE_DIRS = 10240,        /* KW_CREATE_DIRS  */
    KW_OWNER = 10250,              /* KW_OWNER  */
    KW_GROUP = 10251,              /* KW_GROUP  */
    KW_PERM = 10252,               /* KW_PERM  */
    KW_DIR_OWNER = 10260,          /* KW_DIR_OWNER  */
    KW_DIR_GROUP = 10261,          /* KW_DIR_GROUP  */
    KW_DIR_PERM = 10262,           /* KW_DIR_PERM  */
    KW_TEMPLATE = 10270,           /* KW_TEMPLATE  */
    KW_TEMPLATE_ESCAPE = 10271,    /* KW_TEMPLATE_ESCAPE  */
    KW_TEMPLATE_FUNCTION = 10272,  /* KW_TEMPLATE_FUNCTION  */
    KW_DEFAULT_FACILITY = 10300,   /* KW_DEFAULT_FACILITY  */
    KW_DEFAULT_SEVERITY = 10301,   /* KW_DEFAULT_SEVERITY  */
    KW_SDATA_PREFIX = 10302,       /* KW_SDATA_PREFIX  */
    KW_PORT = 10323,               /* KW_PORT  */
    KW_HTTP = 10324,               /* KW_HTTP  */
    KW_USE_TIME_RECVD = 10340,     /* KW_USE_TIME_RECVD  */
    KW_FACILITY = 10350,           /* KW_FACILITY  */
    KW_SEVERITY = 10351,           /* KW_SEVERITY  */
    KW_HOST = 10352,               /* KW_HOST  */
    KW_MATCH = 10353,              /* KW_MATCH  */
    KW_MESSAGE = 10354,            /* KW_MESSAGE  */
    KW_NETMASK = 10355,            /* KW_NETMASK  */
    KW_TAGS = 10356,               /* KW_TAGS  */
    KW_NETMASK6 = 10357,           /* KW_NETMASK6  */
    KW_REWRITE = 10370,            /* KW_REWRITE  */
    KW_CONDITION = 10371,          /* KW_CONDITION  */
    KW_VALUE = 10372,              /* KW_VALUE  */
    KW_YES = 10380,                /* KW_YES  */
    KW_NO = 10381,                 /* KW_NO  */
    KW_AUTO = 10382,               /* KW_AUTO  */
    KW_IFDEF = 10410,              /* KW_IFDEF  */
    KW_ENDIF = 10411,              /* KW_ENDIF  */
    LL_DOTDOT = 10420,             /* LL_DOTDOT  */
    LL_DOTDOTDOT = 10421,          /* LL_DOTDOTDOT  */
    LL_PRAGMA = 10422,             /* LL_PRAGMA  */
    LL_EOL = 10423,                /* LL_EOL  */
    LL_ERROR = 10424,              /* LL_ERROR  */
    LL_ARROW = 10425,              /* LL_ARROW  */
    LL_IDENTIFIER = 10430,         /* LL_IDENTIFIER  */
    LL_NUMBER = 10431,             /* LL_NUMBER  */
    LL_FLOAT = 10432,              /* LL_FLOAT  */
    LL_STRING = 10433,             /* LL_STRING  */
    LL_TOKEN = 10434,              /* LL_TOKEN  */
    LL_BLOCK = 10435,              /* LL_BLOCK  */
    LL_PLUGIN = 10436,             /* LL_PLUGIN  */
    LL_TEMPLATE_REF = 10437,       /* LL_TEMPLATE_REF  */
    LL_MESSAGE_REF = 10438,        /* LL_MESSAGE_REF  */
    KW_VALUE_PAIRS = 10500,        /* KW_VALUE_PAIRS  */
    KW_EXCLUDE = 10502,            /* KW_EXCLUDE  */
    KW_PAIR = 10503,               /* KW_PAIR  */
    KW_KEY = 10504,                /* KW_KEY  */
    KW_SCOPE = 10505,              /* KW_SCOPE  */
    KW_SHIFT = 10506,              /* KW_SHIFT  */
    KW_SHIFT_LEVELS = 10507,       /* KW_SHIFT_LEVELS  */
    KW_REKEY = 10508,              /* KW_REKEY  */
    KW_ADD_PREFIX = 10509,         /* KW_ADD_PREFIX  */
    KW_REPLACE_PREFIX = 10510,     /* KW_REPLACE_PREFIX  */
    KW_CAST = 10511,               /* KW_CAST  */
    KW_UPPER = 10512,              /* KW_UPPER  */
    KW_LOWER = 10513,              /* KW_LOWER  */
    KW_INCLUDE_BYTES = 10514,      /* KW_INCLUDE_BYTES  */
    KW_ON_ERROR = 10520,           /* KW_ON_ERROR  */
    KW_RETRIES = 10521,            /* KW_RETRIES  */
    KW_FETCH_NO_DATA_DELAY = 10522, /* KW_FETCH_NO_DATA_DELAY  */
    KW_LABELS = 10530,             /* KW_LABELS  */
    KW_AUTH = 10532,               /* KW_AUTH  */
    KW_INSECURE = 10533,           /* KW_INSECURE  */
    KW_TLS = 10534,                /* KW_TLS  */
    KW_KEY_FILE = 10535,           /* KW_KEY_FILE  */
    KW_CERT_FILE = 10536,          /* KW_CERT_FILE  */
    KW_CA_FILE = 10537,            /* KW_CA_FILE  */
    KW_PEER_VERIFY = 10538,        /* KW_PEER_VERIFY  */
    KW_OPTIONAL_UNTRUSTED = 10539, /* KW_OPTIONAL_UNTRUSTED  */
    KW_OPTIONAL_TRUSTED = 10540,   /* KW_OPTIONAL_TRUSTED  */
    KW_REQUIRED_UNTRUSTED = 10541, /* KW_REQUIRED_UNTRUSTED  */
    KW_REQUIRED_TRUSTED = 10542,   /* KW_REQUIRED_TRUSTED  */
    KW_ALTS = 10543,               /* KW_ALTS  */
    KW_TARGET_SERVICE_ACCOUNTS = 10544, /* KW_TARGET_SERVICE_ACCOUNTS  */
    KW_URL = 10545,                /* KW_URL  */
    KW_ADC = 10546,                /* KW_ADC  */
    KW_SERVICE_ACCOUNT = 10547,    /* KW_SERVICE_ACCOUNT  */
    KW_TOKEN_VALIDITY_DURATION = 10548, /* KW_TOKEN_VALIDITY_DURATION  */
    KW_COMPRESSION = 10549,        /* KW_COMPRESSION  */
    KW_BATCH_BYTES = 10550,        /* KW_BATCH_BYTES  */
    KW_CONCURRENT_REQUESTS = 10551, /* KW_CONCURRENT_REQUESTS  */
    KW_KEEP_ALIVE = 10552,         /* KW_KEEP_ALIVE  */
    KW_TIME = 10553,               /* KW_TIME  */
    KW_TIMEOUT = 10554,            /* KW_TIMEOUT  */
    KW_MAX_PINGS_WITHOUT_DATA = 10555, /* KW_MAX_PINGS_WITHOUT_DATA  */
    KW_CHANNEL_ARGS = 10556,       /* KW_CHANNEL_ARGS  */
    KW_HEADERS = 10557,            /* KW_HEADERS  */
    KW_SCHEMA = 10558,             /* KW_SCHEMA  */
    KW_PROTOBUF_SCHEMA = 10559,    /* KW_PROTOBUF_SCHEMA  */
    KW_RESPONSE_ACTION = 10560,    /* KW_RESPONSE_ACTION  */
    KW_DISCONNECT = 10561,         /* KW_DISCONNECT  */
    KW_DROP = 10562,               /* KW_DROP  */
    KW_RETRY = 10563,              /* KW_RETRY  */
    KW_SUCCESS = 10564,            /* KW_SUCCESS  */
    KW_OK = 10565,                 /* KW_OK  */
    KW_UNAVAILABLE = 10566,        /* KW_UNAVAILABLE  */
    KW_CANCELLED = 10567,          /* KW_CANCELLED  */
    KW_DEADLINE_EXCEEDED = 10568,  /* KW_DEADLINE_EXCEEDED  */
    KW_ABORTED = 10569,            /* KW_ABORTED  */
    KW_OUT_OF_RANGE = 10570,       /* KW_OUT_OF_RANGE  */
    KW_DATA_LOSS = 10571,          /* KW_DATA_LOSS  */
    KW_UNKNOWN = 10572,            /* KW_UNKNOWN  */
    KW_INVALID_ARGUMENT = 10573,   /* KW_INVALID_ARGUMENT  */
    KW_NOT_FOUND = 10574,          /* KW_NOT_FOUND  */
    KW_ALREADY_EXISTS = 10575,     /* KW_ALREADY_EXISTS  */
    KW_PERMISSION_DENIED = 10576,  /* KW_PERMISSION_DENIED  */
    KW_UNAUTHENTICATED = 10577,    /* KW_UNAUTHENTICATED  */
    KW_FAILED_PRECONDITION = 10578, /* KW_FAILED_PRECONDITION  */
    KW_UNIMPLEMENTED = 10579,      /* KW_UNIMPLEMENTED  */
    KW_RESOURCE_EXHAUSTED = 10580, /* KW_RESOURCE_EXHAUSTED  */
    KW_LOKI = 10581,               /* KW_LOKI  */
    KW_TIMESTAMP = 10582,          /* KW_TIMESTAMP  */
    KW_TENANT_ID = 10583           /* KW_TENANT_ID  */
  };
  typedef enum loki_tokentype loki_token_kind_t;
#endif
/* Token kinds.  */
#define LOKI_EMPTY -2
#define LOKI_EOF 0
#define LOKI_error 256
#define LOKI_UNDEF 10531
#define LL_CONTEXT_ROOT 1
#define LL_CONTEXT_DESTINATION 2
#define LL_CONTEXT_SOURCE 3
#define LL_CONTEXT_PARSER 4
#define LL_CONTEXT_REWRITE 5
#define LL_CONTEXT_FILTER 6
#define LL_CONTEXT_LOG 7
#define LL_CONTEXT_BLOCK_DEF 8
#define LL_CONTEXT_BLOCK_REF 9
#define LL_CONTEXT_BLOCK_CONTENT 10
#define LL_CONTEXT_BLOCK_ARG 11
#define LL_CONTEXT_BLOCK_FUNCARG 12
#define LL_CONTEXT_PRAGMA 13
#define LL_CONTEXT_FORMAT 14
#define LL_CONTEXT_TEMPLATE_FUNC 15
#define LL_CONTEXT_INNER_DEST 16
#define LL_CONTEXT_INNER_SRC 17
#define LL_CONTEXT_CLIENT_PROTO 18
#define LL_CONTEXT_SERVER_PROTO 19
#define LL_CONTEXT_OPTIONS 20
#define LL_CONTEXT_CONFIG 21
#define LL_CONTEXT_TEMPLATE_REF 22
#define LL_CONTEXT_MAX 23
#define KW_ASSIGN 9000
#define KW_OR 9010
#define KW_AND 9020
#define KW_STR_EQ 9030
#define KW_STR_NE 9031
#define KW_TA_EQ 9032
#define KW_TA_NE 9033
#define KW_TAV_EQ 9034
#define KW_TAV_NE 9035
#define KW_STR_LT 9040
#define KW_STR_LE 9041
#define KW_STR_GE 9042
#define KW_STR_GT 9043
#define KW_TA_LT 9044
#define KW_TA_LE 9045
#define KW_TA_GE 9046
#define KW_TA_GT 9047
#define KW_PLUS_ASSIGN 9050
#define KW_REGEXP_MATCH 9060
#define KW_NOT 9049
#define KW_SOURCE 10000
#define KW_FILTER 10001
#define KW_PARSER 10002
#define KW_DESTINATION 10003
#define KW_LOG 10004
#define KW_OPTIONS 10005
#define KW_INCLUDE 10006
#define KW_BLOCK 10007
#define KW_JUNCTION 10008
#define KW_CHANNEL 10009
#define KW_IF 10010
#define KW_ELSE 10011
#define KW_ELIF 10012
#define KW_INTERNAL 10020
#define KW_SYSLOG 10060
#define KW_MARK_FREQ 10071
#define KW_STATS_FREQ 10072
#define KW_STATS_LEVEL 10073
#define KW_STATS_LIFETIME 10074
#define KW_FLUSH_LINES 10075
#define KW_SUPPRESS 10076
#define KW_FLUSH_TIMEOUT 10077
#define KW_LOG_MSG_SIZE 10078
#define KW_FILE_TEMPLATE 10079
#define KW_PROTO_TEMPLATE 10080
#define KW_MARK_MODE 10081
#define KW_ENCODING 10082
#define KW_TYPE 10083
#define KW_STATS_MAX_DYNAMIC 10084
#define KW_MIN_IW_SIZE_PER_READER 10085
#define KW_WORKERS 10086
#define KW_BATCH_LINES 10087
#define KW_BATCH_TIMEOUT 10088
#define KW_TRIM_LARGE_MESSAGES 10089
#define KW_STATS 10400
#define KW_FREQ 10401
#define KW_LEVEL 10402
#define KW_LIFETIME 10403
#define KW_MAX_DYNAMIC 10404
#define KW_SYSLOG_STATS 10405
#define KW_HEALTHCHECK_FREQ 10406
#define KW_WORKER_PARTITION_KEY 10407
#define KW_CHAIN_HOSTNAMES 10090
#define KW_NORMALIZE_HOSTNAMES 10091
#define KW_KEEP_HOSTNAME 10092
#define KW_CHECK_HOSTNAME 10093
#define KW_BAD_HOSTNAME 10094
#define KW_LOG_LEVEL 10095
#define KW_IDLE_TIMEOUT 10096
#define KW_CHECK_PROGRAM 10097
#define KW_KEEP_TIMESTAMP 10100
#define KW_USE_DNS 10110
#define KW_USE_FQDN 10111
#define KW_CUSTOM_DOMAIN 10112
#define KW_DNS_CACHE 10120
#define KW_DNS_CACHE_SIZE 10121
#define KW_DNS_CACHE_EXPIRE 10130
#define KW_DNS_CACHE_EXPIRE_FAILED 10131
#define KW_DNS_CACHE_HOSTS 10132
#define KW_PERSIST_ONLY 10140
#define KW_USE_RCPTID 10141
#define KW_USE_UNIQID 10142
#define KW_TZ_CONVERT 10150
#define KW_TS_FORMAT 10151
#define KW_FRAC_DIGITS 10152
#define KW_LOG_FIFO_SIZE 10160
#define KW_LOG_FETCH_LIMIT 10162
#define KW_LOG_IW_SIZE 10163
#define KW_LOG_PREFIX 10164
#define KW_PROGRAM_OVERRIDE 10165
#define KW_HOST_OVERRIDE 10166
#define KW_THROTTLE 10170
#define KW_THREADED 10171
#define KW_PASS_UNIX_CREDENTIALS 10180
#define KW_PERSIST_NAME 10181
#define KW_USE_SYSLOGNG_PID 10182
#define KW_READ_OLD_RECORDS 10185
#define KW_IGNORE_SAVED_BOOKMARKS 10186
#define KW_DISABLE_BOOKMARKS 10187
#define KW_FLAGS 10190
#define KW_PAD_SIZE 10200
#define KW_TIME_ZONE 10201
#define KW_RECV_TIME_ZONE 10202
#define KW_SEND_TIME_ZONE 10203
#define KW_LOCAL_TIME_ZONE 10204
#define KW_FORMAT 10205
#define KW_MULTI_LINE_MODE 10206
#define KW_MULTI_LINE_PREFIX 10207
#define KW_MULTI_LINE_GARBAGE 10208
#define KW_TRUNCATE_SIZE 10209
#define KW_TIME_REOPEN 10210
#define KW_TIME_REAP 10211
#define KW_TIME_SLEEP 10212
#define KW_PARALLELIZE 10215
#define KW_PARTITIONS 10216
#define KW_PARTITION_KEY 10217
#define KW_TMPL_ESCAPE 10220
#define KW_LOG_FETCH_DELAY 10230
#define KW_LOG_FETCH_RETRY_DELAY 10231
#define KW_OPTIONAL 10235
#define KW_CREATE_DIRS 10240
#define KW_OWNER 10250
#define KW_GROUP 10251
#define KW_PERM 10252
#define KW_DIR_OWNER 10260
#define KW_DIR_GROUP 10261
#define KW_DIR_PERM 10262
#define KW_TEMPLATE 10270
#define KW_TEMPLATE_ESCAPE 10271
#define KW_TEMPLATE_FUNCTION 10272
#define KW_DEFAULT_FACILITY 10300
#define KW_DEFAULT_SEVERITY 10301
#define KW_SDATA_PREFIX 10302
#define KW_PORT 10323
#define KW_HTTP 10324
#define KW_USE_TIME_RECVD 10340
#define KW_FACILITY 10350
#define KW_SEVERITY 10351
#define KW_HOST 10352
#define KW_MATCH 10353
#define KW_MESSAGE 10354
#define KW_NETMASK 10355
#define KW_TAGS 10356
#define KW_NETMASK6 10357
#define KW_REWRITE 10370
#define KW_CONDITION 10371
#define KW_VALUE 10372
#define KW_YES 10380
#define KW_NO 10381
#define KW_AUTO 10382
#define KW_IFDEF 10410
#define KW_ENDIF 10411
#define LL_DOTDOT 10420
#define LL_DOTDOTDOT 10421
#define LL_PRAGMA 10422
#define LL_EOL 10423
#define LL_ERROR 10424
#define LL_ARROW 10425
#define LL_IDENTIFIER 10430
#define LL_NUMBER 10431
#define LL_FLOAT 10432
#define LL_STRING 10433
#define LL_TOKEN 10434
#define LL_BLOCK 10435
#define LL_PLUGIN 10436
#define LL_TEMPLATE_REF 10437
#define LL_MESSAGE_REF 10438
#define KW_VALUE_PAIRS 10500
#define KW_EXCLUDE 10502
#define KW_PAIR 10503
#define KW_KEY 10504
#define KW_SCOPE 10505
#define KW_SHIFT 10506
#define KW_SHIFT_LEVELS 10507
#define KW_REKEY 10508
#define KW_ADD_PREFIX 10509
#define KW_REPLACE_PREFIX 10510
#define KW_CAST 10511
#define KW_UPPER 10512
#define KW_LOWER 10513
#define KW_INCLUDE_BYTES 10514
#define KW_ON_ERROR 10520
#define KW_RETRIES 10521
#define KW_FETCH_NO_DATA_DELAY 10522
#define KW_LABELS 10530
#define KW_AUTH 10532
#define KW_INSECURE 10533
#define KW_TLS 10534
#define KW_KEY_FILE 10535
#define KW_CERT_FILE 10536
#define KW_CA_FILE 10537
#define KW_PEER_VERIFY 10538
#define KW_OPTIONAL_UNTRUSTED 10539
#define KW_OPTIONAL_TRUSTED 10540
#define KW_REQUIRED_UNTRUSTED 10541
#define KW_REQUIRED_TRUSTED 10542
#define KW_ALTS 10543
#define KW_TARGET_SERVICE_ACCOUNTS 10544
#define KW_URL 10545
#define KW_ADC 10546
#define KW_SERVICE_ACCOUNT 10547
#define KW_TOKEN_VALIDITY_DURATION 10548
#define KW_COMPRESSION 10549
#define KW_BATCH_BYTES 10550
#define KW_CONCURRENT_REQUESTS 10551
#define KW_KEEP_ALIVE 10552
#define KW_TIME 10553
#define KW_TIMEOUT 10554
#define KW_MAX_PINGS_WITHOUT_DATA 10555
#define KW_CHANNEL_ARGS 10556
#define KW_HEADERS 10557
#define KW_SCHEMA 10558
#define KW_PROTOBUF_SCHEMA 10559
#define KW_RESPONSE_ACTION 10560
#define KW_DISCONNECT 10561
#define KW_DROP 10562
#define KW_RETRY 10563
#define KW_SUCCESS 10564
#define KW_OK 10565
#define KW_UNAVAILABLE 10566
#define KW_CANCELLED 10567
#define KW_DEADLINE_EXCEEDED 10568
#define KW_ABORTED 10569
#define KW_OUT_OF_RANGE 10570
#define KW_DATA_LOSS 10571
#define KW_UNKNOWN 10572
#define KW_INVALID_ARGUMENT 10573
#define KW_NOT_FOUND 10574
#define KW_ALREADY_EXISTS 10575
#define KW_PERMISSION_DENIED 10576
#define KW_UNAUTHENTICATED 10577
#define KW_FAILED_PRECONDITION 10578
#define KW_UNIMPLEMENTED 10579
#define KW_RESOURCE_EXHAUSTED 10580
#define KW_LOKI 10581
#define KW_TIMESTAMP 10582
#define KW_TENANT_ID 10583

/* Value type.  */
#if ! defined LOKI_STYPE && ! defined LOKI_STYPE_IS_DECLARED
typedef CFG_STYPE LOKI_STYPE;
# define LOKI_STYPE_IS_TRIVIAL 1
# define LOKI_STYPE_IS_DECLARED 1
#endif

/* Location type.  */
typedef CFG_LTYPE LOKI_LTYPE;




int loki_parse (CfgLexer *lexer, LogDriver **instance, gpointer arg);


#endif /* !YY_LOKI_MODULES_GRPC_LOKI_LOKI_GRAMMAR_H_INCLUDED  */
/* Symbol kind.  */
enum yysymbol_kind_t
{
  YYSYMBOL_YYEMPTY = -2,
  YYSYMBOL_YYEOF = 0,                      /* "end of file"  */
  YYSYMBOL_YYerror = 1,                    /* error  */
  YYSYMBOL_YYUNDEF = 2,                    /* "invalid token"  */
  YYSYMBOL_LL_CONTEXT_ROOT = 3,            /* LL_CONTEXT_ROOT  */
  YYSYMBOL_LL_CONTEXT_DESTINATION = 4,     /* LL_CONTEXT_DESTINATION  */
  YYSYMBOL_LL_CONTEXT_SOURCE = 5,          /* LL_CONTEXT_SOURCE  */
  YYSYMBOL_LL_CONTEXT_PARSER = 6,          /* LL_CONTEXT_PARSER  */
  YYSYMBOL_LL_CONTEXT_REWRITE = 7,         /* LL_CONTEXT_REWRITE  */
  YYSYMBOL_LL_CONTEXT_FILTER = 8,          /* LL_CONTEXT_FILTER  */
  YYSYMBOL_LL_CONTEXT_LOG = 9,             /* LL_CONTEXT_LOG  */
  YYSYMBOL_LL_CONTEXT_BLOCK_DEF = 10,      /* LL_CONTEXT_BLOCK_DEF  */
  YYSYMBOL_LL_CONTEXT_BLOCK_REF = 11,      /* LL_CONTEXT_BLOCK_REF  */
  YYSYMBOL_LL_CONTEXT_BLOCK_CONTENT = 12,  /* LL_CONTEXT_BLOCK_CONTENT  */
  YYSYMBOL_LL_CONTEXT_BLOCK_ARG = 13,      /* LL_CONTEXT_BLOCK_ARG  */
  YYSYMBOL_LL_CONTEXT_BLOCK_FUNCARG = 14,  /* LL_CONTEXT_BLOCK_FUNCARG  */
  YYSYMBOL_LL_CONTEXT_PRAGMA = 15,         /* LL_CONTEXT_PRAGMA  */
  YYSYMBOL_LL_CONTEXT_FORMAT = 16,         /* LL_CONTEXT_FORMAT  */
  YYSYMBOL_LL_CONTEXT_TEMPLATE_FUNC = 17,  /* LL_CONTEXT_TEMPLATE_FUNC  */
  YYSYMBOL_LL_CONTEXT_INNER_DEST = 18,     /* LL_CONTEXT_INNER_DEST  */
  YYSYMBOL_LL_CONTEXT_INNER_SRC = 19,      /* LL_CONTEXT_INNER_SRC  */
  YYSYMBOL_LL_CONTEXT_CLIENT_PROTO = 20,   /* LL_CONTEXT_CLIENT_PROTO  */
  YYSYMBOL_LL_CONTEXT_SERVER_PROTO = 21,   /* LL_CONTEXT_SERVER_PROTO  */
  YYSYMBOL_LL_CONTEXT_OPTIONS = 22,        /* LL_CONTEXT_OPTIONS  */
  YYSYMBOL_LL_CONTEXT_CONFIG = 23,         /* LL_CONTEXT_CONFIG  */
  YYSYMBOL_LL_CONTEXT_TEMPLATE_REF = 24,   /* LL_CONTEXT_TEMPLATE_REF  */
  YYSYMBOL_LL_CONTEXT_MAX = 25,            /* LL_CONTEXT_MAX  */
  YYSYMBOL_26_ = 26,                       /* ';'  */
  YYSYMBOL_KW_ASSIGN = 27,                 /* KW_ASSIGN  */
  YYSYMBOL_28_ = 28,                       /* '?'  */
  YYSYMBOL_29_ = 29,                       /* ':'  */
  YYSYMBOL_KW_OR = 30,                     /* KW_OR  */
  YYSYMBOL_KW_AND = 31,                    /* KW_AND  */
  YYSYMBOL_KW_STR_EQ = 32,                 /* KW_STR_EQ  */
  YYSYMBOL_KW_STR_NE = 33,                 /* KW_STR_NE  */
  YYSYMBOL_KW_TA_EQ = 34,                  /* KW_TA_EQ  */
  YYSYMBOL_KW_TA_NE = 35,                  /* KW_TA_NE  */
  YYSYMBOL_KW_TAV_EQ = 36,                 /* KW_TAV_EQ  */
  YYSYMBOL_KW_TAV_NE = 37,                 /* KW_TAV_NE  */
  YYSYMBOL_KW_STR_LT = 38,                 /* KW_STR_LT  */
  YYSYMBOL_KW_STR_LE = 39,                 /* KW_STR_LE  */
  YYSYMBOL_KW_STR_GE = 40,                 /* KW_STR_GE  */
  YYSYMBOL_KW_STR_GT = 41,                 /* KW_STR_GT  */
  YYSYMBOL_KW_TA_LT = 42,                  /* KW_TA_LT  */
  YYSYMBOL_KW_TA_LE = 43,                  /* KW_TA_LE  */
  YYSYMBOL_KW_TA_GE = 44,                  /* KW_TA_GE  */
  YYSYMBOL_KW_TA_GT = 45,                  /* KW_TA_GT  */
  YYSYMBOL_KW_PLUS_ASSIGN = 46,            /* KW_PLUS_ASSIGN  */
  YYSYMBOL_KW_REGEXP_MATCH = 47,           /* KW_REGEXP_MATCH  */
  YYSYMBOL_48_ = 48,                       /* '+'  */
  YYSYMBOL_49_ = 49,                       /* '-'  */
  YYSYMBOL_50_ = 50,                       /* '*'  */
  YYSYMBOL_51_ = 51,                       /* '.'  */
  YYSYMBOL_52_ = 52,                       /* '['  */
  YYSYMBOL_53_ = 53,                       /* ']'  */
  YYSYMBOL_KW_NOT = 54,                    /* KW_NOT  */
  YYSYMBOL_KW_SOURCE = 55,                 /* KW_SOURCE  */
  YYSYMBOL_KW_FILTER = 56,                 /* KW_FILTER  */
  YYSYMBOL_KW_PARSER = 57,                 /* KW_PARSER  */
  YYSYMBOL_KW_DESTINATION = 58,            /* KW_DESTINATION  */
  YYSYMBOL_KW_LOG = 59,                    /* KW_LOG  */
  YYSYMBOL_KW_OPTIONS = 60,                /* KW_OPTIONS  */
  YYSYMBOL_KW_INCLUDE = 61,                /* KW_INCLUDE  */
  YYSYMBOL_KW_BLOCK = 62,                  /* KW_BLOCK  */
  YYSYMBOL_KW_JUNCTION = 63,               /* KW_JUNCTION  */
  YYSYMBOL_KW_CHANNEL = 64,                /* KW_CHANNEL  */
  YYSYMBOL_KW_IF = 65,                     /* KW_IF  */
  YYSYMBOL_KW_ELSE = 66,                   /* KW_ELSE  */
  YYSYMBOL_KW_ELIF = 67,                   /* KW_ELIF  */
  YYSYMBOL_KW_INTERNAL = 68,               /* KW_INTERNAL  */
  YYSYMBOL_KW_SYSLOG = 69,                 /* KW_SYSLOG  */
  YYSYMBOL_KW_MARK_FREQ = 70,              /* KW_MARK_FREQ  */
  YYSYMBOL_KW_STATS_FREQ = 71,             /* KW_STATS_FREQ  */
  YYSYMBOL_KW_STATS_LEVEL = 72,            /* KW_STATS_LEVEL  */
  YYSYMBOL_KW_STATS_LIFETIME = 73,         /* KW_STATS_LIFETIME  */
  YYSYMBOL_KW_FLUSH_LINES = 74,            /* KW_FLUSH_LINES  */
  YYSYMBOL_KW_SUPPRESS = 75,               /* KW_SUPPRESS  */
  YYSYMBOL_KW_FLUSH_TIMEOUT = 76,          /* KW_FLUSH_TIMEOUT  */
  YYSYMBOL_KW_LOG_MSG_SIZE = 77,           /* KW_LOG_MSG_SIZE  */
  YYSYMBOL_KW_FILE_TEMPLATE = 78,          /* KW_FILE_TEMPLATE  */
  YYSYMBOL_KW_PROTO_TEMPLATE = 79,         /* KW_PROTO_TEMPLATE  */
  YYSYMBOL_KW_MARK_MODE = 80,              /* KW_MARK_MODE  */
  YYSYMBOL_KW_ENCODING = 81,               /* KW_ENCODING  */
  YYSYMBOL_KW_TYPE = 82,                   /* KW_TYPE  */
  YYSYMBOL_KW_STATS_MAX_DYNAMIC = 83,      /* KW_STATS_MAX_DYNAMIC  */
  YYSYMBOL_KW_MIN_IW_SIZE_PER_READER = 84, /* KW_MIN_IW_SIZE_PER_READER  */
  YYSYMBOL_KW_WORKERS = 85,                /* KW_WORKERS  */
  YYSYMBOL_KW_BATCH_LINES = 86,            /* KW_BATCH_LINES  */
  YYSYMBOL_KW_BATCH_TIMEOUT = 87,          /* KW_BATCH_TIMEOUT  */
  YYSYMBOL_KW_TRIM_LARGE_MESSAGES = 88,    /* KW_TRIM_LARGE_MESSAGES  */
  YYSYMBOL_KW_STATS = 89,                  /* KW_STATS  */
  YYSYMBOL_KW_FREQ = 90,                   /* KW_FREQ  */
  YYSYMBOL_KW_LEVEL = 91,                  /* KW_LEVEL  */
  YYSYMBOL_KW_LIFETIME = 92,               /* KW_LIFETIME  */
  YYSYMBOL_KW_MAX_DYNAMIC = 93,            /* KW_MAX_DYNAMIC  */
  YYSYMBOL_KW_SYSLOG_STATS = 94,           /* KW_SYSLOG_STATS  */
  YYSYMBOL_KW_HEALTHCHECK_FREQ = 95,       /* KW_HEALTHCHECK_FREQ  */
  YYSYMBOL_KW_WORKER_PARTITION_KEY = 96,   /* KW_WORKER_PARTITION_KEY  */
  YYSYMBOL_KW_CHAIN_HOSTNAMES = 97,        /* KW_CHAIN_HOSTNAMES  */
  YYSYMBOL_KW_NORMALIZE_HOSTNAMES = 98,    /* KW_NORMALIZE_HOSTNAMES  */
  YYSYMBOL_KW_KEEP_HOSTNAME = 99,          /* KW_KEEP_HOSTNAME  */
  YYSYMBOL_KW_CHECK_HOSTNAME = 100,        /* KW_CHECK_HOSTNAME  */
  YYSYMBOL_KW_BAD_HOSTNAME = 101,          /* KW_BAD_HOSTNAME  */
  YYSYMBOL_KW_LOG_LEVEL = 102,             /* KW_LOG_LEVEL  */
  YYSYMBOL_KW_IDLE_TIMEOUT = 103,          /* KW_IDLE_TIMEOUT  */
  YYSYMBOL_KW_CHECK_PROGRAM = 104,         /* KW_CHECK_PROGRAM  */
  YYSYMBOL_KW_KEEP_TIMESTAMP = 105,        /* KW_KEEP_TIMESTAMP  */
  YYSYMBOL_KW_USE_DNS = 106,               /* KW_USE_DNS  */
  YYSYMBOL_KW_USE_FQDN = 107,              /* KW_USE_FQDN  */
  YYSYMBOL_KW_CUSTOM_DOMAIN = 108,         /* KW_CUSTOM_DOMAIN  */
  YYSYMBOL_KW_DNS_CACHE = 109,             /* KW_DNS_CACHE  */
  YYSYMBOL_KW_DNS_CACHE_SIZE = 110,        /* KW_DNS_CACHE_SIZE  */
  YYSYMBOL_KW_DNS_CACHE_EXPIRE = 111,      /* KW_DNS_CACHE_EXPIRE  */
  YYSYMBOL_KW_DNS_CACHE_EXPIRE_FAILED = 112, /* KW_DNS_CACHE_EXPIRE_FAILED  */
  YYSYMBOL_KW_DNS_CACHE_HOSTS = 113,       /* KW_DNS_CACHE_HOSTS  */
  YYSYMBOL_KW_PERSIST_ONLY = 114,          /* KW_PERSIST_ONLY  */
  YYSYMBOL_KW_USE_RCPTID = 115,            /* KW_USE_RCPTID  */
  YYSYMBOL_KW_USE_UNIQID = 116,            /* KW_USE_UNIQID  */
  YYSYMBOL_KW_TZ_CONVERT = 117,            /* KW_TZ_CONVERT  */
  YYSYMBOL_KW_TS_FORMAT = 118,             /* KW_TS_FORMAT  */
  YYSYMBOL_KW_FRAC_DIGITS = 119,           /* KW_FRAC_DIGITS  */
  YYSYMBOL_KW_LOG_FIFO_SIZE = 120,         /* KW_LOG_FIFO_SIZE  */
  YYSYMBOL_KW_LOG_FETCH_LIMIT = 121,       /* KW_LOG_FETCH_LIMIT  */
  YYSYMBOL_KW_LOG_IW_SIZE = 122,           /* KW_LOG_IW_SIZE  */
  YYSYMBOL_KW_LOG_PREFIX = 123,            /* KW_LOG_PREFIX  */
  YYSYMBOL_KW_PROGRAM_OVERRIDE = 124,      /* KW_PROGRAM_OVERRIDE  */
  YYSYMBOL_KW_HOST_OVERRIDE = 125,         /* KW_HOST_OVERRIDE  */
  YYSYMBOL_KW_THROTTLE = 126,              /* KW_THROTTLE  */
  YYSYMBOL_KW_THREADED = 127,              /* KW_THREADED  */
  YYSYMBOL_KW_PASS_UNIX_CREDENTIALS = 128, /* KW_PASS_UNIX_CREDENTIALS  */
  YYSYMBOL_KW_PERSIST_NAME = 129,          /* KW_PERSIST_NAME  */
  YYSYMBOL_KW_USE_SYSLOGNG_PID = 130,      /* KW_USE_SYSLOGNG_PID  */
  YYSYMBOL_KW_READ_OLD_RECORDS = 131,      /* KW_READ_OLD_RECORDS  */
  YYSYMBOL_KW_IGNORE_SAVED_BOOKMARKS = 132, /* KW_IGNORE_SAVED_BOOKMARKS  */
  YYSYMBOL_KW_DISABLE_BOOKMARKS = 133,     /* KW_DISABLE_BOOKMARKS  */
  YYSYMBOL_KW_FLAGS = 134,                 /* KW_FLAGS  */
  YYSYMBOL_KW_PAD_SIZE = 135,              /* KW_PAD_SIZE  */
  YYSYMBOL_KW_TIME_ZONE = 136,             /* KW_TIME_ZONE  */
  YYSYMBOL_KW_RECV_TIME_ZONE = 137,        /* KW_RECV_TIME_ZONE  */
  YYSYMBOL_KW_SEND_TIME_ZONE = 138,        /* KW_SEND_TIME_ZONE  */
  YYSYMBOL_KW_LOCAL_TIME_ZONE = 139,       /* KW_LOCAL_TIME_ZONE  */
  YYSYMBOL_KW_FORMAT = 140,                /* KW_FORMAT  */
  YYSYMBOL_KW_MULTI_LINE_MODE = 141,       /* KW_MULTI_LINE_MODE  */
  YYSYMBOL_KW_MULTI_LINE_PREFIX = 142,     /* KW_MULTI_LINE_PREFIX  */
  YYSYMBOL_KW_MULTI_LINE_GARBAGE = 143,    /* KW_MULTI_LINE_GARBAGE  */
  YYSYMBOL_KW_TRUNCATE_SIZE = 144,         /* KW_TRUNCATE_SIZE  */
  YYSYMBOL_KW_TIME_REOPEN = 145,           /* KW_TIME_REOPEN  */
  YYSYMBOL_KW_TIME_REAP = 146,             /* KW_TIME_REAP  */
  YYSYMBOL_KW_TIME_SLEEP = 147,            /* KW_TIME_SLEEP  */
  YYSYMBOL_KW_PARALLELIZE = 148,           /* KW_PARALLELIZE  */
  YYSYMBOL_KW_PARTITIONS = 149,            /* KW_PARTITIONS  */
  YYSYMBOL_KW_PARTITION_KEY = 150,         /* KW_PARTITION_KEY  */
  YYSYMBOL_KW_TMPL_ESCAPE = 151,           /* KW_TMPL_ESCAPE  */
  YYSYMBOL_KW_LOG_FETCH_DELAY = 152,       /* KW_LOG_FETCH_DELAY  */
  YYSYMBOL_KW_LOG_FETCH_RETRY_DELAY = 153, /* KW_LOG_FETCH_RETRY_DELAY  */
  YYSYMBOL_KW_OPTIONAL = 154,              /* KW_OPTIONAL  */
  YYSYMBOL_KW_CREATE_DIRS = 155,           /* KW_CREATE_DIRS  */
  YYSYMBOL_KW_OWNER = 156,                 /* KW_OWNER  */
  YYSYMBOL_KW_GROUP = 157,                 /* KW_GROUP  */
  YYSYMBOL_KW_PERM = 158,                  /* KW_PERM  */
  YYSYMBOL_KW_DIR_OWNER = 159,             /* KW_DIR_OWNER  */
  YYSYMBOL_KW_DIR_GROUP = 160,             /* KW_DIR_GROUP  */
  YYSYMBOL_KW_DIR_PERM = 161,              /* KW_DIR_PERM  */
  YYSYMBOL_KW_TEMPLATE = 162,              /* KW_TEMPLATE  */
  YYSYMBOL_KW_TEMPLATE_ESCAPE = 163,       /* KW_TEMPLATE_ESCAPE  */
  YYSYMBOL_KW_TEMPLATE_FUNCTION = 164,     /* KW_TEMPLATE_FUNCTION  */
  YYSYMBOL_KW_DEFAULT_FACILITY = 165,      /* KW_DEFAULT_FACILITY  */
  YYSYMBOL_KW_DEFAULT_SEVERITY = 166,      /* KW_DEFAULT_SEVERITY  */
  YYSYMBOL_KW_SDATA_PREFIX = 167,          /* KW_SDATA_PREFIX  */
  YYSYMBOL_KW_PORT = 168,                  /* KW_PORT  */
  YYSYMBOL_KW_HTTP = 169,                  /* KW_HTTP  */
  YYSYMBOL_KW_USE_TIME_RECVD = 170,        /* KW_USE_TIME_RECVD  */
  YYSYMBOL_KW_FACILITY = 171,              /* KW_FACILITY  */
  YYSYMBOL_KW_SEVERITY = 172,              /* KW_SEVERITY  */
  YYSYMBOL_KW_HOST = 173,                  /* KW_HOST  */
  YYSYMBOL_KW_MATCH = 174,                 /* KW_MATCH  */
  YYSYMBOL_KW_MESSAGE = 175,               /* KW_MESSAGE  */
  YYSYMBOL_KW_NETMASK = 176,               /* KW_NETMASK  */
  YYSYMBOL_KW_TAGS = 177,                  /* KW_TAGS  */
  YYSYMBOL_KW_NETMASK6 = 178,              /* KW_NETMASK6  */
  YYSYMBOL_KW_REWRITE = 179,               /* KW_REWRITE  */
  YYSYMBOL_KW_CONDITION = 180,             /* KW_CONDITION  */
  YYSYMBOL_KW_VALUE = 181,                 /* KW_VALUE  */
  YYSYMBOL_KW_YES = 182,                   /* KW_YES  */
  YYSYMBOL_KW_NO = 183,                    /* KW_NO  */
  YYSYMBOL_KW_AUTO = 184,                  /* KW_AUTO  */
  YYSYMBOL_KW_IFDEF = 185,                 /* KW_IFDEF  */
  YYSYMBOL_KW_ENDIF = 186,                 /* KW_ENDIF  */
  YYSYMBOL_LL_DOTDOT = 187,                /* LL_DOTDOT  */
  YYSYMBOL_LL_DOTDOTDOT = 188,             /* LL_DOTDOTDOT  */
  YYSYMBOL_LL_PRAGMA = 189,                /* LL_PRAGMA  */
  YYSYMBOL_LL_EOL = 190,                   /* LL_EOL  */
  YYSYMBOL_LL_ERROR = 191,                 /* LL_ERROR  */
  YYSYMBOL_LL_ARROW = 192,                 /* LL_ARROW  */
  YYSYMBOL_LL_IDENTIFIER = 193,            /* LL_IDENTIFIER  */
  YYSYMBOL_LL_NUMBER = 194,                /* LL_NUMBER  */
  YYSYMBOL_LL_FLOAT = 195,                 /* LL_FLOAT  */
  YYSYMBOL_LL_STRING = 196,                /* LL_STRING  */
  YYSYMBOL_LL_TOKEN = 197,                 /* LL_TOKEN  */
  YYSYMBOL_LL_BLOCK = 198,                 /* LL_BLOCK  */
  YYSYMBOL_LL_PLUGIN = 199,                /* LL_PLUGIN  */
  YYSYMBOL_LL_TEMPLATE_REF = 200,          /* LL_TEMPLATE_REF  */
  YYSYMBOL_LL_MESSAGE_REF = 201,           /* LL_MESSAGE_REF  */
  YYSYMBOL_KW_VALUE_PAIRS = 202,           /* KW_VALUE_PAIRS  */
  YYSYMBOL_KW_EXCLUDE = 203,               /* KW_EXCLUDE  */
  YYSYMBOL_KW_PAIR = 204,                  /* KW_PAIR  */
  YYSYMBOL_KW_KEY = 205,                   /* KW_KEY  */
  YYSYMBOL_KW_SCOPE = 206,                 /* KW_SCOPE  */
  YYSYMBOL_KW_SHIFT = 207,                 /* KW_SHIFT  */
  YYSYMBOL_KW_SHIFT_LEVELS = 208,          /* KW_SHIFT_LEVELS  */
  YYSYMBOL_KW_REKEY = 209,                 /* KW_REKEY  */
  YYSYMBOL_KW_ADD_PREFIX = 210,            /* KW_ADD_PREFIX  */
  YYSYMBOL_KW_REPLACE_PREFIX = 211,        /* KW_REPLACE_PREFIX  */
  YYSYMBOL_KW_CAST = 212,                  /* KW_CAST  */
  YYSYMBOL_KW_UPPER = 213,                 /* KW_UPPER  */
  YYSYMBOL_KW_LOWER = 214,                 /* KW_LOWER  */
  YYSYMBOL_KW_INCLUDE_BYTES = 215,         /* KW_INCLUDE_BYTES  */
  YYSYMBOL_KW_ON_ERROR = 216,              /* KW_ON_ERROR  */
  YYSYMBOL_KW_RETRIES = 217,               /* KW_RETRIES  */
  YYSYMBOL_KW_FETCH_NO_DATA_DELAY = 218,   /* KW_FETCH_NO_DATA_DELAY  */
  YYSYMBOL_KW_LABELS = 219,                /* KW_LABELS  */
  YYSYMBOL_KW_AUTH = 220,                  /* KW_AUTH  */
  YYSYMBOL_KW_INSECURE = 221,              /* KW_INSECURE  */
  YYSYMBOL_KW_TLS = 222,                   /* KW_TLS  */
  YYSYMBOL_KW_KEY_FILE = 223,              /* KW_KEY_FILE  */
  YYSYMBOL_KW_CERT_FILE = 224,             /* KW_CERT_FILE  */
  YYSYMBOL_KW_CA_FILE = 225,               /* KW_CA_FILE  */
  YYSYMBOL_KW_PEER_VERIFY = 226,           /* KW_PEER_VERIFY  */
  YYSYMBOL_KW_OPTIONAL_UNTRUSTED = 227,    /* KW_OPTIONAL_UNTRUSTED  */
  YYSYMBOL_KW_OPTIONAL_TRUSTED = 228,      /* KW_OPTIONAL_TRUSTED  */
  YYSYMBOL_KW_REQUIRED_UNTRUSTED = 229,    /* KW_REQUIRED_UNTRUSTED  */
  YYSYMBOL_KW_REQUIRED_TRUSTED = 230,      /* KW_REQUIRED_TRUSTED  */
  YYSYMBOL_KW_ALTS = 231,                  /* KW_ALTS  */
  YYSYMBOL_KW_TARGET_SERVICE_ACCOUNTS = 232, /* KW_TARGET_SERVICE_ACCOUNTS  */
  YYSYMBOL_KW_URL = 233,                   /* KW_URL  */
  YYSYMBOL_KW_ADC = 234,                   /* KW_ADC  */
  YYSYMBOL_KW_SERVICE_ACCOUNT = 235,       /* KW_SERVICE_ACCOUNT  */
  YYSYMBOL_KW_TOKEN_VALIDITY_DURATION = 236, /* KW_TOKEN_VALIDITY_DURATION  */
  YYSYMBOL_KW_COMPRESSION = 237,           /* KW_COMPRESSION  */
  YYSYMBOL_KW_BATCH_BYTES = 238,           /* KW_BATCH_BYTES  */
  YYSYMBOL_KW_CONCURRENT_REQUESTS = 239,   /* KW_CONCURRENT_REQUESTS  */
  YYSYMBOL_KW_KEEP_ALIVE = 240,            /* KW_KEEP_ALIVE  */
  YYSYMBOL_KW_TIME = 241,                  /* KW_TIME  */
  YYSYMBOL_KW_TIMEOUT = 242,               /* KW_TIMEOUT  */
  YYSYMBOL_KW_MAX_PINGS_WITHOUT_DATA = 243, /* KW_MAX_PINGS_WITHOUT_DATA  */
  YYSYMBOL_KW_CHANNEL_ARGS = 244,          /* KW_CHANNEL_ARGS  */
  YYSYMBOL_KW_HEADERS = 245,               /* KW_HEADERS  */
  YYSYMBOL_KW_SCHEMA = 246,                /* KW_SCHEMA  */
  YYSYMBOL_KW_PROTOBUF_SCHEMA = 247,       /* KW_PROTOBUF_SCHEMA  */
  YYSYMBOL_KW_RESPONSE_ACTION = 248,       /* KW_RESPONSE_ACTION  */
  YYSYMBOL_KW_DISCONNECT = 249,            /* KW_DISCONNECT  */
  YYSYMBOL_KW_DROP = 250,                  /* KW_DROP  */
  YYSYMBOL_KW_RETRY = 251,                 /* KW_RETRY  */
  YYSYMBOL_KW_SUCCESS = 252,               /* KW_SUCCESS  */
  YYSYMBOL_KW_OK = 253,                    /* KW_OK  */
  YYSYMBOL_KW_UNAVAILABLE = 254,           /* KW_UNAVAILABLE  */
  YYSYMBOL_KW_CANCELLED = 255,             /* KW_CANCELLED  */
  YYSYMBOL_KW_DEADLINE_EXCEEDED = 256,     /* KW_DEADLINE_EXCEEDED  */
  YYSYMBOL_KW_ABORTED = 257,               /* KW_ABORTED  */
  YYSYMBOL_KW_OUT_OF_RANGE = 258,          /* KW_OUT_OF_RANGE  */
  YYSYMBOL_KW_DATA_LOSS = 259,             /* KW_DATA_LOSS  */
  YYSYMBOL_KW_UNKNOWN = 260,               /* KW_UNKNOWN  */
  YYSYMBOL_KW_INVALID_ARGUMENT = 261,      /* KW_INVALID_ARGUMENT  */
  YYSYMBOL_KW_NOT_FOUND = 262,             /* KW_NOT_FOUND  */
  YYSYMBOL_KW_ALREADY_EXISTS = 263,        /* KW_ALREADY_EXISTS  */
  YYSYMBOL_KW_PERMISSION_DENIED = 264,     /* KW_PERMISSION_DENIED  */
  YYSYMBOL_KW_UNAUTHENTICATED = 265,       /* KW_UNAUTHENTICATED  */
  YYSYMBOL_KW_FAILED_PRECONDITION = 266,   /* KW_FAILED_PRECONDITION  */
  YYSYMBOL_KW_UNIMPLEMENTED = 267,         /* KW_UNIMPLEMENTED  */
  YYSYMBOL_KW_RESOURCE_EXHAUSTED = 268,    /* KW_RESOURCE_EXHAUSTED  */
  YYSYMBOL_KW_LOKI = 269,                  /* KW_LOKI  */
  YYSYMBOL_KW_TIMESTAMP = 270,             /* KW_TIMESTAMP  */
  YYSYMBOL_KW_TENANT_ID = 271,             /* KW_TENANT_ID  */
  YYSYMBOL_272_ = 272,                     /* '('  */
  YYSYMBOL_273_ = 273,                     /* ')'  */
  YYSYMBOL_274_ = 274,                     /* '{'  */
  YYSYMBOL_275_ = 275,                     /* '}'  */
  YYSYMBOL_YYACCEPT = 276,                 /* $accept  */
  YYSYMBOL_start = 277,                    /* start  */
  YYSYMBOL_loki_dest = 278,                /* loki_dest  */
  YYSYMBOL_279_1 = 279,                    /* $@1  */
  YYSYMBOL_loki_dest_options = 280,        /* loki_dest_options  */
  YYSYMBOL_loki_dest_option = 281,         /* loki_dest_option  */
  YYSYMBOL_loki_labels = 282,              /* loki_labels  */
  YYSYMBOL_loki_label = 283,               /* loki_label  */
  YYSYMBOL_template_content_inner = 284,   /* template_content_inner  */
  YYSYMBOL_type_hint = 285,                /* type_hint  */
  YYSYMBOL_template_content = 286,         /* template_content  */
  YYSYMBOL_287_4 = 287,                    /* @4  */
  YYSYMBOL_template_name_or_content = 288, /* template_name_or_content  */
  YYSYMBOL_template_name_or_content_tail = 289, /* template_name_or_content_tail  */
  YYSYMBOL_string = 290,                   /* string  */
  YYSYMBOL_yesno_strict = 291,             /* yesno_strict  */
  YYSYMBOL_yesno = 292,                    /* yesno  */
  YYSYMBOL_nonnegative_integer64 = 293,    /* nonnegative_integer64  */
  YYSYMBOL_nonnegative_integer = 294,      /* nonnegative_integer  */
  YYSYMBOL_positive_integer64 = 295,       /* positive_integer64  */
  YYSYMBOL_positive_integer = 296,         /* positive_integer  */
  YYSYMBOL_string_or_number = 297,         /* string_or_number  */
  YYSYMBOL_path = 298,                     /* path  */
  YYSYMBOL_path_secret = 299,              /* path_secret  */
  YYSYMBOL_driver_option = 300,            /* driver_option  */
  YYSYMBOL_inner_dest = 301,               /* inner_dest  */
  YYSYMBOL_dest_driver_option = 302,       /* dest_driver_option  */
  YYSYMBOL_threaded_dest_driver_batch_option = 303, /* threaded_dest_driver_batch_option  */
  YYSYMBOL_threaded_dest_driver_workers_option = 304, /* threaded_dest_driver_workers_option  */
  YYSYMBOL_threaded_dest_driver_general_option = 305, /* threaded_dest_driver_general_option  */
  YYSYMBOL_threaded_dest_driver_general_option_noflags = 306, /* threaded_dest_driver_general_option_noflags  */
  YYSYMBOL_threaded_dest_driver_flags_option = 307, /* threaded_dest_driver_flags_option  */
  YYSYMBOL_threaded_dest_driver_flags = 308, /* threaded_dest_driver_flags  */
  YYSYMBOL_template_option = 309,          /* template_option  */
  YYSYMBOL__template_ref_context_push = 310, /* _template_ref_context_push  */
  YYSYMBOL__inner_dest_context_push = 311, /* _inner_dest_context_push  */
  YYSYMBOL__inner_dest_context_pop = 312,  /* _inner_dest_context_pop  */
  YYSYMBOL_grpc_dest_general_option = 313, /* grpc_dest_general_option  */
  YYSYMBOL_314_19 = 314,                   /* $@19  */
  YYSYMBOL_315_20 = 315,                   /* $@20  */
  YYSYMBOL_grpc_keepalive_options = 316,   /* grpc_keepalive_options  */
  YYSYMBOL_grpc_keepalive_option = 317,    /* grpc_keepalive_option  */
  YYSYMBOL_grpc_dest_channel_args = 318,   /* grpc_dest_channel_args  */
  YYSYMBOL_grpc_dest_channel_arg = 319,    /* grpc_dest_channel_arg  */
  YYSYMBOL_grpc_dest_headers = 320,        /* grpc_dest_headers  */
  YYSYMBOL_grpc_dest_header = 321,         /* grpc_dest_header  */
  YYSYMBOL_grpc_dest_response_action_items = 322, /* grpc_dest_response_action_items  */
  YYSYMBOL_grpc_dest_response_action_item = 323, /* grpc_dest_response_action_item  */
  YYSYMBOL_grpc_dest_response = 324,       /* grpc_dest_response  */
  YYSYMBOL_grpc_dest_response_action = 325, /* grpc_dest_response_action  */
  YYSYMBOL_grpc_client_credentials_option = 326, /* grpc_client_credentials_option  */
  YYSYMBOL_327_24 = 327,                   /* $@24  */
  YYSYMBOL_328_25 = 328,                   /* $@25  */
  YYSYMBOL_329_26 = 329,                   /* $@26  */
  YYSYMBOL_330_27 = 330,                   /* $@27  */
  YYSYMBOL_331_28 = 331,                   /* $@28  */
  YYSYMBOL_grpc_client_credentials_builder_tls_options = 332, /* grpc_client_credentials_builder_tls_options  */
  YYSYMBOL_grpc_client_credentials_builder_tls_option = 333, /* grpc_client_credentials_builder_tls_option  */
  YYSYMBOL_grpc_client_credentials_builder_alts_options = 334, /* grpc_client_credentials_builder_alts_options  */
  YYSYMBOL_grpc_client_credentials_builder_alts_option = 335, /* grpc_client_credentials_builder_alts_option  */
  YYSYMBOL_grpc_client_credentials_builder_alts_target_service_accounts = 336, /* grpc_client_credentials_builder_alts_target_service_accounts  */
  YYSYMBOL_337_29 = 337,                   /* $@29  */
  YYSYMBOL_grpc_client_credentials_builder_service_account_options = 338, /* grpc_client_credentials_builder_service_account_options  */
  YYSYMBOL_grpc_client_credentials_builder_service_account_option = 339 /* grpc_client_credentials_builder_service_account_option  */
};
typedef enum yysymbol_kind_t yysymbol_kind_t;



/* Unqualified %code blocks.  */
#line 30 "modules/grpc/loki/loki-grammar.y"


#include "cfg-grammar-internal.h"
#include "plugin.h"
#include "syslog-names.h"

#include "loki-dest.h"

#include <stdlib.h>

#line 57 "modules/grpc/loki/loki-grammar.y"


#pragma GCC diagnostic ignored "-Wswitch-default"
#pragma GCC diagnostic ignored "-Wunused-but-set-variable"

#if (defined(__GNUC__) && __GNUC__ >= 6) || (defined(__clang__) && __clang_major__ >= 10)
#  pragma GCC diagnostic ignored "-Wmisleading-indentation"
#endif


# define YYLLOC_DEFAULT(Current, Rhs, N)                                \
  do {                                                                  \
    if (N)                                                              \
      {                                                                 \
        (Current).name         = YYRHSLOC(Rhs, 1).name;                 \
        (Current).first_line   = YYRHSLOC (Rhs, 1).first_line;          \
        (Current).first_column = YYRHSLOC (Rhs, 1).first_column;        \
        (Current).last_line    = YYRHSLOC (Rhs, N).last_line;           \
        (Current).last_column  = YYRHSLOC (Rhs, N).last_column;         \
      }                                                                 \
    else                                                                \
      {                                                                 \
        (Current).name         = YYRHSLOC(Rhs, 0).name;                 \
        (Current).first_line   = (Current).last_line   =                \
          YYRHSLOC (Rhs, 0).last_line;                                  \
        (Current).first_column = (Current).last_column =                \
          YYRHSLOC (Rhs, 0).last_column;                                \
      }                                                                 \
  } while (0)

#define CHECK_ERROR_WITHOUT_MESSAGE(val, token) do {                    \
    if (!(val))                                                         \
      {                                                                 \
        YYERROR;                                                        \
      }                                                                 \
  } while (0)

#define CHECK_ERROR(val, token, errorfmt, ...) do {                     \
    if (!(val))                                                         \
      {                                                                 \
        if (errorfmt)                                                   \
          {                                                             \
            gchar __buf[256];                                           \
            g_snprintf(__buf, sizeof(__buf), errorfmt, ## __VA_ARGS__); \
            yyerror(& (token), lexer, NULL, NULL, __buf);               \
          }                                                             \
        YYERROR;                                                        \
      }                                                                 \
  } while (0)

#define CHECK_ERROR_GERROR(val, token, error, errorfmt, ...) do {       \
    if (!(val))                                                         \
      {                                                                 \
        if (errorfmt)                                                   \
          {                                                             \
            gchar __buf[256];                                           \
            g_snprintf(__buf, sizeof(__buf), errorfmt ", error=%s", ## __VA_ARGS__, error->message); \
            yyerror(& (token), lexer, NULL, NULL, __buf);               \
          }                                                             \
        g_clear_error(&error);						\
        YYERROR;                                                        \
      }                                                                 \
  } while (0)

#define YYMAXDEPTH 20000


#line 469 "modules/grpc/loki/loki-grammar.y"


#include "grpc-dest.h"
#include "grpc-source.h"
#include "cfg-grammar-internal.h"
#include "plugin.h"

GrpcServerCredentialsBuilderW *last_grpc_server_credentials_builder;
GrpcClientCredentialsBuilderW *last_grpc_client_credentials_builder;


#line 1122 "modules/grpc/loki/loki-grammar.c"

#ifdef short
# undef short
#endif

/* On compilers that do not define __PTRDIFF_MAX__ etc., make sure
   <limits.h> and (if available) <stdint.h> are included
   so that the code can choose integer types of a good width.  */

#ifndef __PTRDIFF_MAX__
# include <limits.h> /* INFRINGES ON USER NAME SPACE */
# if defined __STDC_VERSION__ && 199901 <= __STDC_VERSION__
#  include <stdint.h> /* INFRINGES ON USER NAME SPACE */
#  define YY_STDINT_H
# endif
#endif

/* Narrow types that promote to a signed type and that can represent a
   signed or unsigned integer of at least N bits.  In tables they can
   save space and decrease cache pressure.  Promoting to a signed type
   helps avoid bugs in integer arithmetic.  */

#ifdef __INT_LEAST8_MAX__
typedef __INT_LEAST8_TYPE__ yytype_int8;
#elif defined YY_STDINT_H
typedef int_least8_t yytype_int8;
#else
typedef signed char yytype_int8;
#endif

#ifdef __INT_LEAST16_MAX__
typedef __INT_LEAST16_TYPE__ yytype_int16;
#elif defined YY_STDINT_H
typedef int_least16_t yytype_int16;
#else
typedef short yytype_int16;
#endif

/* Work around bug in HP-UX 11.23, which defines these macros
   incorrectly for preprocessor constants.  This workaround can likely
   be removed in 2023, as HPE has promised support for HP-UX 11.23
   (aka HP-UX 11i v2) only through the end of 2022; see Table 2 of
   <https://h20195.www2.hpe.com/V2/getpdf.aspx/4AA4-7673ENW.pdf>.  */
#ifdef __hpux
# undef UINT_LEAST8_MAX
# undef UINT_LEAST16_MAX
# define UINT_LEAST8_MAX 255
# define UINT_LEAST16_MAX 65535
#endif

#if defined __UINT_LEAST8_MAX__ && __UINT_LEAST8_MAX__ <= __INT_MAX__
typedef __UINT_LEAST8_TYPE__ yytype_uint8;
#elif (!defined __UINT_LEAST8_MAX__ && defined YY_STDINT_H \
       && UINT_LEAST8_MAX <= INT_MAX)
typedef uint_least8_t yytype_uint8;
#elif !defined __UINT_LEAST8_MAX__ && UCHAR_MAX <= INT_MAX
typedef unsigned char yytype_uint8;
#else
typedef short yytype_uint8;
#endif

#if defined __UINT_LEAST16_MAX__ && __UINT_LEAST16_MAX__ <= __INT_MAX__
typedef __UINT_LEAST16_TYPE__ yytype_uint16;
#elif (!defined __UINT_LEAST16_MAX__ && defined YY_STDINT_H \
       && UINT_LEAST16_MAX <= INT_MAX)
typedef uint_least16_t yytype_uint16;
#elif !defined __UINT_LEAST16_MAX__ && USHRT_MAX <= INT_MAX
typedef unsigned short yytype_uint16;
#else
typedef int yytype_uint16;
#endif

#ifndef YYPTRDIFF_T
# if defined __PTRDIFF_TYPE__ && defined __PTRDIFF_MAX__
#  define YYPTRDIFF_T __PTRDIFF_TYPE__
#  define YYPTRDIFF_MAXIMUM __PTRDIFF_MAX__
# elif defined PTRDIFF_MAX
#  ifndef ptrdiff_t
#   include <stddef.h> /* INFRINGES ON USER NAME SPACE */
#  endif
#  define YYPTRDIFF_T ptrdiff_t
#  define YYPTRDIFF_MAXIMUM PTRDIFF_MAX
# else
#  define YYPTRDIFF_T long
#  define YYPTRDIFF_MAXIMUM LONG_MAX
# endif
#endif

#ifndef YYSIZE_T
# ifdef __SIZE_TYPE__
#  define YYSIZE_T __SIZE_TYPE__
# elif defined size_t
#  define YYSIZE_T size_t
# elif defined __STDC_VERSION__ && 199901 <= __STDC_VERSION__
#  include <stddef.h> /* INFRINGES ON USER NAME SPACE */
#  define YYSIZE_T size_t
# else
#  define YYSIZE_T unsigned
# endif
#endif

#define YYSIZE_MAXIMUM                                  \
  YY_CAST (YYPTRDIFF_T,                                 \
           (YYPTRDIFF_MAXIMUM < YY_CAST (YYSIZE_T, -1)  \
            ? YYPTRDIFF_MAXIMUM                         \
            : YY_CAST (YYSIZE_T, -1)))

#define YYSIZEOF(X) YY_CAST (YYPTRDIFF_T, sizeof (X))


/* Stored state numbers (used for stacks). */
typedef yytype_int16 yy_state_t;

/* State numbers in computations.  */
typedef int yy_state_fast_t;

#ifndef YY_
# if defined YYENABLE_NLS && YYENABLE_NLS
#  if ENABLE_NLS
#   include <libintl.h> /* INFRINGES ON USER NAME SPACE */
#   define YY_(Msgid) dgettext ("bison-runtime", Msgid)
#  endif
# endif
# ifndef YY_
#  define YY_(Msgid) Msgid
# endif
#endif


#ifndef YY_ATTRIBUTE_PURE
# if defined __GNUC__ && 2 < __GNUC__ + (96 <= __GNUC_MINOR__)
#  define YY_ATTRIBUTE_PURE __attribute__ ((__pure__))
# else
#  define YY_ATTRIBUTE_PURE
# endif
#endif

#ifndef YY_ATTRIBUTE_UNUSED
# if defined __GNUC__ && 2 < __GNUC__ + (7 <= __GNUC_MINOR__)
#  define YY_ATTRIBUTE_UNUSED __attribute__ ((__unused__))
# else
#  define YY_ATTRIBUTE_UNUSED
# endif
#endif

/* Suppress unused-variable warnings by "using" E.  */
#if ! defined lint || defined __GNUC__
# define YY_USE(E) ((void) (E))
#else
# define YY_USE(E) /* empty */
#endif

/* Suppress an incorrect diagnostic about yylval being uninitialized.  */
#if defined __GNUC__ && ! defined __ICC && 406 <= __GNUC__ * 100 + __GNUC_MINOR__
# if __GNUC__ * 100 + __GNUC_MINOR__ < 407
#  define YY_IGNORE_MAYBE_UNINITIALIZED_BEGIN                           \
    _Pragma ("GCC diagnostic push")                                     \
    _Pragma ("GCC diagnostic ignored \"-Wuninitialized\"")
# else
#  define YY_IGNORE_MAYBE_UNINITIALIZED_BEGIN                           \
    _Pragma ("GCC diagnostic push")                                     \
    _Pragma ("GCC diagnostic ignored \"-Wuninitialized\"")              \
    _Pragma ("GCC diagnostic ignored \"-Wmaybe-uninitialized\"")
# endif
# define YY_IGNORE_MAYBE_UNINITIALIZED_END      \
    _Pragma ("GCC diagnostic pop")
#else
# define YY_INITIAL_VALUE(Value) Value
#endif
#ifndef YY_IGNORE_MAYBE_UNINITIALIZED_BEGIN
# define YY_IGNORE_MAYBE_UNINITIALIZED_BEGIN
# define YY_IGNORE_MAYBE_UNINITIALIZED_END
#endif
#ifndef YY_INITIAL_VALUE
# define YY_INITIAL_VALUE(Value) /* Nothing. */
#endif

#if defined __cplusplus && defined __GNUC__ && ! defined __ICC && 6 <= __GNUC__
# define YY_IGNORE_USELESS_CAST_BEGIN                          \
    _Pragma ("GCC diagnostic push")                            \
    _Pragma ("GCC diagnostic ignored \"-Wuseless-cast\"")
# define YY_IGNORE_USELESS_CAST_END            \
    _Pragma ("GCC diagnostic pop")
#endif
#ifndef YY_IGNORE_USELESS_CAST_BEGIN
# define YY_IGNORE_USELESS_CAST_BEGIN
# define YY_IGNORE_USELESS_CAST_END
#endif


#define YY_ASSERT(E) ((void) (0 && (E)))

#if 1

/* The parser invokes alloca or malloc; define the necessary symbols.  */

# ifdef YYSTACK_USE_ALLOCA
#  if YYSTACK_USE_ALLOCA
#   ifdef __GNUC__
#    define YYSTACK_ALLOC __builtin_alloca
#   elif defined __BUILTIN_VA_ARG_INCR
#    include <alloca.h> /* INFRINGES ON USER NAME SPACE */
#   elif defined _AIX
#    define YYSTACK_ALLOC __alloca
#   elif defined _MSC_VER
#    include <malloc.h> /* INFRINGES ON USER NAME SPACE */
#    define alloca _alloca
#   else
#    define YYSTACK_ALLOC alloca
#    if ! defined _ALLOCA_H && ! defined EXIT_SUCCESS
#     include <stdlib.h> /* INFRINGES ON USER NAME SPACE */
      /* Use EXIT_SUCCESS as a witness for stdlib.h.  */
#     ifndef EXIT_SUCCESS
#      define EXIT_SUCCESS 0
#     endif
#    endif
#   endif
#  endif
# endif

# ifdef YYSTACK_ALLOC
   /* Pacify GCC's 'empty if-body' warning.  */
#  define YYSTACK_FREE(Ptr) do { /* empty */; } while (0)
#  ifndef YYSTACK_ALLOC_MAXIMUM
    /* The OS might guarantee only one guard page at the bottom of the stack,
       and a page size can be as small as 4096 bytes.  So we cannot safely
       invoke alloca (N) if N exceeds 4096.  Use a slightly smaller number
       to allow for a few compiler-allocated temporary stack slots.  */
#   define YYSTACK_ALLOC_MAXIMUM 4032 /* reasonable circa 2006 */
#  endif
# else
#  define YYSTACK_ALLOC YYMALLOC
#  define YYSTACK_FREE YYFREE
#  ifndef YYSTACK_ALLOC_MAXIMUM
#   define YYSTACK_ALLOC_MAXIMUM YYSIZE_MAXIMUM
#  endif
#  if (defined __cplusplus && ! defined EXIT_SUCCESS \
       && ! ((defined YYMALLOC || defined malloc) \
             && (defined YYFREE || defined free)))
#   include <stdlib.h> /* INFRINGES ON USER NAME SPACE */
#   ifndef EXIT_SUCCESS
#    define EXIT_SUCCESS 0
#   endif
#  endif
#  ifndef YYMALLOC
#   define YYMALLOC malloc
#   if ! defined malloc && ! defined EXIT_SUCCESS
void *malloc (YYSIZE_T); /* INFRINGES ON USER NAME SPACE */
#   endif
#  endif
#  ifndef YYFREE
#   define YYFREE free
#   if ! defined free && ! defined EXIT_SUCCESS
void free (void *); /* INFRINGES ON USER NAME SPACE */
#   endif
#  endif
# endif
#endif /* 1 */

#if (! defined yyoverflow \
     && (! defined __cplusplus \
         || (defined LOKI_LTYPE_IS_TRIVIAL && LOKI_LTYPE_IS_TRIVIAL \
             && defined LOKI_STYPE_IS_TRIVIAL && LOKI_STYPE_IS_TRIVIAL)))

/* A type that is properly aligned for any stack member.  */
union yyalloc
{
  yy_state_t yyss_alloc;
  YYSTYPE yyvs_alloc;
  YYLTYPE yyls_alloc;
};

/* The size of the maximum gap between one aligned stack and the next.  */
# define YYSTACK_GAP_MAXIMUM (YYSIZEOF (union yyalloc) - 1)

/* The size of an array large to enough to hold all stacks, each with
   N elements.  */
# define YYSTACK_BYTES(N) \
     ((N) * (YYSIZEOF (yy_state_t) + YYSIZEOF (YYSTYPE) \
             + YYSIZEOF (YYLTYPE)) \
      + 2 * YYSTACK_GAP_MAXIMUM)

# define YYCOPY_NEEDED 1

/* Relocate STACK from its old location to the new one.  The
   local variables YYSIZE and YYSTACKSIZE give the old and new number of
   elements in the stack, and YYPTR gives the new location of the
   stack.  Advance YYPTR to a properly aligned location for the next
   stack.  */
# define YYSTACK_RELOCATE(Stack_alloc, Stack)                           \
    do                                                                  \
      {                                                                 \
        YYPTRDIFF_T yynewbytes;                                         \
        YYCOPY (&yyptr->Stack_alloc, Stack, yysize);                    \
        Stack = &yyptr->Stack_alloc;                                    \
        yynewbytes = yystacksize * YYSIZEOF (*Stack) + YYSTACK_GAP_MAXIMUM; \
        yyptr += yynewbytes / YYSIZEOF (*yyptr);                        \
      }                                                                 \
    while (0)

#endif

#if defined YYCOPY_NEEDED && YYCOPY_NEEDED
/* Copy COUNT objects from SRC to DST.  The source and destination do
   not overlap.  */
# ifndef YYCOPY
#  if defined __GNUC__ && 1 < __GNUC__
#   define YYCOPY(Dst, Src, Count) \
      __builtin_memcpy (Dst, Src, YY_CAST (YYSIZE_T, (Count)) * sizeof (*(Src)))
#  else
#   define YYCOPY(Dst, Src, Count)              \
      do                                        \
        {                                       \
          YYPTRDIFF_T yyi;                      \
          for (yyi = 0; yyi < (Count); yyi++)   \
            (Dst)[yyi] = (Src)[yyi];            \
        }                                       \
      while (0)
#  endif
# endif
#endif /* !YYCOPY_NEEDED */

/* YYFINAL -- State number of the termination state.  */
#define YYFINAL  5
/* YYLAST -- Last index in YYTABLE.  */
#define YYLAST   245

/* YYNTOKENS -- Number of terminals.  */
#define YYNTOKENS  276
/* YYNNTS -- Number of nonterminals.  */
#define YYNNTS  64
/* YYNRULES -- Number of rules.  */
#define YYNRULES  143
/* YYNSTATES -- Number of states.  */
#define YYNSTATES  290

/* YYMAXUTOK -- Last valid token kind.  */
#define YYMAXUTOK   10583


/* YYTRANSLATE(TOKEN-NUM) -- Symbol number corresponding to TOKEN-NUM
   as returned by yylex, with out-of-bounds checking.  */
#define YYTRANSLATE(YYX)                                \
  (0 <= (YYX) && (YYX) <= YYMAXUTOK                     \
   ? YY_CAST (yysymbol_kind_t, yytranslate[YYX])        \
   : YYSYMBOL_YYUNDEF)

/* YYTRANSLATE[TOKEN-NUM] -- Symbol number corresponding to TOKEN-NUM
   as returned by yylex.  */
static const yytype_int16 yytranslate[] =
{
       0,     3,     4,     5,     6,     7,     8,     9,    10,    11,
      12,    13,    14,    15,    16,    17,    18,    19,    20,    21,
      22,    23,    24,    25,     2,     2,     2,     2,     2,     2,
       2,     2,     2,     2,     2,     2,     2,     2,     2,     2,
     272,   273,    50,    48,     2,    49,    51,     2,     2,     2,
       2,     2,     2,     2,     2,     2,     2,     2,    29,    26,
       2,     2,     2,    28,     2,     2,     2,     2,     2,     2,
       2,     2,     2,     2,     2,     2,     2,     2,     2,     2,
       2,     2,     2,     2,     2,     2,     2,     2,     2,     2,
       2,    52,     2,    53,     2,     2,     2,     2,     2,     2,
       2,     2,     2,     2,     2,     2,     2,     2,     2,     2,
       2,     2,     2,     2,     2,     2,     2,     2,     2,     2,
       2,     2,     2,   274,     2,   275,     2,     2,     2,     2,
       2,     2,     2,     2,     2,     2,     2,     2,     2,     2,
       2,     2,     2,     2,     2,     2,     2,     2,     2,     2,
       2,     2,     2,     2,     2,     2,     2,     2,     2,     2,
       2,     2,     2,     2,     2,     2,     2,     2,     2,     2,
       2,     2,     2,     2,     2,     2,     2,     2,     2,     2,
       2,     2,     2,     2,     2,     2,     2,     2,     2,     2,
       2,     2,     2,     2,     2,     2,     2,     2,     2,     2,
       2,     2,     2,     2,     2,     2,     2,     2,     2,     2,
       2,     2,     2,     2,     2,     2,     2,     2,     2,     2,
       2,     2,     2,     2,     2,     2,     2,     2,     2,     2,
       2,     2,     2,     2,     2,     2,     2,     2,     2,     2,
       2,     2,     2,     2,     2,     2,     2,     2,     2,     2,
       2,     2,     2,     2,     2,     2,     1,     2,     2,     2,
       2,     2,     2,     2,     2,     2,     2,     2,     2,     2,
       2,     2,     2,     2,     2,     2,     2,     2,     2,     2,
       2,     2,     2,     2,     2,     2,     2,     2,     2,     2,
       2,     2,     2,     2,     2,     2,     2,     2,     2,     2,
       2,     2,     2,     2,     2,     2,     2,     2,     2,     2,
       2,     2,     2,     2,     2,     2,     2,     2,     2,     2,
       2,     2,     2,     2,     2,     2,     2,     2,     2,     2,
       2,     2,     2,     2,     2,     2,     2,     2,     2,     2,
       2,     2,     2,     2,     2,     2,     2,     2,     2,     2,
       2,     2,     2,     2,     2,     2,     2,     2,     2,     2,
       2,     2,     2,     2,     2,     2,     2,     2,     2,     2,
       2,     2,     2,     2,     2,     2,     2,     2,     2,     2,
       2,     2,     2,     2,     2,     2,     2,     2,     2,     2,
       2,     2,     2,     2,     2,     2,     2,     2,     2,     2,
       2,     2,     2,     2,     2,     2,     2,     2,     2,     2,
       2,     2,     2,     2,     2,     2,     2,     2,     2,     2,
       2,     2,     2,     2,     2,     2,     2,     2,     2,     2,
       2,     2,     2,     2,     2,     2,     2,     2,     2,     2,
       2,     2,     2,     2,     2,     2,     2,     2,     2,     2,
       2,     2,     2,     2,     2,     2,     2,     2,     2,     2,
       2,     2,     2,     2,     2,     2,     2,     2,     2,     2,
       2,     2,     2,     2,     2,     2,     2,     2,     2,     2,
       2,     2,     2,     2,     2,     2,     2,     2,     2,     2,
       2,     2,     2,     2,     2,     2,     2,     2,     2,     2,
       2,     2,     2,     2,     2,     2,     2,     2,     2,     2,
       2,     2,     2,     2,     2,     2,     2,     2,     2,     2,
       2,     2,     2,     2,     2,     2,     2,     2,     2,     2,
       2,     2,     2,     2,     2,     2,     2,     2,     2,     2,
       2,     2,     2,     2,     2,     2,     2,     2,     2,     2,
       2,     2,     2,     2,     2,     2,     2,     2,     2,     2,
       2,     2,     2,     2,     2,     2,     2,     2,     2,     2,
       2,     2,     2,     2,     2,     2,     2,     2,     2,     2,
       2,     2,     2,     2,     2,     2,     2,     2,     2,     2,
       2,     2,     2,     2,     2,     2,     2,     2,     2,     2,
       2,     2,     2,     2,     2,     2,     2,     2,     2,     2,
       2,     2,     2,     2,     2,     2,     2,     2,     2,     2,
       2,     2,     2,     2,     2,     2,     2,     2,     2,     2,
       2,     2,     2,     2,     2,     2,     2,     2,     2,     2,
       2,     2,     2,     2,     2,     2,     2,     2,     2,     2,
       2,     2,     2,     2,     2,     2,     2,     2,     2,     2,
       2,     2,     2,     2,     2,     2,     2,     2,     2,     2,
       2,     2,     2,     2,     2,     2,     2,     2,     2,     2,
       2,     2,     2,     2,     2,     2,     2,     2,     2,     2,
       2,     2,     2,     2,     2,     2,     2,     2,     2,     2,
       2,     2,     2,     2,     2,     2,     2,     2,     2,     2,
       2,     2,     2,     2,     2,     2,     2,     2,     2,     2,
       2,     2,     2,     2,     2,     2,     2,     2,     2,     2,
       2,     2,     2,     2,     2,     2,     2,     2,     2,     2,
       2,     2,     2,     2,     2,     2,     2,     2,     2,     2,
       2,     2,     2,     2,     2,     2,     2,     2,     2,     2,
       2,     2,     2,     2,     2,     2,     2,     2,     2,     2,
       2,     2,     2,     2,     2,     2,     2,     2,     2,     2,
       2,     2,     2,     2,     2,     2,     2,     2,     2,     2,
       2,     2,     2,     2,     2,     2,     2,     2,     2,     2,
       2,     2,     2,     2,     2,     2,     2,     2,     2,     2,
       2,     2,     2,     2,     2,     2,     2,     2,     2,     2,
       2,     2,     2,     2,     2,     2,     2,     2,     2,     2,
       2,     2,     2,     2,     2,     2,     2,     2,     2,     2,
       2,     2,     2,     2,     2,     2,     2,     2,     2,     2,
       2,     2,     2,     2,     2,     2,     2,     2,     2,     2,
       2,     2,     2,     2,     2,     2,     2,     2,     2,     2,
       2,     2,     2,     2,     2,     2,     2,     2,     2,     2,
       2,     2,     2,     2,     2,     2,     2,     2,     2,     2,
       2,     2,     2,     2,     2,     2,     2,     2,     2,     2,
       2,     2,     2,     2,     2,     2,     2,     2,     2,     2,
       2,     2,     2,     2,     2,     2,     2,     2,     2,     2,
       2,     2,     2,     2,     2,     2,     2,     2,     2,     2,
       2,     2,     2,     2,     2,     2,     2,     2,     2,     2,
       2,     2,     2,     2,     2,     2,     2,     2,     2,     2,
       2,     2,     2,     2,     2,     2,     2,     2,     2,     2,
       2,     2,     2,     2,     2,     2,     2,     2,     2,     2,
       2,     2,     2,     2,     2,     2,     2,     2,     2,     2,
       2,     2,     2,     2,     2,     2,     2,     2,     2,     2,
       2,     2,     2,     2,     2,     2,     2,     2,     2,     2,
       2,     2,     2,     2,     2,     2,     2,     2,     2,     2,
       2,     2,     2,     2,     2,     2,     2,     2,     2,     2,
       2,     2,     2,     2,     2,     2,     2,     2,     2,     2,
       2,     2,     2,     2,     2,     2,     2,     2,     2,     2,
       2,     2,     2,     2,     2,     2,     2,     2,     2,     2,
       2,     2,     2,     2,     2,     2,     2,     2,     2,     2,
       2,     2,     2,     2,     2,     2,     2,     2,     2,     2,
       2,     2,     2,     2,     2,     2,     2,     2,     2,     2,
       2,     2,     2,     2,     2,     2,     2,     2,     2,     2,
       2,     2,     2,     2,     2,     2,     2,     2,     2,     2,
       2,     2,     2,     2,     2,     2,     2,     2,     2,     2,
       2,     2,     2,     2,     2,     2,     2,     2,     2,     2,
       2,     2,     2,     2,     2,     2,     2,     2,     2,     2,
       2,     2,     2,     2,     2,     2,     2,     2,     2,     2,
       2,     2,     2,     2,     2,     2,     2,     2,     2,     2,
       2,     2,     2,     2,     2,     2,     2,     2,     2,     2,
       2,     2,     2,     2,     2,     2,     2,     2,     2,     2,
       2,     2,     2,     2,     2,     2,     2,     2,     2,     2,
       2,     2,     2,     2,     2,     2,     2,     2,     2,     2,
       2,     2,     2,     2,     2,     2,     2,     2,     2,     2,
       2,     2,     2,     2,     2,     2,     2,     2,     2,     2,
       2,     2,     2,     2,     2,     2,     2,     2,     2,     2,
       2,     2,     2,     2,     2,     2,     2,     2,     2,     2,
       2,     2,     2,     2,     2,     2,     2,     2,     2,     2,
       2,     2,     2,     2,     2,     2,     2,     2,     2,     2,
       2,     2,     2,     2,     2,     2,     2,     2,     2,     2,
       2,     2,     2,     2,     2,     2,     2,     2,     2,     2,
       2,     2,     2,     2,     2,     2,     2,     2,     2,     2,
       2,     2,     2,     2,     2,     2,     2,     2,     2,     2,
       2,     2,     2,     2,     2,     2,     2,     2,     2,     2,
       2,     2,     2,     2,     2,     2,     2,     2,     2,     2,
       2,     2,     2,     2,     2,     2,     2,     2,     2,     2,
       2,     2,     2,     2,     2,     2,     2,     2,     2,     2,
       2,     2,     2,     2,     2,     2,     2,     2,     2,     2,
       2,     2,     2,     2,     2,     2,     2,     2,     2,     2,
       2,     2,     2,     2,     2,     2,     2,     2,     2,     2,
       2,     2,     2,     2,     2,     2,     2,     2,     2,     2,
       2,     2,     2,     2,     2,     2,     2,     2,     2,     2,
       2,     2,     2,     2,     2,     2,     2,     2,     2,     2,
       2,     2,     2,     2,     2,     2,     2,     2,     2,     2,
       2,     2,     2,     2,     2,     2,     2,     2,     2,     2,
       2,     2,     2,     2,     2,     2,     2,     2,     2,     2,
       2,     2,     2,     2,     2,     2,     2,     2,     2,     2,
       2,     2,     2,     2,     2,     2,     2,     2,     2,     2,
       2,     2,     2,     2,     2,     2,     2,     2,     2,     2,
       2,     2,     2,     2,     2,     2,     2,     2,     2,     2,
       2,     2,     2,     2,     2,     2,     2,     2,     2,     2,
       2,     2,     2,     2,     2,     2,     2,     2,     2,     2,
       2,     2,     2,     2,     2,     2,     2,     2,     2,     2,
       2,     2,     2,     2,     2,     2,     2,     2,     2,     2,
       2,     2,     2,     2,     2,     2,     2,     2,     2,     2,
       2,     2,     2,     2,     2,     2,     2,     2,     2,     2,
       2,     2,     2,     2,     2,     2,     2,     2,     2,     2,
       2,     2,     2,     2,     2,     2,     2,     2,     2,     2,
       2,     2,     2,     2,     2,     2,     2,     2,     2,     2,
       2,     2,     2,     2,     2,     2,     2,     2,     2,     2,
       2,     2,     2,     2,     2,     2,     2,     2,     2,     2,
       2,     2,     2,     2,     2,     2,     2,     2,     2,     2,
       2,     2,     2,     2,     2,     2,     2,     2,     2,     2,
       2,     2,     2,     2,     2,     2,     2,     2,     2,     2,
       2,     2,     2,     2,     2,     2,     2,     2,     2,     2,
       2,     2,     2,     2,     2,     2,     2,     2,     2,     2,
       2,     2,     2,     2,     2,     2,     2,     2,     2,     2,
       2,     2,     2,     2,     2,     2,     2,     2,     2,     2,
       2,     2,     2,     2,     2,     2,     2,     2,     2,     2,
       2,     2,     2,     2,     2,     2,     2,     2,     2,     2,
       2,     2,     2,     2,     2,     2,     2,     2,     2,     2,
       2,     2,     2,     2,     2,     2,     2,     2,     2,     2,
       2,     2,     2,     2,     2,     2,     2,     2,     2,     2,
       2,     2,     2,     2,     2,     2,     2,     2,     2,     2,
       2,     2,     2,     2,     2,     2,     2,     2,     2,     2,
       2,     2,     2,     2,     2,     2,     2,     2,     2,     2,
       2,     2,     2,     2,     2,     2,     2,     2,     2,     2,
       2,     2,     2,     2,     2,     2,     2,     2,     2,     2,
       2,     2,     2,     2,     2,     2,     2,     2,     2,     2,
       2,     2,     2,     2,     2,     2,     2,     2,     2,     2,
       2,     2,     2,     2,     2,     2,     2,     2,     2,     2,
       2,     2,     2,     2,     2,     2,     2,     2,     2,     2,
       2,     2,     2,     2,     2,     2,     2,     2,     2,     2,
       2,     2,     2,     2,     2,     2,     2,     2,     2,     2,
       2,     2,     2,     2,     2,     2,     2,     2,     2,     2,
       2,     2,     2,     2,     2,     2,     2,     2,     2,     2,
       2,     2,     2,     2,     2,     2,     2,     2,     2,     2,
       2,     2,     2,     2,     2,     2,     2,     2,     2,     2,
       2,     2,     2,     2,     2,     2,     2,     2,     2,     2,
       2,     2,     2,     2,     2,     2,     2,     2,     2,     2,
       2,     2,     2,     2,     2,     2,     2,     2,     2,     2,
       2,     2,     2,     2,     2,     2,     2,     2,     2,     2,
       2,     2,     2,     2,     2,     2,     2,     2,     2,     2,
       2,     2,     2,     2,     2,     2,     2,     2,     2,     2,
       2,     2,     2,     2,     2,     2,     2,     2,     2,     2,
       2,     2,     2,     2,     2,     2,     2,     2,     2,     2,
       2,     2,     2,     2,     2,     2,     2,     2,     2,     2,
       2,     2,     2,     2,     2,     2,     2,     2,     2,     2,
       2,     2,     2,     2,     2,     2,     2,     2,     2,     2,
       2,     2,     2,     2,     2,     2,     2,     2,     2,     2,
       2,     2,     2,     2,     2,     2,     2,     2,     2,     2,
       2,     2,     2,     2,     2,     2,     2,     2,     2,     2,
       2,     2,     2,     2,     2,     2,     2,     2,     2,     2,
       2,     2,     2,     2,     2,     2,     2,     2,     2,     2,
       2,     2,     2,     2,     2,     2,     2,     2,     2,     2,
       2,     2,     2,     2,     2,     2,     2,     2,     2,     2,
       2,     2,     2,     2,     2,     2,     2,     2,     2,     2,
       2,     2,     2,     2,     2,     2,     2,     2,     2,     2,
       2,     2,     2,     2,     2,     2,     2,     2,     2,     2,
       2,     2,     2,     2,     2,     2,     2,     2,     2,     2,
       2,     2,     2,     2,     2,     2,     2,     2,     2,     2,
       2,     2,     2,     2,     2,     2,     2,     2,     2,     2,
       2,     2,     2,     2,     2,     2,     2,     2,     2,     2,
       2,     2,     2,     2,     2,     2,     2,     2,     2,     2,
       2,     2,     2,     2,     2,     2,     2,     2,     2,     2,
       2,     2,     2,     2,     2,     2,     2,     2,     2,     2,
       2,     2,     2,     2,     2,     2,     2,     2,     2,     2,
       2,     2,     2,     2,     2,     2,     2,     2,     2,     2,
       2,     2,     2,     2,     2,     2,     2,     2,     2,     2,
       2,     2,     2,     2,     2,     2,     2,     2,     2,     2,
       2,     2,     2,     2,     2,     2,     2,     2,     2,     2,
       2,     2,     2,     2,     2,     2,     2,     2,     2,     2,
       2,     2,     2,     2,     2,     2,     2,     2,     2,     2,
       2,     2,     2,     2,     2,     2,     2,     2,     2,     2,
       2,     2,     2,     2,     2,     2,     2,     2,     2,     2,
       2,     2,     2,     2,     2,     2,     2,     2,     2,     2,
       2,     2,     2,     2,     2,     2,     2,     2,     2,     2,
       2,     2,     2,     2,     2,     2,     2,     2,     2,     2,
       2,     2,     2,     2,     2,     2,     2,     2,     2,     2,
       2,     2,     2,     2,     2,     2,     2,     2,     2,     2,
       2,     2,     2,     2,     2,     2,     2,     2,     2,     2,
       2,     2,     2,     2,     2,     2,     2,     2,     2,     2,
       2,     2,     2,     2,     2,     2,     2,     2,     2,     2,
       2,     2,     2,     2,     2,     2,     2,     2,     2,     2,
       2,     2,     2,     2,     2,     2,     2,     2,     2,     2,
       2,     2,     2,     2,     2,     2,     2,     2,     2,     2,
       2,     2,     2,     2,     2,     2,     2,     2,     2,     2,
       2,     2,     2,     2,     2,     2,     2,     2,     2,     2,
       2,     2,     2,     2,     2,     2,     2,     2,     2,     2,
       2,     2,     2,     2,     2,     2,     2,     2,     2,     2,
       2,     2,     2,     2,     2,     2,     2,     2,     2,     2,
       2,     2,     2,     2,     2,     2,     2,     2,     2,     2,
       2,     2,     2,     2,     2,     2,     2,     2,     2,     2,
       2,     2,     2,     2,     2,     2,     2,     2,     2,     2,
       2,     2,     2,     2,     2,     2,     2,     2,     2,     2,
       2,     2,     2,     2,     2,     2,     2,     2,     2,     2,
       2,     2,     2,     2,     2,     2,     2,     2,     2,     2,
       2,     2,     2,     2,     2,     2,     2,     2,     2,     2,
       2,     2,     2,     2,     2,     2,     2,     2,     2,     2,
       2,     2,     2,     2,     2,     2,     2,     2,     2,     2,
       2,     2,     2,     2,     2,     2,     2,     2,     2,     2,
       2,     2,     2,     2,     2,     2,     2,     2,     2,     2,
       2,     2,     2,     2,     2,     2,     2,     2,     2,     2,
       2,     2,     2,     2,     2,     2,     2,     2,     2,     2,
       2,     2,     2,     2,     2,     2,     2,     2,     2,     2,
       2,     2,     2,     2,     2,     2,     2,     2,     2,     2,
       2,     2,     2,     2,     2,     2,     2,     2,     2,     2,
       2,     2,     2,     2,     2,     2,     2,     2,     2,     2,
       2,     2,     2,     2,     2,     2,     2,     2,     2,     2,
       2,     2,     2,     2,     2,     2,     2,     2,     2,     2,
       2,     2,     2,     2,     2,     2,     2,     2,     2,     2,
       2,     2,     2,     2,     2,     2,     2,     2,     2,     2,
       2,     2,     2,     2,     2,     2,     2,     2,     2,     2,
       2,     2,     2,     2,     2,     2,     2,     2,     2,     2,
       2,     2,     2,     2,     2,     2,     2,     2,     2,     2,
       2,     2,     2,     2,     2,     2,     2,     2,     2,     2,
       2,     2,     2,     2,     2,     2,     2,     2,     2,     2,
       2,     2,     2,     2,     2,     2,     2,     2,     2,     2,
       2,     2,     2,     2,     2,     2,     2,     2,     2,     2,
       2,     2,     2,     2,     2,     2,     2,     2,     2,     2,
       2,     2,     2,     2,     2,     2,     2,     2,     2,     2,
       2,     2,     2,     2,     2,     2,     2,     2,     2,     2,
       2,     2,     2,     2,     2,     2,     2,     2,     2,     2,
       2,     2,     2,     2,     2,     2,     2,     2,     2,     2,
       2,     2,     2,     2,     2,     2,     2,     2,     2,     2,
       2,     2,     2,     2,     2,     2,     2,     2,     2,     2,
       2,     2,     2,     2,     2,     2,     2,     2,     2,     2,
       2,     2,     2,     2,     2,     2,     2,     2,     2,     2,
       2,     2,     2,     2,     2,     2,     2,     2,     2,     2,
       2,     2,     2,     2,     2,     2,     2,     2,     2,     2,
       2,     2,     2,     2,     2,     2,     2,     2,     2,     2,
       2,     2,     2,     2,     2,     2,     2,     2,     2,     2,
       2,     2,     2,     2,     2,     2,     2,     2,     2,     2,
       2,     2,     2,     2,     2,     2,     2,     2,     2,     2,
       2,     2,     2,     2,     2,     2,     2,     2,     2,     2,
       2,     2,     2,     2,     2,     2,     2,     2,     2,     2,
       2,     2,     2,     2,     2,     2,     2,     2,     2,     2,
       2,     2,     2,     2,     2,     2,     2,     2,     2,     2,
       2,     2,     2,     2,     2,     2,     2,     2,     2,     2,
       2,     2,     2,     2,     2,     2,     2,     2,     2,     2,
       2,     2,     2,     2,     2,     2,     2,     2,     2,     2,
       2,     2,     2,     2,     2,     2,     2,     2,     2,     2,
       2,     2,     2,     2,     2,     2,     2,     2,     2,     2,
       2,     2,     2,     2,     2,     2,     2,     2,     2,     2,
       2,     2,     2,     2,     2,     2,     2,     2,     2,     2,
       2,     2,     2,     2,     2,     2,     2,     2,     2,     2,
       2,     2,     2,     2,     2,     2,     2,     2,     2,     2,
       2,     2,     2,     2,     2,     2,     2,     2,     2,     2,
       2,     2,     2,     2,     2,     2,     2,     2,     2,     2,
       2,     2,     2,     2,     2,     2,     2,     2,     2,     2,
       2,     2,     2,     2,     2,     2,     2,     2,     2,     2,
       2,     2,     2,     2,     2,     2,     2,     2,     2,     2,
       2,     2,     2,     2,     2,     2,     2,     2,     2,     2,
       2,     2,     2,     2,     2,     2,     2,     2,     2,     2,
       2,     2,     2,     2,     2,     2,     2,     2,     2,     2,
       2,     2,     2,     2,     2,     2,     2,     2,     2,     2,
       2,     2,     2,     2,     2,     2,     2,     2,     2,     2,
       2,     2,     2,     2,     2,     2,     2,     2,     2,     2,
       2,     2,     2,     2,     2,     2,     2,     2,     2,     2,
       2,     2,     2,     2,     2,     2,     2,     2,     2,     2,
       2,     2,     2,     2,     2,     2,     2,     2,     2,     2,
       2,     2,     2,     2,     2,     2,     2,     2,     2,     2,
       2,     2,     2,     2,     2,     2,     2,     2,     2,     2,
       2,     2,     2,     2,     2,     2,     2,     2,     2,     2,
       2,     2,     2,     2,     2,     2,     2,     2,     2,     2,
       2,     2,     2,     2,     2,     2,     2,     2,     2,     2,
       2,     2,     2,     2,     2,     2,     2,     2,     2,     2,
       2,     2,     2,     2,     2,     2,     2,     2,     2,     2,
       2,     2,     2,     2,     2,     2,     2,     2,     2,     2,
       2,     2,     2,     2,     2,     2,     2,     2,     2,     2,
       2,     2,     2,     2,     2,     2,     2,     2,     2,     2,
       2,     2,     2,     2,     2,     2,     2,     2,     2,     2,
       2,     2,     2,     2,     2,     2,     2,     2,     2,     2,
       2,     2,     2,     2,     2,     2,     2,     2,     2,     2,
       2,     2,     2,     2,     2,     2,     2,     2,     2,     2,
       2,     2,     2,     2,     2,     2,     2,     2,     2,     2,
       2,     2,     2,     2,     2,     2,     2,     2,     2,     2,
       2,     2,     2,     2,     2,     2,     2,     2,     2,     2,
       2,     2,     2,     2,     2,     2,     2,     2,     2,     2,
       2,     2,     2,     2,     2,     2,     2,     2,     2,     2,
       2,     2,     2,     2,     2,     2,     2,     2,     2,     2,
       2,     2,     2,     2,     2,     2,     2,     2,     2,     2,
       2,     2,     2,     2,     2,     2,     2,     2,     2,     2,
       2,     2,     2,     2,     2,     2,     2,     2,     2,     2,
       2,     2,     2,     2,     2,     2,     2,     2,     2,     2,
       2,     2,     2,     2,     2,     2,     2,     2,     2,     2,
       2,     2,     2,     2,     2,     2,     2,     2,     2,     2,
       2,     2,     2,     2,     2,     2,     2,     2,     2,     2,
       2,     2,     2,     2,     2,     2,     2,     2,     2,     2,
       2,     2,     2,     2,     2,     2,     2,     2,     2,     2,
       2,     2,     2,     2,     2,     2,     2,     2,     2,     2,
       2,     2,     2,     2,     2,     2,     2,     2,     2,     2,
       2,     2,     2,     2,     2,     2,     2,     2,     2,     2,
       2,     2,     2,     2,     2,     2,     2,     2,     2,     2,
       2,     2,     2,     2,     2,     2,     2,     2,     2,     2,
       2,     2,     2,     2,     2,     2,     2,     2,     2,     2,
       2,     2,     2,     2,     2,     2,     2,     2,     2,     2,
       2,     2,     2,     2,     2,     2,     2,     2,     2,     2,
       2,     2,     2,     2,     2,     2,     2,     2,     2,     2,
       2,     2,     2,     2,     2,     2,     2,     2,     2,     2,
       2,     2,     2,     2,     2,     2,     2,     2,     2,     2,
       2,     2,     2,     2,     2,     2,     2,     2,     2,     2,
       2,     2,     2,     2,     2,     2,     2,     2,     2,     2,
       2,     2,     2,     2,     2,     2,     2,     2,     2,     2,
       2,     2,     2,     2,     2,     2,     2,     2,     2,     2,
       2,     2,     2,     2,     2,     2,     2,     2,     2,     2,
       2,     2,     2,     2,     2,     2,     2,     2,     2,     2,
       2,     2,     2,     2,     2,     2,     2,     2,     2,     2,
       2,     2,     2,     2,     2,     2,     2,     2,     2,     2,
       2,     2,     2,     2,     2,     2,     2,     2,     2,     2,
       2,     2,     2,     2,     2,     2,     2,     2,     2,     2,
       2,     2,     2,     2,     2,     2,     2,     2,     2,     2,
       2,     2,     2,     2,     2,     2,     2,     2,     2,     2,
       2,     2,     2,     2,     2,     2,     2,     2,     2,     2,
       2,     2,     2,     2,     2,     2,     2,     2,     2,     2,
       2,     2,     2,     2,     2,     2,     2,     2,     2,     2,
       2,     2,     2,     2,     2,     2,     2,     2,     2,     2,
       2,     2,     2,     2,     2,     2,     2,     2,     2,     2,
       2,     2,     2,     2,     2,     2,     2,     2,     2,     2,
       2,     2,     2,     2,     2,     2,     2,     2,     2,     2,
       2,     2,     2,     2,     2,     2,     2,     2,     2,     2,
       2,     2,     2,     2,     2,     2,     2,     2,     2,     2,
       2,     2,     2,     2,     2,     2,     2,     2,     2,     2,
       2,     2,     2,     2,     2,     2,     2,     2,     2,     2,
       2,     2,     2,     2,     2,     2,     2,     2,     2,     2,
       2,     2,     2,     2,     2,     2,     2,     2,     2,     2,
       2,     2,     2,     2,     2,     2,     2,     2,     2,     2,
       2,     2,     2,     2,     2,     2,     2,     2,     2,     2,
       2,     2,     2,     2,     2,     2,     2,     2,     2,     2,
       2,     2,     2,     2,     2,     2,     2,     2,     2,     2,
       2,     2,     2,     2,     2,     2,     2,     2,     2,     2,
       2,     2,     2,     2,     2,     2,     2,     2,     2,     2,
       2,     2,     2,     2,     2,     2,     2,     2,     2,     2,
       2,     2,     2,     2,     2,     2,     2,     2,     2,     2,
       2,     2,     2,     2,     2,     2,     2,     2,     2,     2,
       2,     2,     2,     2,     2,     2,     2,     2,     2,     2,
       2,     2,     2,     2,     2,     2,     2,     2,     2,     2,
       2,     2,     2,     2,     2,     2,     2,     2,     2,     2,
       2,     2,     2,     2,     2,     2,     2,     2,     2,     2,
       2,     2,     2,     2,     2,     2,     2,     2,     2,     2,
       2,     2,     2,     2,     2,     2,     2,     2,     2,     2,
       2,     2,     2,     2,     2,     2,     2,     2,     2,     2,
       2,     2,     2,     2,     2,     2,     2,     2,     2,     2,
       2,     2,     2,     2,     2,     2,     2,     2,     2,     2,
       2,     2,     2,     2,     2,     2,     2,     2,     2,     2,
       2,     2,     2,     2,     2,     2,     2,     2,     2,     2,
       2,     2,     2,     2,     2,     2,     2,     2,     2,     2,
       2,     2,     2,     2,     2,     2,     2,     2,     2,     2,
       2,     2,     2,     2,     2,     2,     2,     2,     2,     2,
       2,     2,     2,     2,     2,     2,     2,     2,     2,     2,
       2,     2,     2,     2,     2,     2,     2,     2,     2,     2,
       2,     2,     2,     2,     2,     2,     2,     2,     2,     2,
       2,     2,     2,     2,     2,     2,     2,     2,     2,     2,
       2,     2,     2,     2,     2,     2,     2,     2,     2,     2,
       2,     2,     2,     2,     2,     2,     2,     2,     2,     2,
       2,     2,     2,     2,     2,     2,     2,     2,     2,     2,
       2,     2,     2,     2,     2,     2,     2,     2,     2,     2,
       2,     2,     2,     2,     2,     2,     2,     2,     2,     2,
       2,     2,     2,     2,     2,     2,     2,     2,     2,     2,
       2,     2,     2,     2,     2,     2,     2,     2,     2,     2,
       2,     2,     2,     2,     2,     2,     2,     2,     2,     2,
       2,     2,     2,     2,     2,     2,     2,     2,     2,     2,
       2,     2,     2,     2,     2,     2,     2,     2,     2,     2,
       2,     2,     2,     2,     2,     2,     2,     2,     2,     2,
       2,     2,     2,     2,     2,     2,     2,     2,     2,     2,
       2,     2,     2,     2,     2,     2,     2,     2,     2,     2,
       2,     2,     2,     2,     2,     2,     2,     2,     2,     2,
       2,     2,     2,     2,     2,     2,     2,     2,     2,     2,
       2,     2,     2,     2,     2,     2,     2,     2,     2,     2,
       2,     2,     2,     2,     2,     2,     2,     2,     2,     2,
       2,     2,     2,     2,     2,     2,     2,     2,     2,     2,
       2,     2,     2,     2,     2,     2,     2,     2,     2,     2,
       2,     2,     2,     2,     2,     2,     2,     2,     2,     2,
       2,     2,     2,     2,     2,     2,     2,     2,     2,     2,
       2,     2,     2,     2,     2,     2,     2,     2,     2,     2,
       2,     2,     2,     2,     2,     2,     2,     2,     2,     2,
       2,     2,     2,     2,     2,     2,     2,     2,     2,     2,
       2,     2,     2,     2,     2,     2,     2,     2,     2,     2,
       2,     2,     2,     2,     2,     2,     2,     2,     2,     2,
       2,     2,     2,     2,     2,     2,     2,     2,     2,     2,
       2,     2,     2,     2,     2,     2,     2,     2,     2,     2,
       2,     2,     2,     2,     2,     2,     2,     2,     2,     2,
       2,     2,     2,     2,     2,     2,     2,     2,     2,     2,
       2,     2,     2,     2,     2,     2,     2,     2,     2,     2,
       2,     2,     2,     2,     2,     2,     2,     2,     2,     2,
       2,     2,     2,     2,     2,     2,     2,     2,     2,     2,
       2,     2,     2,     2,     2,     2,     2,     2,     2,     2,
       2,     2,     2,     2,     2,     2,     2,     2,     2,     2,
       2,     2,     2,     2,     2,     2,     2,     2,     2,     2,
       2,     2,     2,     2,     2,     2,     2,     2,     2,     2,
       2,     2,     2,     2,     2,     2,     2,     2,     2,     2,
       2,     2,     2,     2,     2,     2,     2,     2,     2,     2,
       2,     2,     2,     2,     2,     2,     2,     2,     2,     2,
       2,     2,     2,     2,     2,     2,     2,     2,     2,     2,
       2,     2,     2,     2,     2,     2,     2,     2,     2,     2,
       2,     2,     2,     2,     2,     2,     2,     2,     2,     2,
       2,     2,     2,     2,     2,     2,     2,     2,     2,     2,
       2,     2,     2,     2,     2,     2,     2,     2,     2,     2,
       2,     2,     2,     2,     2,     2,     2,     2,     2,     2,
       2,     2,     2,     2,     2,     2,     2,     2,     2,     2,
       2,     2,     2,     2,     2,     2,     2,     2,     2,     2,
       2,     2,     2,     2,     2,     2,     2,     2,     2,     2,
       2,     2,     2,     2,     2,     2,     2,     2,     2,     2,
       2,     2,     2,     2,     2,     2,     2,     2,     2,     2,
       2,     2,     2,     2,     2,     2,     2,     2,     2,     2,
       2,     2,     2,     2,     2,     2,     2,     2,     2,     2,
       2,     2,     2,     2,     2,     2,     2,     2,     2,     2,
       2,     2,     2,     2,     2,     2,     2,     2,     2,     2,
       2,     2,     2,     2,     2,     2,     2,     2,     2,     2,
       2,     2,     2,     2,     2,     2,     2,     2,     2,     2,
       2,     2,     2,     2,     2,     2,     2,     2,     2,     2,
       2,     2,     2,     2,     2,     2,     2,     2,     2,     2,
       2,     2,     2,     2,     2,     2,     2,     2,     2,     2,
       2,     2,     2,     2,     2,     2,     2,     2,     2,     2,
       2,     2,     2,     2,     2,     2,     2,     2,     2,     2,
       2,     2,     2,     2,     2,     2,     2,     2,     2,     2,
       2,     2,     2,     2,     2,     2,     2,     2,     2,     2,
       2,     2,     2,     2,     2,     2,     2,     2,     2,     2,
       2,     2,     2,     2,     2,     2,     2,     2,     2,     2,
       2,     2,     2,     2,     2,     2,     2,     2,     2,     2,
       2,     2,     2,     2,     2,     2,     2,     2,     2,     2,
       2,     2,     2,     2,     2,     2,     2,     2,     2,     2,
       2,     2,     2,     2,     2,     2,     2,     2,     2,     2,
       2,     2,     2,     2,     2,     2,     2,     2,     2,     2,
       2,     2,     2,     2,     2,     2,     2,     2,     2,     2,
       2,     2,     2,     2,     2,     2,     2,     2,     2,     2,
       2,     2,     2,     2,     2,     2,     2,     2,     2,     2,
       2,     2,     2,     2,     2,     2,     2,     2,     2,     2,
       2,     2,     2,     2,     2,     2,     2,     2,     2,     2,
       2,     2,     2,     2,     2,     2,     2,     2,     2,     2,
       2,     2,     2,     2,     2,     2,     2,     2,     2,     2,
       2,     2,     2,     2,     2,     2,     2,     2,     2,     2,
       2,     2,     2,     2,     2,     2,     2,     2,     2,     2,
       2,     2,     2,     2,     2,     2,     2,     2,     2,     2,
       2,     2,     2,     2,     2,     2,     2,     2,     2,     2,
       2,     2,     2,     2,     2,     2,     2,     2,     2,     2,
       2,     2,     2,     2,     2,     2,     2,     2,     2,     2,
       2,     2,     2,     2,     2,     2,     2,     2,     2,     2,
       2,     2,     2,     2,     2,     2,     2,     2,     2,     2,
       2,     2,     2,     2,     2,     2,     2,     2,     2,     2,
       2,     2,     2,     2,     2,     2,     2,     2,     2,     2,
       2,     2,     2,     2,     2,     2,     2,     2,     2,     2,
       2,     2,     2,     2,     2,     2,     2,     2,     2,     2,
       2,     2,     2,     2,     2,     2,     2,     2,     2,     2,
       2,     2,     2,     2,     2,     2,     2,     2,     2,     2,
       2,     2,     2,     2,     2,     2,     2,     2,     2,     2,
       2,     2,     2,     2,     2,     2,     2,     2,     2,     2,
       2,     2,     2,     2,     2,     2,     2,     2,     2,     2,
       2,     2,     2,     2,     2,     2,     2,     2,     2,     2,
       2,     2,     2,     2,     2,     2,     2,     2,     2,     2,
       2,     2,     2,     2,     2,     2,     2,     2,     2,     2,
       2,     2,     2,     2,     2,     2,     2,     2,     2,     2,
       2,     2,     2,     2,     2,     2,     2,     2,     2,     2,
       2,     2,     2,     2,     2,     2,     2,     2,     2,     2,
       2,     2,     2,     2,     2,     2,     2,     2,     2,     2,
       2,     2,     2,     2,     2,     2,     2,     2,     2,     2,
       2,     2,     2,     2,     2,     2,     2,     2,     2,     2,
       2,     2,     2,     2,     2,     2,     2,     2,     2,     2,
       2,     2,     2,     2,     2,     2,     2,     2,     2,     2,
       2,     2,     2,     2,     2,     2,     2,     2,     2,     2,
       2,     2,     2,     2,     2,     2,     2,     2,     2,     2,
       2,     2,     2,     2,     2,     2,     2,     2,     2,     2,
       2,     2,     2,     2,     2,     2,     2,     2,     2,     2,
       2,     2,     2,     2,     2,     2,     2,     2,     2,     2,
       2,     2,     2,     2,     2,     2,     2,     2,     2,     2,
       2,     2,     2,     2,     2,     2,     2,     2,     2,     2,
       2,     2,     2,     2,     2,     2,     2,     2,     2,     2,
       2,     2,     2,     2,     2,     2,     2,     2,     2,     2,
       2,     2,     2,     2,     2,     2,     2,     2,     2,     2,
       2,     2,     2,     2,     2,     2,     2,     2,     2,     2,
       2,     2,     2,     2,     2,     2,     2,     2,     2,     2,
       2,     2,     2,     2,     2,     2,     2,     2,     2,     2,
       2,     2,     2,     2,     2,     2,     2,     2,     2,     2,
       2,     2,     2,     2,     2,     2,     2,     2,     2,     2,
       2,     2,     2,     2,     2,     2,     2,     2,     2,     2,
       2,     2,     2,     2,     2,     2,     2,     2,     2,     2,
       2,     2,     2,     2,     2,     2,     2,     2,     2,     2,
       2,     2,     2,     2,     2,     2,     2,     2,     2,     2,
       2,     2,     2,     2,     2,     2,     2,     2,     2,     2,
       2,     2,     2,     2,     2,     2,     2,     2,     2,     2,
       2,     2,     2,     2,     2,     2,     2,     2,     2,     2,
       2,     2,     2,     2,     2,     2,     2,     2,     2,     2,
       2,     2,     2,     2,     2,     2,     2,     2,     2,     2,
       2,     2,     2,     2,     2,     2,     2,     2,     2,     2,
       2,     2,     2,     2,     2,     2,     2,     2,     2,     2,
       2,     2,     2,     2,     2,     2,     2,     2,     2,     2,
       2,     2,     2,     2,     2,     2,     2,     2,     2,     2,
       2,     2,     2,     2,     2,     2,     2,     2,     2,     2,
       2,     2,     2,     2,     2,     2,     2,     2,     2,     2,
       2,     2,     2,     2,     2,     2,     2,     2,     2,     2,
       2,     2,     2,     2,     2,     2,     2,     2,     2,     2,
       2,     2,     2,     2,     2,     2,     2,     2,     2,     2,
       2,     2,     2,     2,     2,     2,     2,     2,     2,     2,
       2,     2,     2,     2,     2,     2,     2,     2,     2,     2,
       2,     2,     2,     2,     2,     2,     2,     2,     2,     2,
       2,     2,     2,     2,     2,     2,     2,     2,     2,     2,
       2,     2,     2,     2,     2,     2,     2,     2,     2,     2,
       2,     2,     2,     2,     2,     2,     2,     2,     2,     2,
       2,     2,     2,     2,     2,     2,     2,     2,     2,     2,
       2,     2,     2,     2,     2,     2,     2,     2,     2,     2,
       2,     2,     2,     2,     2,     2,     2,     2,     2,     2,
       2,     2,     2,     2,     2,     2,     2,     2,     2,     2,
       2,     2,     2,     2,     2,     2,     2,     2,     2,     2,
       2,     2,     2,     2,     2,     2,     2,     2,     2,     2,
       2,     2,     2,     2,     2,     2,     2,     2,     2,     2,
       2,     2,     2,     2,     2,     2,     2,     2,     2,     2,
       2,     2,     2,     2,     2,     2,     2,     2,     2,     2,
       2,     2,     2,     2,     2,     2,     2,     2,     2,     2,
       2,     2,     2,     2,     2,     2,     2,     2,     2,     2,
       2,     2,     2,     2,     2,     2,     2,     2,     2,     2,
       2,     2,     2,     2,     2,     2,     2,     2,     2,     2,
       2,     2,     2,     2,     2,     2,     2,     2,     2,     2,
       2,     2,     2,     2,     2,     2,     2,     2,     2,     2,
       2,     2,     2,     2,     2,     2,     2,     2,     2,     2,
       2,     2,     2,     2,     2,     2,     2,     2,     2,     2,
       2,     2,     2,     2,     2,     2,     2,     2,     2,     2,
       2,     2,     2,     2,     2,     2,     2,     2,     2,     2,
       2,     2,     2,     2,     2,     2,     2,     2,     2,     2,
       2,     2,     2,     2,     2,     2,     2,     2,     2,     2,
       2,     2,     2,     2,     2,     2,     2,     2,     2,     2,
       2,     2,     2,     2,     2,     2,     2,     2,     2,     2,
       2,     2,     2,     2,     2,     2,     2,     2,     2,     2,
       2,     2,     2,     2,     2,     2,     2,     2,     2,     2,
       2,     2,     2,     2,     2,     2,     2,     2,     2,     2,
       2,     2,     2,     2,     2,     2,     2,     2,     2,     2,
       2,     2,     2,     2,     2,     2,     2,     2,     2,     2,
       2,     2,     2,     2,     2,     2,     2,     2,     2,     2,
       2,     2,     2,     2,     2,     2,     2,     2,     2,     2,
       2,     2,     2,     2,     2,     2,     2,     2,     2,     2,
       2,     2,     2,     2,     2,     2,     2,     2,     2,     2,
       2,     2,     2,     2,     2,     2,     2,     2,     2,     2,
       2,     2,     2,     2,     2,     2,     2,     2,     2,     2,
       2,     2,     2,     2,     2,     2,     2,     2,     2,     2,
       2,     2,     2,     2,     2,     2,     2,     2,     2,     2,
       2,     2,     2,     2,     2,     2,     2,     2,     2,     2,
       2,     2,     2,     2,     2,     2,     2,     2,     2,     2,
       2,     2,     2,     2,     2,     2,     2,     2,     2,     2,
       2,     2,     2,     2,     2,     2,     2,     2,     2,     2,
       2,     2,     2,     2,     2,     2,     2,     2,     2,     2,
       2,     2,     2,     2,     2,     2,     2,     2,     2,     2,
       2,     2,     2,     2,     2,     2,     2,     2,     2,     2,
       2,     2,     2,     2,     2,     2,     2,     2,     2,     2,
       2,     2,     2,     2,     2,     2,     2,     2,     2,     2,
       2,     2,     2,     2,     2,     2,     2,     2,     2,     2,
       2,     2,     2,     2,     2,     2,     2,     2,     2,     2,
       2,     2,     2,     2,     2,     2,     2,     2,     2,     2,
       2,     2,     2,     2,     2,     2,     2,     2,     2,     2,
       2,     2,     2,     2,     2,     2,     2,     2,     2,     2,
       2,     2,     2,     2,     2,     2,     2,     2,     2,     2,
       2,     2,     2,     2,     2,     2,     2,     2,     2,     2,
       2,     2,     2,     2,     2,     2,     2,     2,     2,     2,
       2,     2,     2,     2,     2,     2,     2,     2,     2,     2,
       2,     2,     2,     2,     2,     2,     2,     2,     2,     2,
       2,     2,     2,     2,     2,     2,     2,     2,     2,     2,
       2,     2,     2,     2,     2,     2,     2,     2,     2,     2,
       2,     2,     2,     2,     2,     2,     2,     2,     2,     2,
       2,     2,     2,     2,     2,     2,     2,     2,     2,     2,
       2,     2,     2,     2,     2,     2,     2,     2,     2,     2,
       2,     2,     2,     2,     2,     2,     2,     2,     2,     2,
       2,     2,     2,     2,     2,     2,     2,     2,     2,     2,
       2,     2,     2,     2,     2,     2,     2,     2,     2,     2,
       2,     2,     2,     2,     2,     2,     2,     2,     2,     2,
       2,     2,     2,     2,     2,     2,     2,     2,     2,     2,
       2,     2,     2,     2,     2,     2,     2,     2,     2,     2,
       2,     2,     2,     2,     2,     2,     2,     2,     2,     2,
       2,     2,     2,     2,     2,     2,     2,     2,     2,     2,
       2,     2,     2,     2,     2,     2,     2,     2,     2,     2,
       2,     2,     2,     2,     2,     2,     2,     2,     2,     2,
       2,     2,     2,     2,     2,     2,     2,     2,     2,     2,
       2,     2,     2,     2,     2,     2,     2,     2,     2,     2,
       2,     2,     2,     2,     2,     2,     2,     2,     2,     2,
       2,     2,     2,     2,     2,     2,     2,     2,     2,     2,
       2,     2,     2,     2,     2,     2,     2,     2,     2,     2,
       2,     2,     2,     2,     2,     2,     2,     2,     2,     2,
       2,     2,     2,     2,     2,     2,     2,     2,     2,     2,
       2,     2,     2,     2,     2,     2,     2,     2,     2,     2,
       2,     2,     2,     2,     2,     2,     2,     2,     2,     2,
       2,     2,     2,     2,     2,     2,     2,     2,     2,     2,
       2,     2,     2,     2,     2,     2,     2,     2,     2,     2,
       2,     2,     2,     2,     2,     2,     2,     2,     2,     2,
       2,     2,     2,     2,     2,     2,     2,     2,     2,     2,
       2,     2,     2,     2,     2,     2,     2,     2,     2,     2,
       2,     2,     2,     2,     2,     2,     2,     2,     2,     2,
       2,     2,     2,     2,     2,     2,     2,     2,     2,     2,
       2,     2,     2,     2,     2,     2,     2,     2,     2,     2,
       2,     2,     2,     2,     2,     2,     2,     2,     2,     2,
       2,     2,     2,     2,     2,     2,     2,     2,     2,     2,
       2,     2,     2,     2,     2,     2,     2,     2,     2,     2,
       2,     2,     2,     2,     2,     2,     2,     2,     2,     2,
       2,     2,     2,     2,     2,     2,     2,     2,     2,     2,
       2,     2,     2,     2,     2,     2,     2,     2,     2,     2,
       2,     2,     2,     2,     2,     2,     2,     2,     2,     2,
       2,     2,     2,     2,     2,     2,     2,     2,     2,     2,
       2,     2,     2,     2,     2,     2,     2,     2,     2,     2,
       2,     2,     2,     2,     2,     2,     2,     2,     2,     2,
       2,     2,     2,     2,     2,     2,     2,     2,     2,     2,
       2,     2,     2,     2,     2,     2,     2,     2,     2,     2,
       2,     2,     2,     2,     2,     2,     2,     2,     2,     2,
       2,     2,     2,     2,     2,     2,     2,     2,     2,     2,
       2,     2,     2,     2,     2,     2,     2,     2,     2,     2,
       2,     2,     2,     2,     2,     2,     2,     2,     2,     2,
       2,     2,     2,     2,     2,     2,     2,     2,     2,     2,
       2,     2,     2,     2,     2,     2,     2,     2,     2,     2,
       2,     2,     2,     2,     2,     2,     2,     2,     2,     2,
       2,     2,     2,     2,     2,     2,     2,     2,     2,     2,
       2,     2,     2,     2,     2,     2,     2,     2,     2,     2,
       2,     2,     2,     2,     2,     2,     2,     2,     2,     2,
       2,     2,     2,     2,     2,     2,     2,     2,     2,     2,
       2,     2,     2,     2,     2,     2,     2,     2,     2,     2,
       2,     2,     2,     2,     2,     2,     2,     2,     2,     2,
       2,     2,     2,     2,     2,     2,     2,     2,     2,     2,
       2,     2,     2,     2,     2,     2,     2,     2,     2,     2,
       2,     2,     2,     2,     2,     2,     2,     2,     2,     2,
       2,     2,     2,     2,     2,     2,     2,     2,     2,     2,
       2,     2,     2,     2,     2,     2,     2,     2,     2,     2,
       2,     2,     2,     2,     2,     2,     2,     2,     2,     2,
       2,     2,     2,     2,     2,     2,     2,     2,     2,     2,
       2,     2,     2,     2,     2,     2,     2,     2,     2,     2,
       2,     2,     2,     2,     2,     2,     2,     2,     2,     2,
       2,     2,     2,     2,     2,     2,     2,     2,     2,     2,
       2,     2,     2,     2,     2,     2,     2,     2,     2,     2,
       2,     2,     2,     2,     2,     2,     2,     2,     2,     2,
       2,     2,     2,     2,     2,     2,     2,     2,     2,     2,
       2,     2,     2,     2,     2,     2,     2,     2,     2,     2,
       2,     2,     2,     2,     2,     2,     2,     2,     2,     2,
       2,     2,     2,     2,     2,     2,     2,     2,     2,     2,
       2,     2,     2,     2,     2,     2,     2,     2,     2,     2,
       2,     2,     2,     2,     2,     2,     2,     2,     2,     2,
       2,     2,     2,     2,     2,     2,     2,     2,     2,     2,
       2,     2,     2,     2,     2,     2,     2,     2,     2,     2,
       2,     2,     2,     2,     2,     2,     2,     2,     2,     2,
       2,     2,     2,     2,     2,     2,     2,     2,     2,     2,
       2,     2,     2,     2,     2,     2,     2,     2,     2,     2,
       2,     2,     2,     2,     2,     2,     2,     2,     2,     2,
       2,     2,     2,     2,     2,     2,     2,     2,     2,     2,
       2,     2,     2,     2,     2,     2,     2,     2,     2,     2,
       2,     2,     2,     2,     2,     2,     2,     2,     2,     2,
       2,     2,     2,     2,     2,     2,     2,     2,     2,     2,
       2,     2,     2,     2,     2,     2,     2,     2,     2,     2,
       2,     2,     2,     2,     2,     2,     2,     2,     2,     2,
       2,     2,     2,     2,     2,     2,     2,     2,     2,     2,
       2,     2,     2,     2,     2,     2,     2,     2,     2,     2,
       2,     2,     2,     2,     2,     2,     2,     2,     2,     2,
       2,     2,     2,     2,     2,     2,     2,     2,     2,     2,
       2,     2,     2,     2,     2,     2,     2,     2,     2,     2,
       2,     2,     2,     2,     2,     2,     2,     2,     2,     2,
       2,     2,     2,     2,     2,     2,     2,     2,     2,     2,
       2,     2,     2,     2,     2,     2,     2,     2,     2,     2,
       2,     2,     2,     2,     2,     2,     2,     2,     2,     2,
       2,     2,     2,     2,     2,     2,     2,     2,     2,     2,
       2,     2,     2,     2,     2,     2,     2,     2,     2,     2,
       2,     2,     2,     2,     2,     2,     2,     2,     2,     2,
       2,     2,     2,     2,     2,     2,     2,     2,     2,     2,
       2,     2,     2,     2,     2,     2,     2,     2,     2,     2,
       2,     2,     2,     2,     2,     2,     2,     2,     2,     2,
       2,     2,     2,     2,     2,     2,     2,     2,     2,     2,
       2,     2,     2,     2,     2,     2,     2,     2,     2,     2,
       2,     2,     2,     2,     2,     2,     2,     2,     2,     2,
       2,     2,     2,     2,     2,     2,     2,     2,     2,     2,
       2,     2,     2,     2,     2,     2,     2,     2,     2,     2,
       2,     2,     2,     2,     2,     2,     2,     2,     2,     2,
       2,     2,     2,     2,     2,     2,     2,     2,     2,     2,
       2,     2,     2,     2,     2,     2,     2,     2,     2,     2,
       2,     2,     2,     2,     2,     2,     2,     2,     2,     2,
       2,     2,     2,     2,     2,     2,     2,     2,     2,     2,
       2,     2,     2,     2,     2,     2,     2,     2,     2,     2,
       2,     2,     2,     2,     2,     2,     2,     2,     2,     2,
       2,     2,     2,     2,     2,     2,     2,     2,     2,     2,
       2,     2,     2,     2,     2,     2,     2,     2,     2,     2,
       2,     2,     2,     2,     2,     2,     2,     2,     2,     2,
       2,     2,     2,     2,     2,     2,     2,     2,     2,     2,
       2,     2,     2,     2,     2,     2,     2,     2,     2,     2,
       2,     2,     2,     2,     2,     2,     2,     2,     2,     2,
       2,     2,     2,     2,     2,     2,     2,     2,     2,     2,
       2,     2,     2,     2,     2,     2,     2,     2,     2,     2,
       2,     2,     2,     2,     2,     2,     2,     2,     2,     2,
       2,     2,     2,     2,     2,     2,     2,     2,     2,     2,
       2,     2,     2,     2,     2,     2,     2,     2,     2,     2,
       2,     2,     2,     2,     2,     2,     2,     2,     2,     2,
       2,     2,     2,     2,     2,     2,     2,     2,     2,     2,
       2,     2,     2,     2,     2,     2,     2,     2,     2,     2,
       2,     2,     2,     2,     2,     2,     2,     2,     2,     2,
       2,     2,     2,     2,     2,     2,     2,     2,     2,     2,
       2,     2,     2,     2,     2,     2,     2,     2,     2,     2,
       2,     2,     2,     2,     2,     2,     2,     2,     2,     2,
       2,     2,     2,     2,     2,     2,     2,     2,     2,     2,
       2,     2,     2,     2,     2,     2,     2,     2,     2,     2,
       2,     2,     2,     2,     2,     2,     2,     2,     2,     2,
       2,     2,     2,     2,     2,     2,     2,     2,     2,     2,
       2,     2,     2,     2,     2,     2,     2,     2,     2,     2,
       2,     2,     2,     2,     2,     2,     2,     2,     2,     2,
       2,     2,     2,     2,     2,     2,     2,     2,     2,     2,
       2,     2,     2,     2,     2,     2,     2,     2,     2,     2,
       2,     2,     2,     2,     2,     2,     2,     2,     2,     2,
       2,     2,     2,     2,     2,     2,     2,     2,     2,     2,
       2,     2,     2,     2,     2,     2,     2,     2,     2,     2,
       2,     2,     2,     2,     2,     2,     2,     2,     2,     2,
       2,     2,     2,     2,     2,     2,     2,     2,     2,     2,
       2,     2,     2,     2,     2,     2,     2,     2,     2,     2,
       2,     2,     2,     2,     2,     2,     2,     2,     2,     2,
       2,     2,     2,     2,     2,     2,     2,     2,     2,     2,
       2,     2,     2,     2,     2,     2,     2,     2,     2,     2,
       2,     2,     2,     2,     2,     2,     2,     2,     2,     2,
       2,     2,     2,     2,     2,     2,     2,     2,     2,     2,
       2,     2,     2,     2,     2,     2,     2,     2,     2,     2,
       2,     2,     2,     2,     2,     2,     2,     2,     2,     2,
       2,     2,     2,     2,     2,     2,     2,     2,     2,     2,
       2,     2,     2,     2,     2,     2,     2,     2,     2,     2,
       2,     2,     2,     2,     2,     2,     2,     2,     2,     2,
       2,     2,     2,     2,     2,     2,     2,     2,     2,     2,
       2,     2,     2,     2,     2,     2,     2,     2,     2,     2,
       2,     2,     2,     2,     2,     2,     2,     2,     2,     2,
       2,     2,     2,     2,     2,     2,     2,     2,     2,     2,
       2,     2,     2,     2,     2,     2,     2,     2,     2,     2,
       2,     2,     2,     2,     2,     2,     2,     2,     2,     2,
       2,     2,     2,     2,     2,     2,     2,     2,     2,     2,
       2,     2,     2,     2,     2,     2,     2,     2,     2,     2,
       2,     2,     2,     2,     2,     2,     2,     2,     2,     2,
       2,     2,     2,     2,     2,     2,     2,     2,     2,     2,
       2,     2,     2,     2,     2,     2,     2,     2,     2,     2,
       2,     2,     2,     2,     2,     2,     2,     2,     2,     2,
       2,     2,     2,     2,     2,     2,     2,     2,     2,     2,
       2,     2,     2,     2,     2,     2,     2,     2,     2,     2,
       2,     2,     2,     2,     2,     2,     2,     2,     2,     2,
       2,     2,     2,     2,     2,     2,     2,     2,     2,     2,
       2,     2,     2,     2,     2,     2,     2,     2,     2,     2,
       2,     2,     2,     2,     2,     2,     2,     2,     2,     2,
       2,     2,     2,     2,     2,     2,     2,     2,     2,     2,
       2,     2,     2,     2,     2,     2,     2,     2,     2,     2,
       2,     2,     2,     2,     2,     2,     2,     2,     2,     2,
       2,     2,     2,     2,     2,     2,     2,     2,     2,     2,
       2,     2,     2,     2,     2,     2,     2,     2,     2,     2,
       2,     2,     2,     2,     2,     2,     2,     2,     2,     2,
       2,     2,     2,     2,     2,     2,     2,     2,     2,     2,
       2,     2,     2,     2,     2,     2,     2,     2,     2,     2,
       2,     2,     2,     2,     2,     2,     2,     2,     2,     2,
       2,     2,     2,     2,     2,     2,     2,     2,     2,     2,
       2,     2,     2,     2,     2,     2,     2,     2,     2,     2,
       2,     2,     2,     2,     2,     2,     2,     2,     2,     2,
       2,     2,     2,     2,     2,     2,     2,     2,     2,     2,
       2,     2,     2,     2,     2,     2,     2,     2,     2,     2,
       2,     2,     2,     2,     2,     2,     2,     2,     2,     2,
       2,     2,     2,     2,     2,     2,     2,     2,     2,     2,
       2,     2,     2,     2,     2,     2,     2,     2,     2,     2,
       2,     2,     2,     2,     2,     2,     2,     2,     2,     2,
       2,     2,     2,     2,     2,     2,     2,     2,     2,     2,
       2,     2,     2,     2,     2,     2,     2,     2,     2,     2,
       2,     2,     2,     2,     2,     2,     2,     2,     2,     2,
       2,     2,     2,     2,     2,     2,     2,     2,     2,     2,
       2,     2,     2,     2,     2,     2,     2,     2,     2,     2,
       2,     2,     2,     2,     2,     2,     2,     2,     2,     2,
       2,     2,     2,     2,     2,     2,     2,     2,     2,     2,
       2,     2,     2,     2,     2,     2,     2,     2,     2,     2,
       2,     2,     2,     2,     2,     2,     2,     2,     2,     2,
       2,     2,     2,     2,     2,     2,     2,     2,     2,     2,
       2,     2,     2,     2,     2,     2,     2,     2,     2,     2,
       2,     2,     2,     2,     2,     2,     2,     2,     2,     2,
       2,     2,     2,     2,     2,     2,     2,     2,     2,     2,
       2,     2,     2,     2,     2,     2,     2,     2,     2,     2,
       2,     2,     2,     2,     2,     2,     2,     2,     2,     2,
       2,     2,     2,     2,     2,     2,     2,     2,     2,     2,
       2,     2,     2,     2,     2,     2,     2,     2,     2,     2,
       2,     2,     2,     2,     2,     2,     2,     2,     2,     2,
       2,     2,     2,     2,     2,     2,     2,     2,     2,     2,
       2,     2,     2,     2,     2,     2,     2,     2,     2,     2,
       2,     2,     2,     2,     2,     2,     2,     2,     2,     2,
       2,     2,     2,     2,     2,     2,     2,     2,     2,     2,
       2,     2,     2,     2,     2,     2,     2,     2,     2,     2,
       2,     2,     2,     2,     2,     2,     2,     2,     2,     2,
       2,     2,     2,     2,     2,     2,     2,     2,     2,     2,
       2,     2,     2,     2,     2,     2,     2,     2,     2,     2,
       2,     2,     2,     2,     2,     2,     2,     2,     2,     2,
       2,     2,     2,     2,     2,     2,     2,     2,     2,     2,
       2,     2,     2,     2,     2,     2,     2,     2,     2,     2,
       2,     2,     2,     2,     2,     2,     2,     2,     2,     2,
       2,     2,     2,     2,     2,     2,     2,     2,     2,     2,
       2,     2,     2,     2,     2,     2,     2,     2,     2,     2,
       2,     2,     2,     2,     2,     2,     2,     2,     2,     2,
       2,     2,     2,     2,     2,     2,     2,     2,     2,     2,
       2,     2,     2,     2,     2,     2,     2,     2,     2,     2,
       2,     2,     2,     2,     2,     2,     2,     2,     2,     2,
       2,     2,     2,     2,     2,     2,     2,     2,     2,     2,
       2,     2,     2,     2,     2,     2,     2,     2,     2,     2,
       2,     2,     2,     2,     2,     2,     2,     2,     2,     2,
       2,     2,     2,     2,     2,     2,     2,     2,     2,     2,
       2,     2,     2,     2,     2,     2,     2,     2,     2,     2,
       2,     2,     2,     2,     2,     2,     2,     2,     2,     2,
       2,     2,     2,     2,     2,     2,     2,     2,     2,     2,
       2,     2,     2,     2,     2,     2,     2,     2,     2,     2,
       2,     2,     2,     2,     2,     2,     2,     2,     2,     2,
       2,     2,     2,     2,     2,     2,     2,     2,     2,     2,
       2,     2,     2,     2,     2,     2,     2,     2,     2,     2,
       2,     2,     2,     2,     2,     2,     2,     2,     2,     2,
       2,     2,     2,     2,     2,     2,     2,     2,     2,     2,
       2,     2,     2,     2,     2,     2,     2,     2,     2,     2,
       2,     2,     2,     2,     2,     2,     2,     2,     2,     2,
       2,     2,     2,     2,     2,     2,     2,     2,     2,     2,
       2,     2,     2,     2,     2,     2,     2,     2,     2,     2,
       2,     2,     2,     2,     2,     2,     2,     2,     2,     2,
       2,     2,     2,     2,     2,     2,     2,     2,     2,     2,
       2,     2,     2,     2,     2,     2,     2,     2,     2,     2,
       2,     2,     2,     2,     2,     2,     2,     2,     2,     2,
       2,     2,     2,     2,     2,     2,     2,     2,     2,     2,
       2,     2,     2,     2,     2,     2,     2,     2,     2,     2,
       2,     2,     2,     2,     2,     2,     2,     2,     2,     2,
       2,     2,     2,     2,     2,     2,     2,     2,     2,     2,
       2,     2,     2,     2,     2,     2,     2,     2,     2,     2,
       2,     2,     2,     2,     2,     2,     2,     2,     2,     2,
       2,     2,     2,     2,     2,     2,     2,     2,     2,     2,
       2,     2,     2,     2,     2,     2,     2,     2,     2,     2,
       2,     2,     2,     2,     2,     2,     2,     2,     2,     2,
       2,     2,     2,     2,     2,     2,     2,     2,     2,     2,
       2,     2,     2,     2,     2,     2,     2,     2,     2,     2,
       2,     2,     2,     2,     2,     2,     2,     2,     2,     2,
       2,     2,     2,     2,     2,     2,     2,     2,     2,     2,
       2,     2,     2,     2,     2,     2,     2,     2,     2,     2,
       2,     2,     2,     2,     2,     2,     2,     2,     2,     2,
       2,     2,     2,     2,     2,     2,     2,     2,     2,     2,
       2,     2,     2,     2,     2,     2,     2,     2,     2,     2,
       2,     2,     2,     2,     2,     2,     2,     2,     2,     2,
       2,     2,     2,     2,     2,     2,     2,     2,     2,     2,
       2,     2,     2,     2,     2,     2,     2,     2,     2,     2,
       2,     2,     2,     2,     2,     2,     2,     2,     2,     2,
       2,     2,     2,     2,     2,     2,     2,     2,     2,     2,
       2,     2,     2,     2,     2,     2,     2,     2,     2,     2,
       2,     2,     2,     2,     2,     2,     2,     2,     2,     2,
       2,     2,     2,     2,     2,     2,     2,     2,     2,     2,
       2,     2,     2,     2,     2,     2,     2,     2,     2,     2,
       2,     2,     2,     2,     2,     2,     2,     2,     2,     2,
       2,     2,     2,     2,     2,     2,     2,     2,     2,     2,
       2,     2,     2,     2,     2,     2,     2,     2,     2,     2,
       2,     2,     2,     2,     2,     2,     2,     2,     2,     2,
       2,     2,     2,     2,     2,     2,     2,     2,     2,     2,
       2,     2,     2,     2,     2,     2,     2,     2,     2,     2,
       2,     2,     2,     2,     2,     2,     2,     2,     2,     2,
       2,     2,     2,     2,     2,     2,     2,     2,     2,     2,
       2,     2,     2,     2,     2,     2,     2,     2,     2,     2,
       2,     2,     2,     2,     2,     2,     2,     2,     2,     2,
       2,     2,     2,     2,     2,     2,     2,     2,     2,     2,
       2,     2,     2,     2,     2,     2,     2,     2,     2,     2,
       2,     2,     2,     2,     2,     2,     2,     2,     2,     2,
       2,     2,     2,     2,     2,     2,     2,     2,     2,     2,
       2,     2,     2,     2,     2,     2,     2,     2,     2,     2,
       2,     2,     2,     2,     2,     2,     2,     2,     2,     2,
       2,     2,     2,     2,     2,     2,     2,     2,     2,     2,
       2,     2,     2,     2,     2,     2,     2,     2,     2,     2,
       2,     2,     2,     2,     2,     2,     2,     2,     2,     2,
       2,     2,     2,     2,     2,     2,     2,     2,     2,     2,
       2,     2,     2,     2,     2,     2,     2,     2,     2,     2,
       2,     2,     2,     2,     2,     2,     2,     2,     2,     2,
       2,     2,     2,     2,     2,     2,     2,     2,     2,     2,
       2,     2,     2,     2,     2,     2,     2,     2,     2,     2,
       2,     2,     2,     2,     2,     2,     2,     2,     2,     2,
       2,     2,     2,     2,     2,     2,     2,     2,     2,     2,
      27,     2,     2,     2,     2,     2,     2,     2,     2,     2,
      30,     2,     2,     2,     2,     2,     2,     2,     2,     2,
      31,     2,     2,     2,     2,     2,     2,     2,     2,     2,
      32,    33,    34,    35,    36,    37,     2,     2,     2,     2,
      38,    39,    40,    41,    42,    43,    44,    45,     2,    54,
      46,     2,     2,     2,     2,     2,     2,     2,     2,     2,
      47,     2,     2,     2,     2,     2,     2,     2,     2,     2,
       2,     2,     2,     2,     2,     2,     2,     2,     2,     2,
       2,     2,     2,     2,     2,     2,     2,     2,     2,     2,
       2,     2,     2,     2,     2,     2,     2,     2,     2,     2,
       2,     2,     2,     2,     2,     2,     2,     2,     2,     2,
       2,     2,     2,     2,     2,     2,     2,     2,     2,     2,
       2,     2,     2,     2,     2,     2,     2,     2,     2,     2,
       2,     2,     2,     2,     2,     2,     2,     2,     2,     2,
       2,     2,     2,     2,     2,     2,     2,     2,     2,     2,
       2,     2,     2,     2,     2,     2,     2,     2,     2,     2,
       2,     2,     2,     2,     2,     2,     2,     2,     2,     2,
       2,     2,     2,     2,     2,     2,     2,     2,     2,     2,
       2,     2,     2,     2,     2,     2,     2,     2,     2,     2,
       2,     2,     2,     2,     2,     2,     2,     2,     2,     2,
       2,     2,     2,     2,     2,     2,     2,     2,     2,     2,
       2,     2,     2,     2,     2,     2,     2,     2,     2,     2,
       2,     2,     2,     2,     2,     2,     2,     2,     2,     2,
       2,     2,     2,     2,     2,     2,     2,     2,     2,     2,
       2,     2,     2,     2,     2,     2,     2,     2,     2,     2,
       2,     2,     2,     2,     2,     2,     2,     2,     2,     2,
       2,     2,     2,     2,     2,     2,     2,     2,     2,     2,
       2,     2,     2,     2,     2,     2,     2,     2,     2,     2,
       2,     2,     2,     2,     2,     2,     2,     2,     2,     2,
       2,     2,     2,     2,     2,     2,     2,     2,     2,     2,
       2,     2,     2,     2,     2,     2,     2,     2,     2,     2,
       2,     2,     2,     2,     2,     2,     2,     2,     2,     2,
       2,     2,     2,     2,     2,     2,     2,     2,     2,     2,
       2,     2,     2,     2,     2,     2,     2,     2,     2,     2,
       2,     2,     2,     2,     2,     2,     2,     2,     2,     2,
       2,     2,     2,     2,     2,     2,     2,     2,     2,     2,
       2,     2,     2,     2,     2,     2,     2,     2,     2,     2,
       2,     2,     2,     2,     2,     2,     2,     2,     2,     2,
       2,     2,     2,     2,     2,     2,     2,     2,     2,     2,
       2,     2,     2,     2,     2,     2,     2,     2,     2,     2,
       2,     2,     2,     2,     2,     2,     2,     2,     2,     2,
       2,     2,     2,     2,     2,     2,     2,     2,     2,     2,
       2,     2,     2,     2,     2,     2,     2,     2,     2,     2,
       2,     2,     2,     2,     2,     2,     2,     2,     2,     2,
       2,     2,     2,     2,     2,     2,     2,     2,     2,     2,
       2,     2,     2,     2,     2,     2,     2,     2,     2,     2,
       2,     2,     2,     2,     2,     2,     2,     2,     2,     2,
       2,     2,     2,     2,     2,     2,     2,     2,     2,     2,
       2,     2,     2,     2,     2,     2,     2,     2,     2,     2,
       2,     2,     2,     2,     2,     2,     2,     2,     2,     2,
       2,     2,     2,     2,     2,     2,     2,     2,     2,     2,
       2,     2,     2,     2,     2,     2,     2,     2,     2,     2,
       2,     2,     2,     2,     2,     2,     2,     2,     2,     2,
       2,     2,     2,     2,     2,     2,     2,     2,     2,     2,
       2,     2,     2,     2,     2,     2,     2,     2,     2,     2,
       2,     2,     2,     2,     2,     2,     2,     2,     2,     2,
       2,     2,     2,     2,     2,     2,     2,     2,     2,     2,
       2,     2,     2,     2,     2,     2,     2,     2,     2,     2,
       2,     2,     2,     2,     2,     2,     2,     2,     2,     2,
       2,     2,     2,     2,     2,     2,     2,     2,     2,     2,
       2,     2,     2,     2,     2,     2,     2,     2,     2,     2,
       2,     2,     2,     2,     2,     2,     2,     2,     2,     2,
       2,     2,     2,     2,     2,     2,     2,     2,     2,     2,
       2,     2,     2,     2,     2,     2,     2,     2,     2,     2,
       2,     2,     2,     2,     2,     2,     2,     2,     2,     2,
       2,     2,     2,     2,     2,     2,     2,     2,     2,     2,
       2,     2,     2,     2,     2,     2,     2,     2,     2,     2,
       2,     2,     2,     2,     2,     2,     2,     2,     2,     2,
       2,     2,     2,     2,     2,     2,     2,     2,     2,     2,
       2,     2,     2,     2,     2,     2,     2,     2,     2,     2,
       2,     2,     2,     2,     2,     2,     2,     2,     2,     2,
       2,     2,     2,     2,     2,     2,     2,     2,     2,     2,
       2,     2,     2,     2,     2,     2,     2,     2,     2,     2,
       2,     2,     2,     2,     2,     2,     2,     2,     2,     2,
       2,     2,     2,     2,     2,     2,     2,     2,     2,     2,
       2,     2,     2,     2,     2,     2,     2,     2,     2,     2,
       2,     2,     2,     2,     2,     2,     2,     2,     2,     2,
       2,     2,     2,     2,     2,     2,     2,     2,     2,     2,
       2,     2,     2,     2,     2,     2,     2,     2,     2,     2,
       2,     2,     2,     2,     2,     2,     2,     2,     2,     2,
       2,     2,     2,     2,     2,     2,     2,     2,     2,     2,
       2,     2,     2,     2,     2,     2,     2,     2,     2,     2,
       2,     2,     2,     2,     2,     2,     2,     2,     2,     2,
       2,     2,     2,     2,     2,     2,     2,     2,     2,     2,
       2,     2,     2,     2,     2,     2,     2,     2,     2,     2,
       2,     2,     2,     2,     2,     2,     2,     2,     2,     2,
       2,     2,     2,     2,     2,     2,     2,     2,     2,     2,
       2,     2,     2,     2,     2,     2,     2,     2,     2,     2,
       2,     2,     2,     2,     2,     2,     2,     2,     2,     2,
       2,     2,     2,     2,     2,     2,     2,     2,     2,     2,
       2,     2,     2,     2,     2,     2,     2,     2,     2,     2,
       2,     2,     2,     2,     2,     2,     2,     2,     2,     2,
       2,     2,     2,     2,     2,     2,     2,     2,     2,     2,
       2,     2,     2,     2,     2,     2,     2,     2,     2,     2,
       2,     2,     2,     2,     2,     2,     2,     2,     2,     2,
       2,     2,     2,     2,     2,     2,     2,     2,     2,     2,
       2,     2,     2,     2,     2,     2,     2,     2,     2,     2,
       2,     2,     2,     2,     2,     2,     2,     2,     2,     2,
       2,     2,     2,     2,     2,     2,     2,     2,     2,     2,
       2,     2,     2,     2,     2,     2,     2,     2,     2,     2,
      55,    56,    57,    58,    59,    60,    61,    62,    63,    64,
      65,    66,    67,     2,     2,     2,     2,     2,     2,     2,
      68,     2,     2,     2,     2,     2,     2,     2,     2,     2,
       2,     2,     2,     2,     2,     2,     2,     2,     2,     2,
       2,     2,     2,     2,     2,     2,     2,     2,     2,     2,
       2,     2,     2,     2,     2,     2,     2,     2,     2,     2,
      69,     2,     2,     2,     2,     2,     2,     2,     2,     2,
       2,    70,    71,    72,    73,    74,    75,    76,    77,    78,
      79,    80,    81,    82,    83,    84,    85,    86,    87,    88,
      97,    98,    99,   100,   101,   102,   103,   104,     2,     2,
     105,     2,     2,     2,     2,     2,     2,     2,     2,     2,
     106,   107,   108,     2,     2,     2,     2,     2,     2,     2,
     109,   110,     2,     2,     2,     2,     2,     2,     2,     2,
     111,   112,   113,     2,     2,     2,     2,     2,     2,     2,
     114,   115,   116,     2,     2,     2,     2,     2,     2,     2,
     117,   118,   119,     2,     2,     2,     2,     2,     2,     2,
     120,     2,   121,   122,   123,   124,   125,     2,     2,     2,
     126,   127,     2,     2,     2,     2,     2,     2,     2,     2,
     128,   129,   130,     2,     2,   131,   132,   133,     2,     2,
     134,     2,     2,     2,     2,     2,     2,     2,     2,     2,
     135,   136,   137,   138,   139,   140,   141,   142,   143,   144,
     145,   146,   147,     2,     2,   148,   149,   150,     2,     2,
     151,     2,     2,     2,     2,     2,     2,     2,     2,     2,
     152,   153,     2,     2,     2,   154,     2,     2,     2,     2,
     155,     2,     2,     2,     2,     2,     2,     2,     2,     2,
     156,   157,   158,     2,     2,     2,     2,     2,     2,     2,
     159,   160,   161,     2,     2,     2,     2,     2,     2,     2,
     162,   163,   164,     2,     2,     2,     2,     2,     2,     2,
       2,     2,     2,     2,     2,     2,     2,     2,     2,     2,
       2,     2,     2,     2,     2,     2,     2,     2,     2,     2,
     165,   166,   167,     2,     2,     2,     2,     2,     2,     2,
       2,     2,     2,     2,     2,     2,     2,     2,     2,     2,
       2,     2,     2,   168,   169,     2,     2,     2,     2,     2,
       2,     2,     2,     2,     2,     2,     2,     2,     2,     2,
     170,     2,     2,     2,     2,     2,     2,     2,     2,     2,
     171,   172,   173,   174,   175,   176,   177,   178,     2,     2,
       2,     2,     2,     2,     2,     2,     2,     2,     2,     2,
     179,   180,   181,     2,     2,     2,     2,     2,     2,     2,
     182,   183,   184,     2,     2,     2,     2,     2,     2,     2,
       2,     2,     2,     2,     2,     2,     2,     2,     2,     2,
      89,    90,    91,    92,    93,    94,    95,    96,     2,     2,
     185,   186,     2,     2,     2,     2,     2,     2,     2,     2,
     187,   188,   189,   190,   191,   192,     2,     2,     2,     2,
     193,   194,   195,   196,   197,   198,   199,   200,   201,     2,
       2,     2,     2,     2,     2,     2,     2,     2,     2,     2,
       2,     2,     2,     2,     2,     2,     2,     2,     2,     2,
       2,     2,     2,     2,     2,     2,     2,     2,     2,     2,
       2,     2,     2,     2,     2,     2,     2,     2,     2,     2,
       2,     2,     2,     2,     2,     2,     2,     2,     2,     2,
       2,     2,     2,     2,     2,     2,     2,     2,     2,     2,
     202,     2,   203,   204,   205,   206,   207,   208,   209,   210,
     211,   212,   213,   214,   215,     2,     2,     2,     2,     2,
     216,   217,   218,     2,     2,     2,     2,     2,     2,     2,
     219,     2,   220,   221,   222,   223,   224,   225,   226,   227,
     228,   229,   230,   231,   232,   233,   234,   235,   236,   237,
     238,   239,   240,   241,   242,   243,   244,   245,   246,   247,
     248,   249,   250,   251,   252,   253,   254,   255,   256,   257,
     258,   259,   260,   261,   262,   263,   264,   265,   266,   267,
     268,   269,   270,   271
};

#if LOKI_DEBUG
/* YYRLINE[YYN] -- Source line where rule number YYN was defined.  */
static const yytype_int16 yyrline[] =
{
       0,   551,   551,   556,   555,   563,   564,   568,   569,   570,
     575,   576,   580,   581,   585,   868,   875,   884,   892,   900,
     911,   911,   922,   926,   927,   933,   934,   938,   939,   943,
     944,   959,   966,   973,   980,  1009,  1010,  1011,  1020,  1034,
    1088,  1089,  1125,  1153,  1154,  1155,  1156,  1160,  1161,  1165,
    1166,  1171,  1172,  1176,  1180,  1181,  1185,  1189,  1190,  1347,
    1348,  1349,  1350,  1351,  1352,  1353,  1538,  1539,  1540,  1568,
    1569,  1569,  1570,  1571,  1572,  1573,  1574,  1575,  1576,  1577,
    1578,  1579,  1579,  1607,  1608,  1612,  1613,  1614,  1619,  1620,
    1624,  1625,  1629,  1630,  1634,  1643,  1644,  1648,  1652,  1653,
    1654,  1655,  1656,  1657,  1658,  1659,  1660,  1661,  1662,  1663,
    1664,  1665,  1666,  1667,  1668,  1672,  1673,  1674,  1675,  1719,
    1719,  1720,  1720,  1721,  1721,  1722,  1722,  1723,  1723,  1727,
    1728,  1732,  1737,  1742,  1750,  1751,  1755,  1760,  1759,  1765,
    1769,  1770,  1774,  1775
};
#endif

/** Accessing symbol of state STATE.  */
#define YY_ACCESSING_SYMBOL(State) YY_CAST (yysymbol_kind_t, yystos[State])

#if 1
/* The user-facing name of the symbol whose (internal) number is
   YYSYMBOL.  No bounds checking.  */
static const char *yysymbol_name (yysymbol_kind_t yysymbol) YY_ATTRIBUTE_UNUSED;

/* YYTNAME[SYMBOL-NUM] -- String name of the symbol SYMBOL-NUM.
   First, the terminals, then, starting at YYNTOKENS, nonterminals.  */
static const char *const yytname[] =
{
  "\"end of file\"", "error", "\"invalid token\"", "LL_CONTEXT_ROOT",
  "LL_CONTEXT_DESTINATION", "LL_CONTEXT_SOURCE", "LL_CONTEXT_PARSER",
  "LL_CONTEXT_REWRITE", "LL_CONTEXT_FILTER", "LL_CONTEXT_LOG",
  "LL_CONTEXT_BLOCK_DEF", "LL_CONTEXT_BLOCK_REF",
  "LL_CONTEXT_BLOCK_CONTENT", "LL_CONTEXT_BLOCK_ARG",
  "LL_CONTEXT_BLOCK_FUNCARG", "LL_CONTEXT_PRAGMA", "LL_CONTEXT_FORMAT",
  "LL_CONTEXT_TEMPLATE_FUNC", "LL_CONTEXT_INNER_DEST",
  "LL_CONTEXT_INNER_SRC", "LL_CONTEXT_CLIENT_PROTO",
  "LL_CONTEXT_SERVER_PROTO", "LL_CONTEXT_OPTIONS", "LL_CONTEXT_CONFIG",
  "LL_CONTEXT_TEMPLATE_REF", "LL_CONTEXT_MAX", "';'", "KW_ASSIGN", "'?'",
  "':'", "KW_OR", "KW_AND", "KW_STR_EQ", "KW_STR_NE", "KW_TA_EQ",
  "KW_TA_NE", "KW_TAV_EQ", "KW_TAV_NE", "KW_STR_LT", "KW_STR_LE",
  "KW_STR_GE", "KW_STR_GT", "KW_TA_LT", "KW_TA_LE", "KW_TA_GE", "KW_TA_GT",
  "KW_PLUS_ASSIGN", "KW_REGEXP_MATCH", "'+'", "'-'", "'*'", "'.'", "'['",
  "']'", "KW_NOT", "KW_SOURCE", "KW_FILTER", "KW_PARSER", "KW_DESTINATION",
  "KW_LOG", "KW_OPTIONS", "KW_INCLUDE", "KW_BLOCK", "KW_JUNCTION",
  "KW_CHANNEL", "KW_IF", "KW_ELSE", "KW_ELIF", "KW_INTERNAL", "KW_SYSLOG",
  "KW_MARK_FREQ", "KW_STATS_FREQ", "KW_STATS_LEVEL", "KW_STATS_LIFETIME",
  "KW_FLUSH_LINES", "KW_SUPPRESS", "KW_FLUSH_TIMEOUT", "KW_LOG_MSG_SIZE",
  "KW_FILE_TEMPLATE", "KW_PROTO_TEMPLATE", "KW_MARK_MODE", "KW_ENCODING",
  "KW_TYPE", "KW_STATS_MAX_DYNAMIC", "KW_MIN_IW_SIZE_PER_READER",
  "KW_WORKERS", "KW_BATCH_LINES", "KW_BATCH_TIMEOUT",
  "KW_TRIM_LARGE_MESSAGES", "KW_STATS", "KW_FREQ", "KW_LEVEL",
  "KW_LIFETIME", "KW_MAX_DYNAMIC", "KW_SYSLOG_STATS",
  "KW_HEALTHCHECK_FREQ", "KW_WORKER_PARTITION_KEY", "KW_CHAIN_HOSTNAMES",
  "KW_NORMALIZE_HOSTNAMES", "KW_KEEP_HOSTNAME", "KW_CHECK_HOSTNAME",
  "KW_BAD_HOSTNAME", "KW_LOG_LEVEL", "KW_IDLE_TIMEOUT", "KW_CHECK_PROGRAM",
  "KW_KEEP_TIMESTAMP", "KW_USE_DNS", "KW_USE_FQDN", "KW_CUSTOM_DOMAIN",
  "KW_DNS_CACHE", "KW_DNS_CACHE_SIZE", "KW_DNS_CACHE_EXPIRE",
  "KW_DNS_CACHE_EXPIRE_FAILED", "KW_DNS_CACHE_HOSTS", "KW_PERSIST_ONLY",
  "KW_USE_RCPTID", "KW_USE_UNIQID", "KW_TZ_CONVERT", "KW_TS_FORMAT",
  "KW_FRAC_DIGITS", "KW_LOG_FIFO_SIZE", "KW_LOG_FETCH_LIMIT",
  "KW_LOG_IW_SIZE", "KW_LOG_PREFIX", "KW_PROGRAM_OVERRIDE",
  "KW_HOST_OVERRIDE", "KW_THROTTLE", "KW_THREADED",
  "KW_PASS_UNIX_CREDENTIALS", "KW_PERSIST_NAME", "KW_USE_SYSLOGNG_PID",
  "KW_READ_OLD_RECORDS", "KW_IGNORE_SAVED_BOOKMARKS",
  "KW_DISABLE_BOOKMARKS", "KW_FLAGS", "KW_PAD_SIZE", "KW_TIME_ZONE",
  "KW_RECV_TIME_ZONE", "KW_SEND_TIME_ZONE", "KW_LOCAL_TIME_ZONE",
  "KW_FORMAT", "KW_MULTI_LINE_MODE", "KW_MULTI_LINE_PREFIX",
  "KW_MULTI_LINE_GARBAGE", "KW_TRUNCATE_SIZE", "KW_TIME_REOPEN",
  "KW_TIME_REAP", "KW_TIME_SLEEP", "KW_PARALLELIZE", "KW_PARTITIONS",
  "KW_PARTITION_KEY", "KW_TMPL_ESCAPE", "KW_LOG_FETCH_DELAY",
  "KW_LOG_FETCH_RETRY_DELAY", "KW_OPTIONAL", "KW_CREATE_DIRS", "KW_OWNER",
  "KW_GROUP", "KW_PERM", "KW_DIR_OWNER", "KW_DIR_GROUP", "KW_DIR_PERM",
  "KW_TEMPLATE", "KW_TEMPLATE_ESCAPE", "KW_TEMPLATE_FUNCTION",
  "KW_DEFAULT_FACILITY", "KW_DEFAULT_SEVERITY", "KW_SDATA_PREFIX",
  "KW_PORT", "KW_HTTP", "KW_USE_TIME_RECVD", "KW_FACILITY", "KW_SEVERITY",
  "KW_HOST", "KW_MATCH", "KW_MESSAGE", "KW_NETMASK", "KW_TAGS",
  "KW_NETMASK6", "KW_REWRITE", "KW_CONDITION", "KW_VALUE", "KW_YES",
  "KW_NO", "KW_AUTO", "KW_IFDEF", "KW_ENDIF", "LL_DOTDOT", "LL_DOTDOTDOT",
  "LL_PRAGMA", "LL_EOL", "LL_ERROR", "LL_ARROW", "LL_IDENTIFIER",
  "LL_NUMBER", "LL_FLOAT", "LL_STRING", "LL_TOKEN", "LL_BLOCK",
  "LL_PLUGIN", "LL_TEMPLATE_REF", "LL_MESSAGE_REF", "KW_VALUE_PAIRS",
  "KW_EXCLUDE", "KW_PAIR", "KW_KEY", "KW_SCOPE", "KW_SHIFT",
  "KW_SHIFT_LEVELS", "KW_REKEY", "KW_ADD_PREFIX", "KW_REPLACE_PREFIX",
  "KW_CAST", "KW_UPPER", "KW_LOWER", "KW_INCLUDE_BYTES", "KW_ON_ERROR",
  "KW_RETRIES", "KW_FETCH_NO_DATA_DELAY", "KW_LABELS", "KW_AUTH",
  "KW_INSECURE", "KW_TLS", "KW_KEY_FILE", "KW_CERT_FILE", "KW_CA_FILE",
  "KW_PEER_VERIFY", "KW_OPTIONAL_UNTRUSTED", "KW_OPTIONAL_TRUSTED",
  "KW_REQUIRED_UNTRUSTED", "KW_REQUIRED_TRUSTED", "KW_ALTS",
  "KW_TARGET_SERVICE_ACCOUNTS", "KW_URL", "KW_ADC", "KW_SERVICE_ACCOUNT",
  "KW_TOKEN_VALIDITY_DURATION", "KW_COMPRESSION", "KW_BATCH_BYTES",
  "KW_CONCURRENT_REQUESTS", "KW_KEEP_ALIVE", "KW_TIME", "KW_TIMEOUT",
  "KW_MAX_PINGS_WITHOUT_DATA", "KW_CHANNEL_ARGS", "KW_HEADERS",
  "KW_SCHEMA", "KW_PROTOBUF_SCHEMA", "KW_RESPONSE_ACTION", "KW_DISCONNECT",
  "KW_DROP", "KW_RETRY", "KW_SUCCESS", "KW_OK", "KW_UNAVAILABLE",
  "KW_CANCELLED", "KW_DEADLINE_EXCEEDED", "KW_ABORTED", "KW_OUT_OF_RANGE",
  "KW_DATA_LOSS", "KW_UNKNOWN", "KW_INVALID_ARGUMENT", "KW_NOT_FOUND",
  "KW_ALREADY_EXISTS", "KW_PERMISSION_DENIED", "KW_UNAUTHENTICATED",
  "KW_FAILED_PRECONDITION", "KW_UNIMPLEMENTED", "KW_RESOURCE_EXHAUSTED",
  "KW_LOKI", "KW_TIMESTAMP", "KW_TENANT_ID", "'('", "')'", "'{'", "'}'",
  "$accept", "start", "loki_dest", "$@1", "loki_dest_options",
  "loki_dest_option", "loki_labels", "loki_label",
  "template_content_inner", "type_hint", "template_content", "@4",
  "template_name_or_content", "template_name_or_content_tail", "string",
  "yesno_strict", "yesno", "nonnegative_integer64", "nonnegative_integer",
  "positive_integer64", "positive_integer", "string_or_number", "path",
  "path_secret", "driver_option", "inner_dest", "dest_driver_option",
  "threaded_dest_driver_batch_option",
  "threaded_dest_driver_workers_option",
  "threaded_dest_driver_general_option",
  "threaded_dest_driver_general_option_noflags",
  "threaded_dest_driver_flags_option", "threaded_dest_driver_flags",
  "template_option", "_template_ref_context_push",
  "_inner_dest_context_push", "_inner_dest_context_pop",
  "grpc_dest_general_option", "$@19", "$@20", "grpc_keepalive_options",
  "grpc_keepalive_option", "grpc_dest_channel_args",
  "grpc_dest_channel_arg", "grpc_dest_headers", "grpc_dest_header",
  "grpc_dest_response_action_items", "grpc_dest_response_action_item",
  "grpc_dest_response", "grpc_dest_response_action",
  "grpc_client_credentials_option", "$@24", "$@25", "$@26", "$@27", "$@28",
  "grpc_client_credentials_builder_tls_options",
  "grpc_client_credentials_builder_tls_option",
  "grpc_client_credentials_builder_alts_options",
  "grpc_client_credentials_builder_alts_option",
  "grpc_client_credentials_builder_alts_target_service_accounts", "$@29",
  "grpc_client_credentials_builder_service_account_options",
  "grpc_client_credentials_builder_service_account_option", YY_NULLPTR
};

static const char *
yysymbol_name (yysymbol_kind_t yysymbol)
{
  return yytname[yysymbol];
}
#endif

#define YYPACT_NINF (-245)

#define yypact_value_is_default(Yyn) \
  ((Yyn) == YYPACT_NINF)

#define YYTABLE_NINF (-20)

#define yytable_value_is_error(Yyn) \
  0

/* YYPACT[STATE-NUM] -- Index in YYTABLE of the portion describing
   STATE-NUM.  */
static const yytype_int16 yypact[] =
{
      13,  -244,    27,  -245,  -245,  -245,  -237,  -245,   -65,  -222,
    -221,  -218,  -212,  -210,  -209,  -206,  -205,  -196,  -188,  -187,
    -245,  -186,  -185,  -245,  -184,  -183,  -182,  -179,  -173,  -171,
    -170,  -169,  -168,  -245,   -65,  -245,  -245,  -245,  -245,  -245,
    -245,  -245,  -245,  -245,  -110,  -164,  -115,   -89,  -115,  -245,
    -115,   -89,  -180,  -180,  -115,  -245,  -115,  -180,  -165,  -180,
    -164,  -115,  -199,  -180,  -180,   -67,  -180,  -180,  -163,  -245,
    -161,  -160,  -159,  -158,  -157,  -156,  -155,  -245,  -245,  -245,
    -245,  -245,  -154,  -245,  -245,  -153,  -245,  -245,  -152,  -151,
    -150,  -147,  -149,  -148,  -245,  -245,  -146,  -180,  -145,  -144,
    -143,   -92,  -141,  -140,  -180,   -83,  -198,  -138,  -137,  -136,
    -133,  -129,  -128,  -127,  -199,   -74,  -126,  -180,   -66,  -125,
    -180,  -245,  -245,  -245,  -245,  -245,  -245,  -245,  -245,  -245,
    -245,  -245,  -245,  -245,  -245,  -245,  -245,  -245,  -124,   -67,
     -61,  -122,  -120,  -245,  -180,   -89,  -180,  -180,  -180,  -164,
    -180,  -245,  -245,  -245,  -245,  -245,  -114,  -245,  -245,  -245,
    -113,  -245,  -245,  -245,  -245,  -245,  -245,  -245,  -245,  -245,
    -245,  -245,  -245,  -245,  -245,  -245,  -245,  -245,  -245,  -245,
    -245,  -116,  -245,  -245,  -245,   -89,   -89,   -89,  -245,  -245,
    -119,  -245,  -245,  -245,  -245,  -245,  -245,  -245,  -193,  -245,
    -245,  -112,  -111,  -109,  -108,  -107,  -106,  -104,  -123,  -245,
    -102,  -101,   -98,   -96,   -95,  -245,   -91,   -88,   -71,  -245,
    -245,  -245,  -245,  -245,  -245,  -245,  -245,  -245,  -245,  -245,
    -245,  -245,  -245,  -245,  -245,  -245,  -245,   -70,   -69,  -142,
     -87,   -60,  -195,  -245,  -245,  -245,  -245,  -245,   -94,   -57,
     -56,   -55,  -142,   -53,   -51,   -87,  -245,   -49,   -48,   -47,
    -195,  -180,  -180,  -180,  -245,  -245,  -180,  -245,  -245,  -180,
     -89,  -245,  -245,   -46,   -44,   -43,  -245,   -42,  -245,  -245,
     -41,   -39,  -245,  -245,  -245,  -180,  -245,  -245,  -245,  -245
};

/* YYDEFACT[STATE-NUM] -- Default reduction number in state STATE-NUM.
   Performed when YYTABLE does not specify something else to do.  Zero
   means the default is an error.  */
static const yytype_uint8 yydefact[] =
{
       0,     0,     0,     3,     2,     1,     0,    67,    81,     0,
       0,     0,     0,     0,     0,     0,     0,     0,     0,     0,
      42,     0,     0,    70,     0,     0,     0,     0,     0,     0,
       0,     0,     0,    68,    81,    46,    45,    55,    79,    80,
      78,    51,    52,    11,     0,     0,     0,     0,     0,    20,
       0,     0,     0,    58,     0,    66,     0,    13,     0,     0,
       0,     0,    84,    89,    93,    96,     0,     0,     0,     5,
       0,     0,     0,     0,     0,     0,     0,    82,    27,    28,
      30,    29,     0,    33,    34,     0,    31,    32,     0,     0,
       0,     0,     0,     0,    25,    26,     0,    58,     0,     0,
       0,    20,     0,     0,    13,     0,     0,     0,     0,     0,
       0,     0,     0,     0,    84,     0,     0,    89,     0,     0,
      93,   113,    98,    99,   100,   101,   102,   103,   104,   105,
     106,   107,   108,   109,   110,   111,   112,   114,     0,    96,
       0,     0,     0,     4,     0,     0,     0,     0,     0,     0,
       0,    41,    49,    47,    48,    50,    25,    17,    18,    21,
       0,    15,    43,    44,    40,    57,    56,    54,    10,    23,
      24,    22,    53,     7,    12,    20,   119,   121,   123,   125,
     127,     0,    69,    72,    73,     0,     0,     0,    74,    83,
       0,    75,    88,    66,    76,    92,    77,    95,     0,     9,
       8,     0,     0,     0,     0,     0,     0,     0,     0,    14,
       0,     0,     0,     0,     0,    71,     0,     0,     0,    90,
      91,    94,   115,   116,   117,   118,    97,    59,    60,    61,
      62,    63,    64,    65,    36,    37,    35,     0,     0,   130,
     135,     0,   141,    85,    86,    87,    16,   120,     0,     0,
       0,     0,   130,     0,     0,   135,   126,     0,     0,     0,
     141,     0,     0,     0,   122,   129,   139,   124,   134,     0,
       0,   128,   140,     0,     0,     0,   137,     0,    38,    39,
       0,     0,   131,   132,   133,   139,   136,   142,   143,   138
};

/* YYPGOTO[NTERM-NUM].  */
static const yytype_int16 yypgoto[] =
{
    -245,  -245,  -245,  -245,   116,  -245,    56,  -245,  -245,  -245,
     -97,  -245,   -30,  -245,   -52,  -245,   -58,   -86,   -45,  -245,
     -16,  -245,  -245,  -245,  -245,  -245,  -245,  -245,  -245,  -245,
    -245,  -245,    84,  -245,  -245,  -245,  -245,  -245,  -245,  -245,
      93,  -245,    95,  -245,   100,  -245,    82,  -245,  -245,  -245,
    -245,  -245,  -245,  -245,  -245,  -245,   -27,  -245,   -20,  -245,
     -40,  -245,   -32,  -245
};

/* YYDEFGOTO[NTERM-NUM].  */
static const yytype_int16 yydefgoto[] =
{
       0,     2,     4,     6,    33,    34,   103,   104,   159,   160,
      90,    91,   100,   171,    97,    81,    82,    87,    88,    84,
      85,   237,   279,   280,    35,    36,    37,    38,    39,    40,
      41,    42,    98,    77,   101,     8,    68,    43,    58,    44,
     113,   114,   116,   117,   119,   120,   138,   139,   140,   226,
     181,   210,   211,   212,   213,   214,   251,   252,   254,   255,
     277,   285,   259,   260
};

/* YYTABLE[YYPACT[STATE-NUM]] -- What to do in state STATE-NUM.  If
   positive, shift that token.  If negative, reduce the rule whose
   number is the opposite.  If YYTABLE_NINF, syntax error.  */
static const yytype_int16 yytable[] =
{
      96,   121,   108,     9,   170,   105,    93,   107,    70,    71,
     257,   115,   118,    94,   141,   142,    95,     1,    78,    79,
      10,    11,    12,   176,   177,     3,    72,     5,    73,    74,
      80,    13,    89,   178,    92,     7,   179,   180,    99,   161,
     102,   258,   110,   111,   112,   109,   156,   157,   158,    95,
      45,    46,   105,    75,    47,    14,   222,   223,   224,   225,
      48,    15,    49,    50,    16,   115,    51,    52,   118,    17,
      94,   234,   235,    95,    94,   219,    53,    95,   209,    83,
      18,   248,   249,   250,    54,    55,    56,    57,    59,    60,
      61,   206,   201,    62,   203,   204,   205,    19,   207,    63,
     202,    64,    65,    66,    67,    86,    76,   106,   169,   175,
     143,   144,   145,   146,   147,   148,   149,   150,   190,   151,
     152,   153,   154,   155,   162,   163,   193,   164,   166,   167,
     168,   198,   172,   173,    20,   182,   183,   184,   220,   185,
     216,   217,   218,   186,   187,   253,   188,   191,   194,   196,
      69,   199,    21,   200,    22,    23,   236,   215,   -19,   208,
     174,   227,   228,   221,   229,   230,   231,   232,    24,   233,
     238,   239,    25,    26,   240,    27,   241,   242,   261,    28,
      29,   165,   243,    30,   281,   244,   122,   123,   124,   125,
     126,   127,   128,   129,   130,   131,   132,   133,   134,   135,
     136,   137,   245,   246,   247,    31,    32,   189,    -6,   273,
     274,   275,   192,   256,   276,   262,   263,   278,   264,   266,
     195,   197,   267,   269,   270,   265,   271,   282,   272,   283,
     284,   286,   287,   276,   288,   268,     0,     0,     0,     0,
       0,     0,     0,     0,     0,   289
};

static const yytype_int16 yycheck[] =
{
      52,    68,    60,    68,   101,    57,    51,    59,   118,   119,
     205,    63,    64,   193,    66,    67,   196,     4,   182,   183,
      85,    86,    87,   221,   222,   269,   136,     0,   138,   139,
     194,    96,    48,   231,    50,   272,   234,   235,    54,    91,
      56,   236,   241,   242,   243,    61,   193,   194,   195,   196,
     272,   272,   104,   163,   272,   120,   249,   250,   251,   252,
     272,   126,   272,   272,   129,   117,   272,   272,   120,   134,
     193,   194,   195,   196,   193,   194,   272,   196,   175,   194,
     145,   223,   224,   225,   272,   272,   272,   272,   272,   272,
     272,   149,   144,   272,   146,   147,   148,   162,   150,   272,
     145,   272,   272,   272,   272,   194,   216,   272,   200,   192,
     273,   272,   272,   272,   272,   272,   272,   272,   192,   273,
     273,   273,   273,   273,   273,   273,   192,   273,   273,   273,
     273,   192,   273,   273,   199,   273,   273,   273,   190,   272,
     185,   186,   187,   272,   272,   232,   273,   273,   273,   273,
      34,   273,   217,   273,   219,   220,   208,   273,   272,   272,
     104,   273,   273,   193,   273,   273,   273,   273,   233,   273,
     272,   272,   237,   238,   272,   240,   272,   272,   272,   244,
     245,    97,   273,   248,   270,   273,   253,   254,   255,   256,
     257,   258,   259,   260,   261,   262,   263,   264,   265,   266,
     267,   268,   273,   273,   273,   270,   271,   114,   273,   261,
     262,   263,   117,   273,   266,   272,   272,   269,   273,   272,
     120,   139,   273,   272,   272,   252,   273,   273,   260,   273,
     273,   273,   273,   285,   273,   255,    -1,    -1,    -1,    -1,
      -1,    -1,    -1,    -1,    -1,   285
};

/* YYSTOS[STATE-NUM] -- The symbol kind of the accessing symbol of
   state STATE-NUM.  */
static const yytype_int16 yystos[] =
{
       0,     4,   277,   269,   278,     0,   279,   272,   311,    68,
      85,    86,    87,    96,   120,   126,   129,   134,   145,   162,
     199,   217,   219,   220,   233,   237,   238,   240,   244,   245,
     248,   270,   271,   280,   281,   300,   301,   302,   303,   304,
     305,   306,   307,   313,   315,   272,   272,   272,   272,   272,
     272,   272,   272,   272,   272,   272,   272,   272,   314,   272,
     272,   272,   272,   272,   272,   272,   272,   272,   312,   280,
     118,   119,   136,   138,   139,   163,   216,   309,   182,   183,
     194,   291,   292,   194,   295,   296,   194,   293,   294,   296,
     286,   287,   296,   294,   193,   196,   290,   290,   308,   296,
     288,   310,   296,   282,   283,   290,   272,   290,   292,   296,
     241,   242,   243,   316,   317,   290,   318,   319,   290,   320,
     321,    68,   253,   254,   255,   256,   257,   258,   259,   260,
     261,   262,   263,   264,   265,   266,   267,   268,   322,   323,
     324,   290,   290,   273,   272,   272,   272,   272,   272,   272,
     272,   273,   273,   273,   273,   273,   193,   194,   195,   284,
     285,   290,   273,   273,   273,   308,   273,   273,   273,   200,
     286,   289,   273,   273,   282,   192,   221,   222,   231,   234,
     235,   326,   273,   273,   273,   272,   272,   272,   273,   316,
     192,   273,   318,   192,   273,   320,   273,   322,   192,   273,
     273,   290,   294,   290,   290,   290,   292,   290,   272,   286,
     327,   328,   329,   330,   331,   273,   294,   294,   294,   194,
     290,   288,   249,   250,   251,   252,   325,   273,   273,   273,
     273,   273,   273,   273,   194,   195,   290,   297,   272,   272,
     272,   272,   272,   273,   273,   273,   273,   273,   223,   224,
     225,   332,   333,   232,   334,   335,   273,   205,   236,   338,
     339,   272,   272,   272,   273,   332,   272,   273,   334,   272,
     272,   273,   338,   290,   290,   290,   290,   336,   290,   298,
     299,   293,   273,   273,   273,   337,   273,   273,   273,   336
};

/* YYR1[RULE-NUM] -- Symbol kind of the left-hand side of rule RULE-NUM.  */
static const yytype_int16 yyr1[] =
{
       0,   276,   277,   279,   278,   280,   280,   281,   281,   281,
     281,   281,   282,   282,   283,   284,   284,   284,   284,   285,
     287,   286,   288,   289,   289,   290,   290,   291,   291,   292,
     292,   293,   294,   295,   296,   297,   297,   297,   298,   299,
     300,   300,   301,   302,   302,   302,   302,   303,   303,   304,
     304,   305,   305,   306,   306,   306,   307,   308,   308,   309,
     309,   309,   309,   309,   309,   309,   310,   311,   312,   313,
     314,   313,   313,   313,   313,   313,   313,   313,   313,   313,
     313,   315,   313,   316,   316,   317,   317,   317,   318,   318,
     319,   319,   320,   320,   321,   322,   322,   323,   324,   324,
     324,   324,   324,   324,   324,   324,   324,   324,   324,   324,
     324,   324,   324,   324,   324,   325,   325,   325,   325,   327,
     326,   328,   326,   329,   326,   330,   326,   331,   326,   332,
     332,   333,   333,   333,   334,   334,   335,   337,   336,   336,
     338,   338,   339,   339
};

/* YYR2[RULE-NUM] -- Number of symbols on the right-hand side of rule RULE-NUM.  */
static const yytype_int8 yyr2[] =
{
       0,     2,     2,     0,     7,     2,     0,     4,     4,     4,
       4,     1,     2,     0,     3,     1,     4,     1,     1,     1,
       0,     2,     2,     1,     1,     1,     1,     1,     1,     1,
       1,     1,     1,     1,     1,     1,     1,     1,     1,     1,
       4,     4,     1,     4,     4,     1,     1,     4,     4,     4,
       4,     1,     1,     4,     4,     1,     4,     2,     0,     4,
       4,     4,     4,     4,     4,     4,     0,     0,     0,     4,
       0,     5,     4,     4,     4,     4,     4,     4,     1,     1,
       1,     0,     2,     2,     0,     4,     4,     4,     2,     0,
       3,     3,     2,     0,     3,     2,     0,     3,     1,     1,
       1,     1,     1,     1,     1,     1,     1,     1,     1,     1,
       1,     1,     1,     1,     1,     1,     1,     1,     1,     0,
       4,     0,     5,     0,     5,     0,     4,     0,     5,     2,
       0,     4,     4,     4,     2,     0,     4,     0,     3,     0,
       2,     0,     4,     4
};


enum { YYENOMEM = -2 };

#define yyerrok         (yyerrstatus = 0)
#define yyclearin       (yychar = LOKI_EMPTY)

#define YYACCEPT        goto yyacceptlab
#define YYABORT         goto yyabortlab
#define YYERROR         goto yyerrorlab
#define YYNOMEM         goto yyexhaustedlab


#define YYRECOVERING()  (!!yyerrstatus)

#define YYBACKUP(Token, Value)                                    \
  do                                                              \
    if (yychar == LOKI_EMPTY)                                        \
      {                                                           \
        yychar = (Token);                                         \
        yylval = (Value);                                         \
        YYPOPSTACK (yylen);                                       \
        yystate = *yyssp;                                         \
        goto yybackup;                                            \
      }                                                           \
    else                                                          \
      {                                                           \
        yyerror (&yylloc, lexer, instance, arg, YY_("syntax error: cannot back up")); \
        YYERROR;                                                  \
      }                                                           \
  while (0)

/* Backward compatibility with an undocumented macro.
   Use LOKI_error or LOKI_UNDEF. */
#define YYERRCODE LOKI_UNDEF

/* YYLLOC_DEFAULT -- Set CURRENT to span from RHS[1] to RHS[N].
   If N is 0, then set CURRENT to the empty location which ends
   the previous symbol: RHS[0] (always defined).  */

#ifndef YYLLOC_DEFAULT
# define YYLLOC_DEFAULT(Current, Rhs, N)                                \
    do                                                                  \
      if (N)                                                            \
        {                                                               \
          (Current).first_line   = YYRHSLOC (Rhs, 1).first_line;        \
          (Current).first_column = YYRHSLOC (Rhs, 1).first_column;      \
          (Current).last_line    = YYRHSLOC (Rhs, N).last_line;         \
          (Current).last_column  = YYRHSLOC (Rhs, N).last_column;       \
        }                                                               \
      else                                                              \
        {                                                               \
          (Current).first_line   = (Current).last_line   =              \
            YYRHSLOC (Rhs, 0).last_line;                                \
          (Current).first_column = (Current).last_column =              \
            YYRHSLOC (Rhs, 0).last_column;                              \
        }                                                               \
    while (0)
#endif

#define YYRHSLOC(Rhs, K) ((Rhs)[K])


/* Enable debugging if requested.  */
#if LOKI_DEBUG

# ifndef YYFPRINTF
#  include <stdio.h> /* INFRINGES ON USER NAME SPACE */
#  define YYFPRINTF fprintf
# endif

# define YYDPRINTF(Args)                        \
do {                                            \
  if (yydebug)                                  \
    YYFPRINTF Args;                             \
} while (0)


/* YYLOCATION_PRINT -- Print the location on the stream.
   This macro was not mandated originally: define only if we know
   we won't break user code: when these are the locations we know.  */

# ifndef YYLOCATION_PRINT

#  if defined YY_LOCATION_PRINT

   /* Temporary convenience wrapper in case some people defined the
      undocumented and private YY_LOCATION_PRINT macros.  */
#   define YYLOCATION_PRINT(File, Loc)  YY_LOCATION_PRINT(File, *(Loc))

#  elif defined LOKI_LTYPE_IS_TRIVIAL && LOKI_LTYPE_IS_TRIVIAL

/* Print *YYLOCP on YYO.  Private, do not rely on its existence. */

YY_ATTRIBUTE_UNUSED
static int
yy_location_print_ (FILE *yyo, YYLTYPE const * const yylocp)
{
  int res = 0;
  int end_col = 0 != yylocp->last_column ? yylocp->last_column - 1 : 0;
  if (0 <= yylocp->first_line)
    {
      res += YYFPRINTF (yyo, "%d", yylocp->first_line);
      if (0 <= yylocp->first_column)
        res += YYFPRINTF (yyo, ".%d", yylocp->first_column);
    }
  if (0 <= yylocp->last_line)
    {
      if (yylocp->first_line < yylocp->last_line)
        {
          res += YYFPRINTF (yyo, "-%d", yylocp->last_line);
          if (0 <= end_col)
            res += YYFPRINTF (yyo, ".%d", end_col);
        }
      else if (0 <= end_col && yylocp->first_column < end_col)
        res += YYFPRINTF (yyo, "-%d", end_col);
    }
  return res;
}

#   define YYLOCATION_PRINT  yy_location_print_

    /* Temporary convenience wrapper in case some people defined the
       undocumented and private YY_LOCATION_PRINT macros.  */
#   define YY_LOCATION_PRINT(File, Loc)  YYLOCATION_PRINT(File, &(Loc))

#  else

#   define YYLOCATION_PRINT(File, Loc) ((void) 0)
    /* Temporary convenience wrapper in case some people defined the
       undocumented and private YY_LOCATION_PRINT macros.  */
#   define YY_LOCATION_PRINT  YYLOCATION_PRINT

#  endif
# endif /* !defined YYLOCATION_PRINT */


# define YY_SYMBOL_PRINT(Title, Kind, Value, Location)                    \
do {                                                                      \
  if (yydebug)                                                            \
    {                                                                     \
      YYFPRINTF (stderr, "%s ", Title);                                   \
      yy_symbol_print (stderr,                                            \
                  Kind, Value, Location, lexer, instance, arg); \
      YYFPRINTF (stderr, "\n");                                           \
    }                                                                     \
} while (0)


/*-----------------------------------.
| Print this symbol's value on YYO.  |
`-----------------------------------*/

static void
yy_symbol_value_print (FILE *yyo,
                       yysymbol_kind_t yykind, YYSTYPE const * const yyvaluep, YYLTYPE const * const yylocationp, CfgLexer *lexer, LogDriver **instance, gpointer arg)
{
  FILE *yyoutput = yyo;
  YY_USE (yyoutput);
  YY_USE (yylocationp);
  YY_USE (lexer);
  YY_USE (instance);
  YY_USE (arg);
  if (!yyvaluep)
    return;
  YY_IGNORE_MAYBE_UNINITIALIZED_BEGIN
  YY_USE (yykind);
  YY_IGNORE_MAYBE_UNINITIALIZED_END
}


/*---------------------------.
| Print this symbol on YYO.  |
`---------------------------*/

static void
yy_symbol_print (FILE *yyo,
                 yysymbol_kind_t yykind, YYSTYPE const * const yyvaluep, YYLTYPE const * const yylocationp, CfgLexer *lexer, LogDriver **instance, gpointer arg)
{
  YYFPRINTF (yyo, "%s %s (",
             yykind < YYNTOKENS ? "token" : "nterm", yysymbol_name (yykind));

  YYLOCATION_PRINT (yyo, yylocationp);
  YYFPRINTF (yyo, ": ");
  yy_symbol_value_print (yyo, yykind, yyvaluep, yylocationp, lexer, instance, arg);
  YYFPRINTF (yyo, ")");
}

/*------------------------------------------------------------------.
| yy_stack_print -- Print the state stack from its BOTTOM up to its |
| TOP (included).                                                   |
`------------------------------------------------------------------*/

static void
yy_stack_print (yy_state_t *yybottom, yy_state_t *yytop)
{
  YYFPRINTF (stderr, "Stack now");
  for (; yybottom <= yytop; yybottom++)
    {
      int yybot = *yybottom;
      YYFPRINTF (stderr, " %d", yybot);
    }
  YYFPRINTF (stderr, "\n");
}

# define YY_STACK_PRINT(Bottom, Top)                            \
do {                                                            \
  if (yydebug)                                                  \
    yy_stack_print ((Bottom), (Top));                           \
} while (0)


/*------------------------------------------------.
| Report that the YYRULE is going to be reduced.  |
`------------------------------------------------*/

static void
yy_reduce_print (yy_state_t *yyssp, YYSTYPE *yyvsp, YYLTYPE *yylsp,
                 int yyrule, CfgLexer *lexer, LogDriver **instance, gpointer arg)
{
  int yylno = yyrline[yyrule];
  int yynrhs = yyr2[yyrule];
  int yyi;
  YYFPRINTF (stderr, "Reducing stack by rule %d (line %d):\n",
             yyrule - 1, yylno);
  /* The symbols being reduced.  */
  for (yyi = 0; yyi < yynrhs; yyi++)
    {
      YYFPRINTF (stderr, "   $%d = ", yyi + 1);
      yy_symbol_print (stderr,
                       YY_ACCESSING_SYMBOL (+yyssp[yyi + 1 - yynrhs]),
                       &yyvsp[(yyi + 1) - (yynrhs)],
                       &(yylsp[(yyi + 1) - (yynrhs)]), lexer, instance, arg);
      YYFPRINTF (stderr, "\n");
    }
}

# define YY_REDUCE_PRINT(Rule)          \
do {                                    \
  if (yydebug)                          \
    yy_reduce_print (yyssp, yyvsp, yylsp, Rule, lexer, instance, arg); \
} while (0)

/* Nonzero means print parse trace.  It is left uninitialized so that
   multiple parsers can coexist.  */
int yydebug;
#else /* !LOKI_DEBUG */
# define YYDPRINTF(Args) ((void) 0)
# define YY_SYMBOL_PRINT(Title, Kind, Value, Location)
# define YY_STACK_PRINT(Bottom, Top)
# define YY_REDUCE_PRINT(Rule)
#endif /* !LOKI_DEBUG */


/* YYINITDEPTH -- initial size of the parser's stacks.  */
#ifndef YYINITDEPTH
# define YYINITDEPTH 200
#endif

/* YYMAXDEPTH -- maximum size the stacks can grow to (effective only
   if the built-in stack extension method is used).

   Do not make this value too large; the results are undefined if
   YYSTACK_ALLOC_MAXIMUM < YYSTACK_BYTES (YYMAXDEPTH)
   evaluated with infinite-precision integer arithmetic.  */

#ifndef YYMAXDEPTH
# define YYMAXDEPTH 10000
#endif


/* Context of a parse error.  */
typedef struct
{
  yy_state_t *yyssp;
  yysymbol_kind_t yytoken;
  YYLTYPE *yylloc;
} yypcontext_t;

/* Put in YYARG at most YYARGN of the expected tokens given the
   current YYCTX, and return the number of tokens stored in YYARG.  If
   YYARG is null, return the number of expected tokens (guaranteed to
   be less than YYNTOKENS).  Return YYENOMEM on memory exhaustion.
   Return 0 if there are more than YYARGN expected tokens, yet fill
   YYARG up to YYARGN. */
static int
yypcontext_expected_tokens (const yypcontext_t *yyctx,
                            yysymbol_kind_t yyarg[], int yyargn)
{
  /* Actual size of YYARG. */
  int yycount = 0;
  int yyn = yypact[+*yyctx->yyssp];
  if (!yypact_value_is_default (yyn))
    {
      /* Start YYX at -YYN if negative to avoid negative indexes in
         YYCHECK.  In other words, skip the first -YYN actions for
         this state because they are default actions.  */
      int yyxbegin = yyn < 0 ? -yyn : 0;
      /* Stay within bounds of both yycheck and yytname.  */
      int yychecklim = YYLAST - yyn + 1;
      int yyxend = yychecklim < YYNTOKENS ? yychecklim : YYNTOKENS;
      int yyx;
      for (yyx = yyxbegin; yyx < yyxend; ++yyx)
        if (yycheck[yyx + yyn] == yyx && yyx != YYSYMBOL_YYerror
            && !yytable_value_is_error (yytable[yyx + yyn]))
          {
            if (!yyarg)
              ++yycount;
            else if (yycount == yyargn)
              return 0;
            else
              yyarg[yycount++] = YY_CAST (yysymbol_kind_t, yyx);
          }
    }
  if (yyarg && yycount == 0 && 0 < yyargn)
    yyarg[0] = YYSYMBOL_YYEMPTY;
  return yycount;
}




#ifndef yystrlen
# if defined __GLIBC__ && defined _STRING_H
#  define yystrlen(S) (YY_CAST (YYPTRDIFF_T, strlen (S)))
# else
/* Return the length of YYSTR.  */
static YYPTRDIFF_T
yystrlen (const char *yystr)
{
  YYPTRDIFF_T yylen;
  for (yylen = 0; yystr[yylen]; yylen++)
    continue;
  return yylen;
}
# endif
#endif

#ifndef yystpcpy
# if defined __GLIBC__ && defined _STRING_H && defined _GNU_SOURCE
#  define yystpcpy stpcpy
# else
/* Copy YYSRC to YYDEST, returning the address of the terminating '\0' in
   YYDEST.  */
static char *
yystpcpy (char *yydest, const char *yysrc)
{
  char *yyd = yydest;
  const char *yys = yysrc;

  while ((*yyd++ = *yys++) != '\0')
    continue;

  return yyd - 1;
}
# endif
#endif

#ifndef yytnamerr
/* Copy to YYRES the contents of YYSTR after stripping away unnecessary
   quotes and backslashes, so that it's suitable for yyerror.  The
   heuristic is that double-quoting is unnecessary unless the string
   contains an apostrophe, a comma, or backslash (other than
   backslash-backslash).  YYSTR is taken from yytname.  If YYRES is
   null, do not copy; instead, return the length of what the result
   would have been.  */
static YYPTRDIFF_T
yytnamerr (char *yyres, const char *yystr)
{
  if (*yystr == '"')
    {
      YYPTRDIFF_T yyn = 0;
      char const *yyp = yystr;
      for (;;)
        switch (*++yyp)
          {
          case '\'':
          case ',':
            goto do_not_strip_quotes;

          case '\\':
            if (*++yyp != '\\')
              goto do_not_strip_quotes;
            else
              goto append;

          append:
          default:
            if (yyres)
              yyres[yyn] = *yyp;
            yyn++;
            break;

          case '"':
            if (yyres)
              yyres[yyn] = '\0';
            return yyn;
          }
    do_not_strip_quotes: ;
    }

  if (yyres)
    return yystpcpy (yyres, yystr) - yyres;
  else
    return yystrlen (yystr);
}
#endif


static int
yy_syntax_error_arguments (const yypcontext_t *yyctx,
                           yysymbol_kind_t yyarg[], int yyargn)
{
  /* Actual size of YYARG. */
  int yycount = 0;
  /* There are many possibilities here to consider:
     - If this state is a consistent state with a default action, then
       the only way this function was invoked is if the default action
       is an error action.  In that case, don't check for expected
       tokens because there are none.
     - The only way there can be no lookahead present (in yychar) is if
       this state is a consistent state with a default action.  Thus,
       detecting the absence of a lookahead is sufficient to determine
       that there is no unexpected or expected token to report.  In that
       case, just report a simple "syntax error".
     - Don't assume there isn't a lookahead just because this state is a
       consistent state with a default action.  There might have been a
       previous inconsistent state, consistent state with a non-default
       action, or user semantic action that manipulated yychar.
     - Of course, the expected token list depends on states to have
       correct lookahead information, and it depends on the parser not
       to perform extra reductions after fetching a lookahead from the
       scanner and before detecting a syntax error.  Thus, state merging
       (from LALR or IELR) and default reductions corrupt the expected
       token list.  However, the list is correct for canonical LR with
       one exception: it will still contain any token that will not be
       accepted due to an error action in a later state.
  */
  if (yyctx->yytoken != YYSYMBOL_YYEMPTY)
    {
      int yyn;
      if (yyarg)
        yyarg[yycount] = yyctx->yytoken;
      ++yycount;
      yyn = yypcontext_expected_tokens (yyctx,
                                        yyarg ? yyarg + 1 : yyarg, yyargn - 1);
      if (yyn == YYENOMEM)
        return YYENOMEM;
      else
        yycount += yyn;
    }
  return yycount;
}

/* Copy into *YYMSG, which is of size *YYMSG_ALLOC, an error message
   about the unexpected token YYTOKEN for the state stack whose top is
   YYSSP.

   Return 0 if *YYMSG was successfully written.  Return -1 if *YYMSG is
   not large enough to hold the message.  In that case, also set
   *YYMSG_ALLOC to the required number of bytes.  Return YYENOMEM if the
   required number of bytes is too large to store.  */
static int
yysyntax_error (YYPTRDIFF_T *yymsg_alloc, char **yymsg,
                const yypcontext_t *yyctx)
{
  enum { YYARGS_MAX = 5 };
  /* Internationalized format string. */
  const char *yyformat = YY_NULLPTR;
  /* Arguments of yyformat: reported tokens (one for the "unexpected",
     one per "expected"). */
  yysymbol_kind_t yyarg[YYARGS_MAX];
  /* Cumulated lengths of YYARG.  */
  YYPTRDIFF_T yysize = 0;

  /* Actual size of YYARG. */
  int yycount = yy_syntax_error_arguments (yyctx, yyarg, YYARGS_MAX);
  if (yycount == YYENOMEM)
    return YYENOMEM;

  switch (yycount)
    {
#define YYCASE_(N, S)                       \
      case N:                               \
        yyformat = S;                       \
        break
    default: /* Avoid compiler warnings. */
      YYCASE_(0, YY_("syntax error"));
      YYCASE_(1, YY_("syntax error, unexpected %s"));
      YYCASE_(2, YY_("syntax error, unexpected %s, expecting %s"));
      YYCASE_(3, YY_("syntax error, unexpected %s, expecting %s or %s"));
      YYCASE_(4, YY_("syntax error, unexpected %s, expecting %s or %s or %s"));
      YYCASE_(5, YY_("syntax error, unexpected %s, expecting %s or %s or %s or %s"));
#undef YYCASE_
    }

  /* Compute error message size.  Don't count the "%s"s, but reserve
     room for the terminator.  */
  yysize = yystrlen (yyformat) - 2 * yycount + 1;
  {
    int yyi;
    for (yyi = 0; yyi < yycount; ++yyi)
      {
        YYPTRDIFF_T yysize1
          = yysize + yytnamerr (YY_NULLPTR, yytname[yyarg[yyi]]);
        if (yysize <= yysize1 && yysize1 <= YYSTACK_ALLOC_MAXIMUM)
          yysize = yysize1;
        else
          return YYENOMEM;
      }
  }

  if (*yymsg_alloc < yysize)
    {
      *yymsg_alloc = 2 * yysize;
      if (! (yysize <= *yymsg_alloc
             && *yymsg_alloc <= YYSTACK_ALLOC_MAXIMUM))
        *yymsg_alloc = YYSTACK_ALLOC_MAXIMUM;
      return -1;
    }

  /* Avoid sprintf, as that infringes on the user's name space.
     Don't have undefined behavior even if the translation
     produced a string with the wrong number of "%s"s.  */
  {
    char *yyp = *yymsg;
    int yyi = 0;
    while ((*yyp = *yyformat) != '\0')
      if (*yyp == '%' && yyformat[1] == 's' && yyi < yycount)
        {
          yyp += yytnamerr (yyp, yytname[yyarg[yyi++]]);
          yyformat += 2;
        }
      else
        {
          ++yyp;
          ++yyformat;
        }
  }
  return 0;
}


/*-----------------------------------------------.
| Release the memory associated to this symbol.  |
`-----------------------------------------------*/

static void
yydestruct (const char *yymsg,
            yysymbol_kind_t yykind, YYSTYPE *yyvaluep, YYLTYPE *yylocationp, CfgLexer *lexer, LogDriver **instance, gpointer arg)
{
  YY_USE (yyvaluep);
  YY_USE (yylocationp);
  YY_USE (lexer);
  YY_USE (instance);
  YY_USE (arg);
  if (!yymsg)
    yymsg = "Deleting";
  YY_SYMBOL_PRINT (yymsg, yykind, yyvaluep, yylocationp);

  YY_IGNORE_MAYBE_UNINITIALIZED_BEGIN
  switch (yykind)
    {
    case YYSYMBOL_LL_IDENTIFIER: /* LL_IDENTIFIER  */
#line 372 "modules/grpc/loki/loki-grammar.y"
            { free(((*yyvaluep).cptr)); }
#line 3482 "modules/grpc/loki/loki-grammar.c"
        break;

    case YYSYMBOL_LL_STRING: /* LL_STRING  */
#line 372 "modules/grpc/loki/loki-grammar.y"
            { free(((*yyvaluep).cptr)); }
#line 3488 "modules/grpc/loki/loki-grammar.c"
        break;

    case YYSYMBOL_LL_BLOCK: /* LL_BLOCK  */
#line 372 "modules/grpc/loki/loki-grammar.y"
            { free(((*yyvaluep).cptr)); }
#line 3494 "modules/grpc/loki/loki-grammar.c"
        break;

    case YYSYMBOL_LL_PLUGIN: /* LL_PLUGIN  */
#line 372 "modules/grpc/loki/loki-grammar.y"
            { free(((*yyvaluep).cptr)); }
#line 3500 "modules/grpc/loki/loki-grammar.c"
        break;

    case YYSYMBOL_LL_TEMPLATE_REF: /* LL_TEMPLATE_REF  */
#line 372 "modules/grpc/loki/loki-grammar.y"
            { free(((*yyvaluep).cptr)); }
#line 3506 "modules/grpc/loki/loki-grammar.c"
        break;

    case YYSYMBOL_LL_MESSAGE_REF: /* LL_MESSAGE_REF  */
#line 372 "modules/grpc/loki/loki-grammar.y"
            { free(((*yyvaluep).cptr)); }
#line 3512 "modules/grpc/loki/loki-grammar.c"
        break;

    case YYSYMBOL_string: /* string  */
#line 372 "modules/grpc/loki/loki-grammar.y"
            { free(((*yyvaluep).cptr)); }
#line 3518 "modules/grpc/loki/loki-grammar.c"
        break;

    case YYSYMBOL_string_or_number: /* string_or_number  */
#line 372 "modules/grpc/loki/loki-grammar.y"
            { free(((*yyvaluep).cptr)); }
#line 3524 "modules/grpc/loki/loki-grammar.c"
        break;

    case YYSYMBOL_path: /* path  */
#line 372 "modules/grpc/loki/loki-grammar.y"
            { free(((*yyvaluep).cptr)); }
#line 3530 "modules/grpc/loki/loki-grammar.c"
        break;

    case YYSYMBOL_path_secret: /* path_secret  */
#line 372 "modules/grpc/loki/loki-grammar.y"
            { free(((*yyvaluep).cptr)); }
#line 3536 "modules/grpc/loki/loki-grammar.c"
        break;

      default:
        break;
    }
  YY_IGNORE_MAYBE_UNINITIALIZED_END
}






/*----------.
| yyparse.  |
`----------*/

int
yyparse (CfgLexer *lexer, LogDriver **instance, gpointer arg)
{
/* Lookahead token kind.  */
int yychar;


/* The semantic value of the lookahead symbol.  */
/* Default value used for initialization, for pacifying older GCCs
   or non-GCC compilers.  */
YY_INITIAL_VALUE (static YYSTYPE yyval_default;)
YYSTYPE yylval YY_INITIAL_VALUE (= yyval_default);

/* Location data for the lookahead symbol.  */
static YYLTYPE yyloc_default
# if defined LOKI_LTYPE_IS_TRIVIAL && LOKI_LTYPE_IS_TRIVIAL
  = { 1, 1, 1, 1 }
# endif
;
YYLTYPE yylloc = yyloc_default;

    /* Number of syntax errors so far.  */
    int yynerrs = 0;

    yy_state_fast_t yystate = 0;
    /* Number of tokens to shift before error messages enabled.  */
    int yyerrstatus = 0;

    /* Refer to the stacks through separate pointers, to allow yyoverflow
       to reallocate them elsewhere.  */

    /* Their size.  */
    YYPTRDIFF_T yystacksize = YYINITDEPTH;

    /* The state stack: array, bottom, top.  */
    yy_state_t yyssa[YYINITDEPTH];
    yy_state_t *yyss = yyssa;
    yy_state_t *yyssp = yyss;

    /* The semantic value stack: array, bottom, top.  */
    YYSTYPE yyvsa[YYINITDEPTH];
    YYSTYPE *yyvs = yyvsa;
    YYSTYPE *yyvsp = yyvs;

    /* The location stack: array, bottom, top.  */
    YYLTYPE yylsa[YYINITDEPTH];
    YYLTYPE *yyls = yylsa;
    YYLTYPE *yylsp = yyls;

  int yyn;
  /* The return value of yyparse.  */
  int yyresult;
  /* Lookahead symbol kind.  */
  yysymbol_kind_t yytoken = YYSYMBOL_YYEMPTY;
  /* The variables used to return semantic value and location from the
     action routines.  */
  YYSTYPE yyval;
  YYLTYPE yyloc;

  /* The locations where the error started and ended.  */
  YYLTYPE yyerror_range[3];

  /* Buffer for error messages, and its allocated size.  */
  char yymsgbuf[128];
  char *yymsg = yymsgbuf;
  YYPTRDIFF_T yymsg_alloc = sizeof yymsgbuf;

#define YYPOPSTACK(N)   (yyvsp -= (N), yyssp -= (N), yylsp -= (N))

  /* The number of symbols on the RHS of the reduced rule.
     Keep to zero when no symbol should be popped.  */
  int yylen = 0;

  YYDPRINTF ((stderr, "Starting parse\n"));

  yychar = LOKI_EMPTY; /* Cause a token to be read.  */

  yylsp[0] = yylloc;
  goto yysetstate;


/*------------------------------------------------------------.
| yynewstate -- push a new state, which is found in yystate.  |
`------------------------------------------------------------*/
yynewstate:
  /* In all cases, when you get here, the value and location stacks
     have just been pushed.  So pushing a state here evens the stacks.  */
  yyssp++;


/*--------------------------------------------------------------------.
| yysetstate -- set current state (the top of the stack) to yystate.  |
`--------------------------------------------------------------------*/
yysetstate:
  YYDPRINTF ((stderr, "Entering state %d\n", yystate));
  YY_ASSERT (0 <= yystate && yystate < YYNSTATES);
  YY_IGNORE_USELESS_CAST_BEGIN
  *yyssp = YY_CAST (yy_state_t, yystate);
  YY_IGNORE_USELESS_CAST_END
  YY_STACK_PRINT (yyss, yyssp);

  if (yyss + yystacksize - 1 <= yyssp)
#if !defined yyoverflow && !defined YYSTACK_RELOCATE
    YYNOMEM;
#else
    {
      /* Get the current used size of the three stacks, in elements.  */
      YYPTRDIFF_T yysize = yyssp - yyss + 1;

# if defined yyoverflow
      {
        /* Give user a chance to reallocate the stack.  Use copies of
           these so that the &'s don't force the real ones into
           memory.  */
        yy_state_t *yyss1 = yyss;
        YYSTYPE *yyvs1 = yyvs;
        YYLTYPE *yyls1 = yyls;

        /* Each stack pointer address is followed by the size of the
           data in use in that stack, in bytes.  This used to be a
           conditional around just the two extra args, but that might
           be undefined if yyoverflow is a macro.  */
        yyoverflow (YY_("memory exhausted"),
                    &yyss1, yysize * YYSIZEOF (*yyssp),
                    &yyvs1, yysize * YYSIZEOF (*yyvsp),
                    &yyls1, yysize * YYSIZEOF (*yylsp),
                    &yystacksize);
        yyss = yyss1;
        yyvs = yyvs1;
        yyls = yyls1;
      }
# else /* defined YYSTACK_RELOCATE */
      /* Extend the stack our own way.  */
      if (YYMAXDEPTH <= yystacksize)
        YYNOMEM;
      yystacksize *= 2;
      if (YYMAXDEPTH < yystacksize)
        yystacksize = YYMAXDEPTH;

      {
        yy_state_t *yyss1 = yyss;
        union yyalloc *yyptr =
          YY_CAST (union yyalloc *,
                   YYSTACK_ALLOC (YY_CAST (YYSIZE_T, YYSTACK_BYTES (yystacksize))));
        if (! yyptr)
          YYNOMEM;
        YYSTACK_RELOCATE (yyss_alloc, yyss);
        YYSTACK_RELOCATE (yyvs_alloc, yyvs);
        YYSTACK_RELOCATE (yyls_alloc, yyls);
#  undef YYSTACK_RELOCATE
        if (yyss1 != yyssa)
          YYSTACK_FREE (yyss1);
      }
# endif

      yyssp = yyss + yysize - 1;
      yyvsp = yyvs + yysize - 1;
      yylsp = yyls + yysize - 1;

      YY_IGNORE_USELESS_CAST_BEGIN
      YYDPRINTF ((stderr, "Stack size increased to %ld\n",
                  YY_CAST (long, yystacksize)));
      YY_IGNORE_USELESS_CAST_END

      if (yyss + yystacksize - 1 <= yyssp)
        YYABORT;
    }
#endif /* !defined yyoverflow && !defined YYSTACK_RELOCATE */


  if (yystate == YYFINAL)
    YYACCEPT;

  goto yybackup;


/*-----------.
| yybackup.  |
`-----------*/
yybackup:
  /* Do appropriate processing given the current state.  Read a
     lookahead token if we need one and don't already have one.  */

  /* First try to decide what to do without reference to lookahead token.  */
  yyn = yypact[yystate];
  if (yypact_value_is_default (yyn))
    goto yydefault;

  /* Not known => get a lookahead token if don't already have one.  */

  /* YYCHAR is either empty, or end-of-input, or a valid lookahead.  */
  if (yychar == LOKI_EMPTY)
    {
      YYDPRINTF ((stderr, "Reading a token\n"));
      yychar = yylex (&yylval, &yylloc, lexer);
    }

  if (yychar <= LOKI_EOF)
    {
      yychar = LOKI_EOF;
      yytoken = YYSYMBOL_YYEOF;
      YYDPRINTF ((stderr, "Now at end of input.\n"));
    }
  else if (yychar == LOKI_error)
    {
      /* The scanner already issued an error message, process directly
         to error recovery.  But do not keep the error token as
         lookahead, it is too special and may lead us to an endless
         loop in error recovery. */
      yychar = LOKI_UNDEF;
      yytoken = YYSYMBOL_YYerror;
      yyerror_range[1] = yylloc;
      goto yyerrlab1;
    }
  else
    {
      yytoken = YYTRANSLATE (yychar);
      YY_SYMBOL_PRINT ("Next token is", yytoken, &yylval, &yylloc);
    }

  /* If the proper action on seeing token YYTOKEN is to reduce or to
     detect an error, take that action.  */
  yyn += yytoken;
  if (yyn < 0 || YYLAST < yyn || yycheck[yyn] != yytoken)
    goto yydefault;
  yyn = yytable[yyn];
  if (yyn <= 0)
    {
      if (yytable_value_is_error (yyn))
        goto yyerrlab;
      yyn = -yyn;
      goto yyreduce;
    }

  /* Count tokens shifted since error; after three, turn off error
     status.  */
  if (yyerrstatus)
    yyerrstatus--;

  /* Shift the lookahead token.  */
  YY_SYMBOL_PRINT ("Shifting", yytoken, &yylval, &yylloc);
  yystate = yyn;
  YY_IGNORE_MAYBE_UNINITIALIZED_BEGIN
  *++yyvsp = yylval;
  YY_IGNORE_MAYBE_UNINITIALIZED_END
  *++yylsp = yylloc;

  /* Discard the shifted token.  */
  yychar = LOKI_EMPTY;
  goto yynewstate;


/*-----------------------------------------------------------.
| yydefault -- do the default action for the current state.  |
`-----------------------------------------------------------*/
yydefault:
  yyn = yydefact[yystate];
  if (yyn == 0)
    goto yyerrlab;
  goto yyreduce;


/*-----------------------------.
| yyreduce -- do a reduction.  |
`-----------------------------*/
yyreduce:
  /* yyn is the number of a rule to reduce with.  */
  yylen = yyr2[yyn];

  /* If YYLEN is nonzero, implement the default value of the action:
     '$$ = $1'.

     Otherwise, the following line sets YYVAL to garbage.
     This behavior is undocumented and Bison
     users should not rely upon it.  Assigning to YYVAL
     unconditionally makes the parser a bit smaller, and it avoids a
     GCC warning that YYVAL may be used uninitialized.  */
  yyval = yyvsp[1-yylen];

  /* Default location. */
  YYLLOC_DEFAULT (yyloc, (yylsp - yylen), yylen);
  yyerror_range[1] = yyloc;
  YY_REDUCE_PRINT (yyn);
  switch (yyn)
    {
  case 2: /* start: LL_CONTEXT_DESTINATION loki_dest  */
#line 551 "modules/grpc/loki/loki-grammar.y"
                                     { YYACCEPT; }
#line 3842 "modules/grpc/loki/loki-grammar.c"
    break;

  case 3: /* $@1: %empty  */
#line 556 "modules/grpc/loki/loki-grammar.y"
    {
      last_driver = *instance = loki_dd_new(configuration);
    }
#line 3850 "modules/grpc/loki/loki-grammar.c"
    break;

  case 4: /* loki_dest: KW_LOKI $@1 '(' _inner_dest_context_push loki_dest_options _inner_dest_context_pop ')'  */
#line 559 "modules/grpc/loki/loki-grammar.y"
                                                                               { (yyval.ptr) = last_driver; }
#line 3856 "modules/grpc/loki/loki-grammar.c"
    break;

  case 8: /* loki_dest_option: KW_TENANT_ID '(' string ')'  */
#line 569 "modules/grpc/loki/loki-grammar.y"
                                { loki_dd_set_tenant_id(last_driver, (yyvsp[-1].cptr)); free((yyvsp[-1].cptr)); }
#line 3862 "modules/grpc/loki/loki-grammar.c"
    break;

  case 9: /* loki_dest_option: KW_TIMESTAMP '(' string ')'  */
#line 571 "modules/grpc/loki/loki-grammar.y"
    {
      CHECK_ERROR(loki_dd_set_timestamp(last_driver, (yyvsp[-1].cptr)), (yylsp[-3]), "Failed to set timestamp(). Valid values are: \"current\", \"received\", \"msg\"");
      free((yyvsp[-1].cptr));
    }
#line 3871 "modules/grpc/loki/loki-grammar.c"
    break;

  case 10: /* loki_dest_option: KW_TEMPLATE '(' template_name_or_content ')'  */
#line 575 "modules/grpc/loki/loki-grammar.y"
                                                 { loki_dd_set_message_template_ref(last_driver, (yyvsp[-1].ptr)); }
#line 3877 "modules/grpc/loki/loki-grammar.c"
    break;

  case 14: /* loki_label: string LL_ARROW template_content  */
#line 586 "modules/grpc/loki/loki-grammar.y"
    {
	    loki_dd_add_label(last_driver, (yyvsp[-2].cptr), (yyvsp[0].ptr));
      free((yyvsp[-2].cptr));
      log_template_unref((yyvsp[0].ptr));
    }
#line 3887 "modules/grpc/loki/loki-grammar.c"
    break;

  case 15: /* template_content_inner: string  */
#line 869 "modules/grpc/loki/loki-grammar.y"
        {
          GError *error = NULL;

          CHECK_ERROR_GERROR(log_template_compile((yyvsp[-1].ptr), (yyvsp[0].cptr), &error), (yylsp[0]), error, "Error compiling template");
          free((yyvsp[0].cptr));
        }
#line 3898 "modules/grpc/loki/loki-grammar.c"
    break;

  case 16: /* template_content_inner: type_hint '(' string_or_number ')'  */
#line 876 "modules/grpc/loki/loki-grammar.y"
        {
          GError *error = NULL;

          CHECK_ERROR_GERROR(log_template_compile((yyvsp[-4].ptr), (yyvsp[-1].cptr), &error), (yylsp[-1]), error, "Error compiling template");
          free((yyvsp[-1].cptr));

          log_template_set_type_hint_value((yyvsp[-4].ptr), (yyvsp[-3].num));
        }
#line 3911 "modules/grpc/loki/loki-grammar.c"
    break;

  case 17: /* template_content_inner: LL_NUMBER  */
#line 885 "modules/grpc/loki/loki-grammar.y"
        {
          gchar decimal[32];

          g_snprintf(decimal, sizeof(decimal), "%" G_GINT64_FORMAT, (yyvsp[0].num));
          log_template_compile_literal_string((yyvsp[-1].ptr), decimal);
          log_template_set_type_hint((yyvsp[-1].ptr), "int64", NULL);
        }
#line 3923 "modules/grpc/loki/loki-grammar.c"
    break;

  case 18: /* template_content_inner: LL_FLOAT  */
#line 893 "modules/grpc/loki/loki-grammar.y"
        {
          log_template_compile_literal_string((yyvsp[-1].ptr), lexer->token_text->str);
          log_template_set_type_hint((yyvsp[-1].ptr), "float", NULL);
        }
#line 3932 "modules/grpc/loki/loki-grammar.c"
    break;

  case 19: /* type_hint: LL_IDENTIFIER  */
#line 901 "modules/grpc/loki/loki-grammar.y"
          {
            LogMessageValueType type;
            GError *error = NULL;

            CHECK_ERROR_GERROR(type_hint_parse((yyvsp[0].cptr), &type, &error), (yylsp[0]), error, "Unknown type hint");
            free((yyvsp[0].cptr));
            (yyval.num) = type;
          }
#line 3945 "modules/grpc/loki/loki-grammar.c"
    break;

  case 20: /* @4: %empty  */
#line 911 "modules/grpc/loki/loki-grammar.y"
               {
            (yyval.ptr) = log_template_new(configuration, NULL);
          }
#line 3953 "modules/grpc/loki/loki-grammar.c"
    break;

  case 21: /* template_content: @4 template_content_inner  */
#line 913 "modules/grpc/loki/loki-grammar.y"
                                                                            { (yyval.ptr) = (yyvsp[-1].ptr); }
#line 3959 "modules/grpc/loki/loki-grammar.c"
    break;

  case 22: /* template_name_or_content: _template_ref_context_push template_name_or_content_tail  */
#line 922 "modules/grpc/loki/loki-grammar.y"
                                                                            { (yyval.ptr) = (yyvsp[0].ptr); }
#line 3965 "modules/grpc/loki/loki-grammar.c"
    break;

  case 23: /* template_name_or_content_tail: LL_TEMPLATE_REF  */
#line 926 "modules/grpc/loki/loki-grammar.y"
                                                                            { (yyval.ptr) = cfg_tree_lookup_template(&configuration->tree, (yyvsp[0].cptr)); free((yyvsp[0].cptr)); }
#line 3971 "modules/grpc/loki/loki-grammar.c"
    break;

  case 24: /* template_name_or_content_tail: template_content  */
#line 927 "modules/grpc/loki/loki-grammar.y"
                                                                            { (yyval.ptr) = (yyvsp[0].ptr); }
#line 3977 "modules/grpc/loki/loki-grammar.c"
    break;

  case 27: /* yesno_strict: KW_YES  */
#line 938 "modules/grpc/loki/loki-grammar.y"
                                                { (yyval.num) = 1; }
#line 3983 "modules/grpc/loki/loki-grammar.c"
    break;

  case 28: /* yesno_strict: KW_NO  */
#line 939 "modules/grpc/loki/loki-grammar.y"
                                                { (yyval.num) = 0; }
#line 3989 "modules/grpc/loki/loki-grammar.c"
    break;

  case 30: /* yesno: LL_NUMBER  */
#line 944 "modules/grpc/loki/loki-grammar.y"
                                                { (yyval.num) = (yyvsp[0].num); }
#line 3995 "modules/grpc/loki/loki-grammar.c"
    break;

  case 31: /* nonnegative_integer64: LL_NUMBER  */
#line 960 "modules/grpc/loki/loki-grammar.y"
          {
            CHECK_ERROR(((yyvsp[0].num) >= 0), (yylsp[0]), "It cannot be negative");
          }
#line 4003 "modules/grpc/loki/loki-grammar.c"
    break;

  case 32: /* nonnegative_integer: nonnegative_integer64  */
#line 967 "modules/grpc/loki/loki-grammar.y"
          {
            CHECK_ERROR(((yyvsp[0].num) <= G_MAXINT32), (yylsp[0]), "Must be smaller than 2^31");
          }
#line 4011 "modules/grpc/loki/loki-grammar.c"
    break;

  case 33: /* positive_integer64: LL_NUMBER  */
#line 974 "modules/grpc/loki/loki-grammar.y"
          {
            CHECK_ERROR(((yyvsp[0].num) > 0), (yylsp[0]), "Must be positive");
          }
#line 4019 "modules/grpc/loki/loki-grammar.c"
    break;

  case 34: /* positive_integer: positive_integer64  */
#line 981 "modules/grpc/loki/loki-grammar.y"
          {
            CHECK_ERROR(((yyvsp[0].num) <= G_MAXINT32), (yylsp[0]), "Must be smaller than 2^31");
          }
#line 4027 "modules/grpc/loki/loki-grammar.c"
    break;

  case 35: /* string_or_number: string  */
#line 1009 "modules/grpc/loki/loki-grammar.y"
                                                { (yyval.cptr) = (yyvsp[0].cptr); }
#line 4033 "modules/grpc/loki/loki-grammar.c"
    break;

  case 36: /* string_or_number: LL_NUMBER  */
#line 1010 "modules/grpc/loki/loki-grammar.y"
                                                { (yyval.cptr) = strdup(lexer->token_text->str); }
#line 4039 "modules/grpc/loki/loki-grammar.c"
    break;

  case 37: /* string_or_number: LL_FLOAT  */
#line 1011 "modules/grpc/loki/loki-grammar.y"
                                                { (yyval.cptr) = strdup(lexer->token_text->str); }
#line 4045 "modules/grpc/loki/loki-grammar.c"
    break;

  case 38: /* path: string  */
#line 1021 "modules/grpc/loki/loki-grammar.y"
          {
            struct stat buffer;
            int ret = stat((yyvsp[0].cptr), &buffer);
            CHECK_ERROR((ret == 0), (yylsp[0]), "File \"%s\" not found: %s", (yyvsp[0].cptr), strerror(errno));
            (yyval.cptr) = (yyvsp[0].cptr);
	  }
#line 4056 "modules/grpc/loki/loki-grammar.c"
    break;

  case 39: /* path_secret: path  */
#line 1034 "modules/grpc/loki/loki-grammar.y"
           { cfg_path_track_file(configuration, (yyvsp[0].cptr), "path_secret"); }
#line 4062 "modules/grpc/loki/loki-grammar.c"
    break;

  case 40: /* driver_option: KW_PERSIST_NAME '(' string ')'  */
#line 1088 "modules/grpc/loki/loki-grammar.y"
                                         { log_pipe_set_persist_name(&last_driver->super, (yyvsp[-1].cptr)); free((yyvsp[-1].cptr)); }
#line 4068 "modules/grpc/loki/loki-grammar.c"
    break;

  case 41: /* driver_option: KW_INTERNAL '(' yesno ')'  */
#line 1089 "modules/grpc/loki/loki-grammar.y"
                                    { log_pipe_set_internal(&last_driver->super, (yyvsp[-1].num)); }
#line 4074 "modules/grpc/loki/loki-grammar.c"
    break;

  case 42: /* inner_dest: LL_PLUGIN  */
#line 1126 "modules/grpc/loki/loki-grammar.y"
          {
            Plugin *p;
            gint context = LL_CONTEXT_INNER_DEST;
            gpointer value;

            p = cfg_find_plugin(configuration, context, (yyvsp[0].cptr));
            CHECK_ERROR(p, (yylsp[0]), "%s plugin %s not found", cfg_lexer_lookup_context_name_by_type(context), (yyvsp[0].cptr));

            value = cfg_parse_plugin(configuration, p, &(yylsp[0]), last_driver);

            free((yyvsp[0].cptr));
            if (!value)
              {
                YYERROR;
              }
            if (!log_driver_add_plugin(last_driver, (LogDriverPlugin *) value))
              {
                log_driver_plugin_free(value);
                CHECK_ERROR(TRUE, (yylsp[0]), "Error while registering the plugin %s in this destination", (yyvsp[0].cptr));
              }
          }
#line 4100 "modules/grpc/loki/loki-grammar.c"
    break;

  case 43: /* dest_driver_option: KW_LOG_FIFO_SIZE '(' positive_integer ')'  */
#line 1153 "modules/grpc/loki/loki-grammar.y"
                                                        { ((LogDestDriver *) last_driver)->log_fifo_size = (yyvsp[-1].num); }
#line 4106 "modules/grpc/loki/loki-grammar.c"
    break;

  case 44: /* dest_driver_option: KW_THROTTLE '(' nonnegative_integer ')'  */
#line 1154 "modules/grpc/loki/loki-grammar.y"
                                                          { ((LogDestDriver *) last_driver)->throttle = (yyvsp[-1].num); }
#line 4112 "modules/grpc/loki/loki-grammar.c"
    break;

  case 47: /* threaded_dest_driver_batch_option: KW_BATCH_LINES '(' nonnegative_integer ')'  */
#line 1160 "modules/grpc/loki/loki-grammar.y"
                                                     { log_threaded_dest_driver_set_batch_lines(last_driver, (yyvsp[-1].num)); }
#line 4118 "modules/grpc/loki/loki-grammar.c"
    break;

  case 48: /* threaded_dest_driver_batch_option: KW_BATCH_TIMEOUT '(' positive_integer ')'  */
#line 1161 "modules/grpc/loki/loki-grammar.y"
                                                    { log_threaded_dest_driver_set_batch_timeout(last_driver, (yyvsp[-1].num)); }
#line 4124 "modules/grpc/loki/loki-grammar.c"
    break;

  case 49: /* threaded_dest_driver_workers_option: KW_WORKERS '(' positive_integer ')'  */
#line 1165 "modules/grpc/loki/loki-grammar.y"
                                               { log_threaded_dest_driver_set_num_workers(last_driver, (yyvsp[-1].num)); }
#line 4130 "modules/grpc/loki/loki-grammar.c"
    break;

  case 50: /* threaded_dest_driver_workers_option: KW_WORKER_PARTITION_KEY '(' template_content ')'  */
#line 1166 "modules/grpc/loki/loki-grammar.y"
                                                           { log_threaded_dest_driver_set_worker_partition_key_ref(last_driver, (yyvsp[-1].ptr)); }
#line 4136 "modules/grpc/loki/loki-grammar.c"
    break;

  case 53: /* threaded_dest_driver_general_option_noflags: KW_RETRIES '(' positive_integer ')'  */
#line 1177 "modules/grpc/loki/loki-grammar.y"
        {
          log_threaded_dest_driver_set_max_retries_on_error(last_driver, (yyvsp[-1].num));
        }
#line 4144 "modules/grpc/loki/loki-grammar.c"
    break;

  case 54: /* threaded_dest_driver_general_option_noflags: KW_TIME_REOPEN '(' positive_integer ')'  */
#line 1180 "modules/grpc/loki/loki-grammar.y"
                                                  { log_threaded_dest_driver_set_time_reopen(last_driver, (yyvsp[-1].num)); }
#line 4150 "modules/grpc/loki/loki-grammar.c"
    break;

  case 57: /* threaded_dest_driver_flags: string threaded_dest_driver_flags  */
#line 1189 "modules/grpc/loki/loki-grammar.y"
                                                { CHECK_ERROR(log_threaded_dest_driver_process_flag(last_driver, (yyvsp[-1].cptr)), (yylsp[-1]), "Unknown flag \"%s\"", (yyvsp[-1].cptr)); free((yyvsp[-1].cptr)); }
#line 4156 "modules/grpc/loki/loki-grammar.c"
    break;

  case 59: /* template_option: KW_TS_FORMAT '(' string ')'  */
#line 1347 "modules/grpc/loki/loki-grammar.y"
                                                { last_template_options->ts_format = cfg_ts_format_value((yyvsp[-1].cptr)); free((yyvsp[-1].cptr)); }
#line 4162 "modules/grpc/loki/loki-grammar.c"
    break;

  case 60: /* template_option: KW_FRAC_DIGITS '(' nonnegative_integer ')'  */
#line 1348 "modules/grpc/loki/loki-grammar.y"
                                                        { last_template_options->frac_digits = (yyvsp[-1].num); }
#line 4168 "modules/grpc/loki/loki-grammar.c"
    break;

  case 61: /* template_option: KW_TIME_ZONE '(' string ')'  */
#line 1349 "modules/grpc/loki/loki-grammar.y"
                                                { last_template_options->time_zone[LTZ_SEND] = g_strdup((yyvsp[-1].cptr)); free((yyvsp[-1].cptr)); }
#line 4174 "modules/grpc/loki/loki-grammar.c"
    break;

  case 62: /* template_option: KW_SEND_TIME_ZONE '(' string ')'  */
#line 1350 "modules/grpc/loki/loki-grammar.y"
                                                { last_template_options->time_zone[LTZ_SEND] = g_strdup((yyvsp[-1].cptr)); free((yyvsp[-1].cptr)); }
#line 4180 "modules/grpc/loki/loki-grammar.c"
    break;

  case 63: /* template_option: KW_LOCAL_TIME_ZONE '(' string ')'  */
#line 1351 "modules/grpc/loki/loki-grammar.y"
                                                { last_template_options->time_zone[LTZ_LOCAL] = g_strdup((yyvsp[-1].cptr)); free((yyvsp[-1].cptr)); }
#line 4186 "modules/grpc/loki/loki-grammar.c"
    break;

  case 64: /* template_option: KW_TEMPLATE_ESCAPE '(' yesno ')'  */
#line 1352 "modules/grpc/loki/loki-grammar.y"
                                                { last_template_options->escape = (yyvsp[-1].num); }
#line 4192 "modules/grpc/loki/loki-grammar.c"
    break;

  case 65: /* template_option: KW_ON_ERROR '(' string ')'  */
#line 1354 "modules/grpc/loki/loki-grammar.y"
        {
          gint on_error;

          CHECK_ERROR(log_template_on_error_parse((yyvsp[-1].cptr), &on_error), (yylsp[-1]), "Invalid on-error() setting \"%s\"", (yyvsp[-1].cptr));
          free((yyvsp[-1].cptr));

          log_template_options_set_on_error(last_template_options, on_error);
        }
#line 4205 "modules/grpc/loki/loki-grammar.c"
    break;

  case 66: /* _template_ref_context_push: %empty  */
#line 1538 "modules/grpc/loki/loki-grammar.y"
                            { cfg_lexer_push_context(lexer, LL_CONTEXT_TEMPLATE_REF, NULL, "template reference"); }
#line 4211 "modules/grpc/loki/loki-grammar.c"
    break;

  case 67: /* _inner_dest_context_push: %empty  */
#line 1539 "modules/grpc/loki/loki-grammar.y"
                          { cfg_lexer_push_context(lexer, LL_CONTEXT_INNER_DEST, NULL, "within destination"); }
#line 4217 "modules/grpc/loki/loki-grammar.c"
    break;

  case 68: /* _inner_dest_context_pop: %empty  */
#line 1540 "modules/grpc/loki/loki-grammar.y"
                         { cfg_lexer_pop_context(lexer); }
#line 4223 "modules/grpc/loki/loki-grammar.c"
    break;

  case 69: /* grpc_dest_general_option: KW_URL '(' string ')'  */
#line 1568 "modules/grpc/loki/loki-grammar.y"
                          { grpc_dd_set_url(last_driver, (yyvsp[-1].cptr)); free((yyvsp[-1].cptr)); }
#line 4229 "modules/grpc/loki/loki-grammar.c"
    break;

  case 70: /* $@19: %empty  */
#line 1569 "modules/grpc/loki/loki-grammar.y"
            { last_grpc_client_credentials_builder = grpc_dd_get_credentials_builder(last_driver); }
#line 4235 "modules/grpc/loki/loki-grammar.c"
    break;

  case 72: /* grpc_dest_general_option: KW_COMPRESSION '(' yesno ')'  */
#line 1570 "modules/grpc/loki/loki-grammar.y"
                                 { grpc_dd_set_compression(last_driver, (yyvsp[-1].num)); }
#line 4241 "modules/grpc/loki/loki-grammar.c"
    break;

  case 73: /* grpc_dest_general_option: KW_BATCH_BYTES '(' positive_integer ')'  */
#line 1571 "modules/grpc/loki/loki-grammar.y"
                                            { grpc_dd_set_batch_bytes(last_driver, (yyvsp[-1].num)); }
#line 4247 "modules/grpc/loki/loki-grammar.c"
    break;

  case 81: /* $@20: %empty  */
#line 1579 "modules/grpc/loki/loki-grammar.y"
    { last_template_options = grpc_dd_get_template_options(last_driver); }
#line 4253 "modules/grpc/loki/loki-grammar.c"
    break;

  case 85: /* grpc_keepalive_option: KW_TIME '(' nonnegative_integer ')'  */
#line 1612 "modules/grpc/loki/loki-grammar.y"
                                        { grpc_dd_set_keepalive_time(last_driver, (yyvsp[-1].num)); }
#line 4259 "modules/grpc/loki/loki-grammar.c"
    break;

  case 86: /* grpc_keepalive_option: KW_TIMEOUT '(' nonnegative_integer ')'  */
#line 1613 "modules/grpc/loki/loki-grammar.y"
                                           { grpc_dd_set_keepalive_timeout(last_driver, (yyvsp[-1].num)); }
#line 4265 "modules/grpc/loki/loki-grammar.c"
    break;

  case 87: /* grpc_keepalive_option: KW_MAX_PINGS_WITHOUT_DATA '(' nonnegative_integer ')'  */
#line 1614 "modules/grpc/loki/loki-grammar.y"
                                                          { grpc_dd_set_keepalive_max_pings(last_driver, (yyvsp[-1].num)); }
#line 4271 "modules/grpc/loki/loki-grammar.c"
    break;

  case 90: /* grpc_dest_channel_arg: string LL_ARROW LL_NUMBER  */
#line 1624 "modules/grpc/loki/loki-grammar.y"
                              { grpc_dd_add_int_channel_arg(last_driver, (yyvsp[-2].cptr), (yyvsp[0].num)); free((yyvsp[-2].cptr)); }
#line 4277 "modules/grpc/loki/loki-grammar.c"
    break;

  case 91: /* grpc_dest_channel_arg: string LL_ARROW string  */
#line 1625 "modules/grpc/loki/loki-grammar.y"
                           { grpc_dd_add_string_channel_arg(last_driver, (yyvsp[-2].cptr), (yyvsp[0].cptr)); free((yyvsp[-2].cptr)); free((yyvsp[0].cptr)); }
#line 4283 "modules/grpc/loki/loki-grammar.c"
    break;

  case 94: /* grpc_dest_header: string LL_ARROW template_name_or_content  */
#line 1635 "modules/grpc/loki/loki-grammar.y"
      {
        CHECK_ERROR(grpc_dd_add_header(last_driver, (yyvsp[-2].cptr), (yyvsp[0].ptr)), (yylsp[0]), "Failed to set header: templating is not supported");
        free((yyvsp[-2].cptr));
        log_template_unref((yyvsp[0].ptr));
      }
#line 4293 "modules/grpc/loki/loki-grammar.c"
    break;

  case 97: /* grpc_dest_response_action_item: grpc_dest_response LL_ARROW grpc_dest_response_action  */
#line 1648 "modules/grpc/loki/loki-grammar.y"
                                                          { grpc_dd_set_response_action(last_driver, (yyvsp[-2].num), (yyvsp[0].num)); }
#line 4299 "modules/grpc/loki/loki-grammar.c"
    break;

  case 98: /* grpc_dest_response: KW_OK  */
#line 1652 "modules/grpc/loki/loki-grammar.y"
          { (yyval.num) = GDR_OK; }
#line 4305 "modules/grpc/loki/loki-grammar.c"
    break;

  case 99: /* grpc_dest_response: KW_UNAVAILABLE  */
#line 1653 "modules/grpc/loki/loki-grammar.y"
                   { (yyval.num) = GDR_UNAVAILABLE; }
#line 4311 "modules/grpc/loki/loki-grammar.c"
    break;

  case 100: /* grpc_dest_response: KW_CANCELLED  */
#line 1654 "modules/grpc/loki/loki-grammar.y"
                 { (yyval.num) = GDR_CANCELLED; }
#line 4317 "modules/grpc/loki/loki-grammar.c"
    break;

  case 101: /* grpc_dest_response: KW_DEADLINE_EXCEEDED  */
#line 1655 "modules/grpc/loki/loki-grammar.y"
                         { (yyval.num) = GDR_DEADLINE_EXCEEDED; }
#line 4323 "modules/grpc/loki/loki-grammar.c"
    break;

  case 102: /* grpc_dest_response: KW_ABORTED  */
#line 1656 "modules/grpc/loki/loki-grammar.y"
               { (yyval.num) = GDR_ABORTED; }
#line 4329 "modules/grpc/loki/loki-grammar.c"
    break;

  case 103: /* grpc_dest_response: KW_OUT_OF_RANGE  */
#line 1657 "modules/grpc/loki/loki-grammar.y"
                    { (yyval.num) = GDR_OUT_OF_RANGE; }
#line 4335 "modules/grpc/loki/loki-grammar.c"
    break;

  case 104: /* grpc_dest_response: KW_DATA_LOSS  */
#line 1658 "modules/grpc/loki/loki-grammar.y"
                 { (yyval.num) = GDR_DATA_LOSS; }
#line 4341 "modules/grpc/loki/loki-grammar.c"
    break;

  case 105: /* grpc_dest_response: KW_UNKNOWN  */
#line 1659 "modules/grpc/loki/loki-grammar.y"
               { (yyval.num) = GDR_UNKNOWN; }
#line 4347 "modules/grpc/loki/loki-grammar.c"
    break;

  case 106: /* grpc_dest_response: KW_INVALID_ARGUMENT  */
#line 1660 "modules/grpc/loki/loki-grammar.y"
                        { (yyval.num) = GDR_INVALID_ARGUMENT; }
#line 4353 "modules/grpc/loki/loki-grammar.c"
    break;

  case 107: /* grpc_dest_response: KW_NOT_FOUND  */
#line 1661 "modules/grpc/loki/loki-grammar.y"
                 { (yyval.num) = GDR_NOT_FOUND; }
#line 4359 "modules/grpc/loki/loki-grammar.c"
    break;

  case 108: /* grpc_dest_response: KW_ALREADY_EXISTS  */
#line 1662 "modules/grpc/loki/loki-grammar.y"
                      { (yyval.num) = GDR_ALREADY_EXISTS; }
#line 4365 "modules/grpc/loki/loki-grammar.c"
    break;

  case 109: /* grpc_dest_response: KW_PERMISSION_DENIED  */
#line 1663 "modules/grpc/loki/loki-grammar.y"
                         { (yyval.num) = GDR_PERMISSION_DENIED; }
#line 4371 "modules/grpc/loki/loki-grammar.c"
    break;

  case 110: /* grpc_dest_response: KW_UNAUTHENTICATED  */
#line 1664 "modules/grpc/loki/loki-grammar.y"
                       { (yyval.num) = GDR_UNAUTHENTICATED; }
#line 4377 "modules/grpc/loki/loki-grammar.c"
    break;

  case 111: /* grpc_dest_response: KW_FAILED_PRECONDITION  */
#line 1665 "modules/grpc/loki/loki-grammar.y"
                           { (yyval.num) = GDR_FAILED_PRECONDITION; }
#line 4383 "modules/grpc/loki/loki-grammar.c"
    break;

  case 112: /* grpc_dest_response: KW_UNIMPLEMENTED  */
#line 1666 "modules/grpc/loki/loki-grammar.y"
                     { (yyval.num) = GDR_UNIMPLEMENTED; }
#line 4389 "modules/grpc/loki/loki-grammar.c"
    break;

  case 113: /* grpc_dest_response: KW_INTERNAL  */
#line 1667 "modules/grpc/loki/loki-grammar.y"
                { (yyval.num) = GDR_INTERNAL; }
#line 4395 "modules/grpc/loki/loki-grammar.c"
    break;

  case 114: /* grpc_dest_response: KW_RESOURCE_EXHAUSTED  */
#line 1668 "modules/grpc/loki/loki-grammar.y"
                          { (yyval.num) = GDR_RESOURCE_EXHAUSTED; }
#line 4401 "modules/grpc/loki/loki-grammar.c"
    break;

  case 115: /* grpc_dest_response_action: KW_DISCONNECT  */
#line 1672 "modules/grpc/loki/loki-grammar.y"
                  { (yyval.num) = GDRA_DISCONNECT; }
#line 4407 "modules/grpc/loki/loki-grammar.c"
    break;

  case 116: /* grpc_dest_response_action: KW_DROP  */
#line 1673 "modules/grpc/loki/loki-grammar.y"
            { (yyval.num) = GDRA_DROP; }
#line 4413 "modules/grpc/loki/loki-grammar.c"
    break;

  case 117: /* grpc_dest_response_action: KW_RETRY  */
#line 1674 "modules/grpc/loki/loki-grammar.y"
             { (yyval.num) = GDRA_RETRY; }
#line 4419 "modules/grpc/loki/loki-grammar.c"
    break;

  case 118: /* grpc_dest_response_action: KW_SUCCESS  */
#line 1675 "modules/grpc/loki/loki-grammar.y"
               { (yyval.num) = GDRA_SUCCESS; }
#line 4425 "modules/grpc/loki/loki-grammar.c"
    break;

  case 119: /* $@24: %empty  */
#line 1719 "modules/grpc/loki/loki-grammar.y"
                { grpc_client_credentials_builder_set_mode(last_grpc_client_credentials_builder, GCAM_INSECURE); }
#line 4431 "modules/grpc/loki/loki-grammar.c"
    break;

  case 121: /* $@25: %empty  */
#line 1720 "modules/grpc/loki/loki-grammar.y"
           { grpc_client_credentials_builder_set_mode(last_grpc_client_credentials_builder, GCAM_TLS); }
#line 4437 "modules/grpc/loki/loki-grammar.c"
    break;

  case 123: /* $@26: %empty  */
#line 1721 "modules/grpc/loki/loki-grammar.y"
            { grpc_client_credentials_builder_set_mode(last_grpc_client_credentials_builder, GCAM_ALTS); }
#line 4443 "modules/grpc/loki/loki-grammar.c"
    break;

  case 125: /* $@27: %empty  */
#line 1722 "modules/grpc/loki/loki-grammar.y"
           { grpc_client_credentials_builder_set_mode(last_grpc_client_credentials_builder, GCAM_ADC); }
#line 4449 "modules/grpc/loki/loki-grammar.c"
    break;

  case 127: /* $@28: %empty  */
#line 1723 "modules/grpc/loki/loki-grammar.y"
                       { grpc_client_credentials_builder_set_mode(last_grpc_client_credentials_builder, GCAM_SERVICE_ACCOUNT); }
#line 4455 "modules/grpc/loki/loki-grammar.c"
    break;

  case 131: /* grpc_client_credentials_builder_tls_option: KW_KEY_FILE '(' string ')'  */
#line 1733 "modules/grpc/loki/loki-grammar.y"
      {
        CHECK_ERROR(grpc_client_credentials_builder_set_tls_key_path(last_grpc_client_credentials_builder, (yyvsp[-1].cptr)), (yylsp[-3]), "Failed to set key-file()");
        free((yyvsp[-1].cptr));
      }
#line 4464 "modules/grpc/loki/loki-grammar.c"
    break;

  case 132: /* grpc_client_credentials_builder_tls_option: KW_CERT_FILE '(' string ')'  */
#line 1738 "modules/grpc/loki/loki-grammar.y"
      {
        CHECK_ERROR(grpc_client_credentials_builder_set_tls_cert_path(last_grpc_client_credentials_builder, (yyvsp[-1].cptr)), (yylsp[-3]), "Failed to set cert-file()");
        free((yyvsp[-1].cptr));
      }
#line 4473 "modules/grpc/loki/loki-grammar.c"
    break;

  case 133: /* grpc_client_credentials_builder_tls_option: KW_CA_FILE '(' string ')'  */
#line 1743 "modules/grpc/loki/loki-grammar.y"
      {
        CHECK_ERROR(grpc_client_credentials_builder_set_tls_ca_path(last_grpc_client_credentials_builder, (yyvsp[-1].cptr)), (yylsp[-3]), "Failed to set ca-file()");
        free((yyvsp[-1].cptr));
      }
#line 4482 "modules/grpc/loki/loki-grammar.c"
    break;

  case 137: /* $@29: %empty  */
#line 1760 "modules/grpc/loki/loki-grammar.y"
      {
        grpc_client_credentials_builder_add_alts_target_service_account(last_grpc_client_credentials_builder, (yyvsp[0].cptr));
        free((yyvsp[0].cptr));
      }
#line 4491 "modules/grpc/loki/loki-grammar.c"
    break;

  case 142: /* grpc_client_credentials_builder_service_account_option: KW_KEY '(' path_secret ')'  */
#line 1774 "modules/grpc/loki/loki-grammar.y"
                               { grpc_client_credentials_builder_service_account_set_key(last_grpc_client_credentials_builder, (yyvsp[-1].cptr)); free((yyvsp[-1].cptr)); }
#line 4497 "modules/grpc/loki/loki-grammar.c"
    break;

  case 143: /* grpc_client_credentials_builder_service_account_option: KW_TOKEN_VALIDITY_DURATION '(' nonnegative_integer64 ')'  */
#line 1775 "modules/grpc/loki/loki-grammar.y"
                                                             { grpc_client_credentials_builder_service_account_set_validity_duration(last_grpc_client_credentials_builder, (yyvsp[-1].num)); }
#line 4503 "modules/grpc/loki/loki-grammar.c"
    break;


#line 4507 "modules/grpc/loki/loki-grammar.c"

      default: break;
    }
  /* User semantic actions sometimes alter yychar, and that requires
     that yytoken be updated with the new translation.  We take the
     approach of translating immediately before every use of yytoken.
     One alternative is translating here after every semantic action,
     but that translation would be missed if the semantic action invokes
     YYABORT, YYACCEPT, or YYERROR immediately after altering yychar or
     if it invokes YYBACKUP.  In the case of YYABORT or YYACCEPT, an
     incorrect destructor might then be invoked immediately.  In the
     case of YYERROR or YYBACKUP, subsequent parser actions might lead
     to an incorrect destructor call or verbose syntax error message
     before the lookahead is translated.  */
  YY_SYMBOL_PRINT ("-> $$ =", YY_CAST (yysymbol_kind_t, yyr1[yyn]), &yyval, &yyloc);

  YYPOPSTACK (yylen);
  yylen = 0;

  *++yyvsp = yyval;
  *++yylsp = yyloc;

  /* Now 'shift' the result of the reduction.  Determine what state
     that goes to, based on the state we popped back to and the rule
     number reduced by.  */
  {
    const int yylhs = yyr1[yyn] - YYNTOKENS;
    const int yyi = yypgoto[yylhs] + *yyssp;
    yystate = (0 <= yyi && yyi <= YYLAST && yycheck[yyi] == *yyssp
               ? yytable[yyi]
               : yydefgoto[yylhs]);
  }

  goto yynewstate;


/*--------------------------------------.
| yyerrlab -- here on detecting error.  |
`--------------------------------------*/
yyerrlab:
  /* Make sure we have latest lookahead translation.  See comments at
     user semantic actions for why this is necessary.  */
  yytoken = yychar == LOKI_EMPTY ? YYSYMBOL_YYEMPTY : YYTRANSLATE (yychar);
  /* If not already recovering from an error, report this error.  */
  if (!yyerrstatus)
    {
      ++yynerrs;
      {
        yypcontext_t yyctx
          = {yyssp, yytoken, &yylloc};
        char const *yymsgp = YY_("syntax error");
        int yysyntax_error_status;
        yysyntax_error_status = yysyntax_error (&yymsg_alloc, &yymsg, &yyctx);
        if (yysyntax_error_status == 0)
          yymsgp = yymsg;
        else if (yysyntax_error_status == -1)
          {
            if (yymsg != yymsgbuf)
              YYSTACK_FREE (yymsg);
            yymsg = YY_CAST (char *,
                             YYSTACK_ALLOC (YY_CAST (YYSIZE_T, yymsg_alloc)));
            if (yymsg)
              {
                yysyntax_error_status
                  = yysyntax_error (&yymsg_alloc, &yymsg, &yyctx);
                yymsgp = yymsg;
              }
            else
              {
                yymsg = yymsgbuf;
                yymsg_alloc = sizeof yymsgbuf;
                yysyntax_error_status = YYENOMEM;
              }
          }
        yyerror (&yylloc, lexer, instance, arg, yymsgp);
        if (yysyntax_error_status == YYENOMEM)
          YYNOMEM;
      }
    }

  yyerror_range[1] = yylloc;
  if (yyerrstatus == 3)
    {
      /* If just tried and failed to reuse lookahead token after an
         error, discard it.  */

      if (yychar <= LOKI_EOF)
        {
          /* Return failure if at end of input.  */
          if (yychar == LOKI_EOF)
            YYABORT;
        }
      else
        {
          yydestruct ("Error: discarding",
                      yytoken, &yylval, &yylloc, lexer, instance, arg);
          yychar = LOKI_EMPTY;
        }
    }

  /* Else will try to reuse lookahead token after shifting the error
     token.  */
  goto yyerrlab1;


/*---------------------------------------------------.
| yyerrorlab -- error raised explicitly by YYERROR.  |
`---------------------------------------------------*/
yyerrorlab:
  /* Pacify compilers when the user code never invokes YYERROR and the
     label yyerrorlab therefore never appears in user code.  */
  if (0)
    YYERROR;
  ++yynerrs;

  /* Do not reclaim the symbols of the rule whose action triggered
     this YYERROR.  */
  YYPOPSTACK (yylen);
  yylen = 0;
  YY_STACK_PRINT (yyss, yyssp);
  yystate = *yyssp;
  goto yyerrlab1;


/*-------------------------------------------------------------.
| yyerrlab1 -- common code for both syntax error and YYERROR.  |
`-------------------------------------------------------------*/
yyerrlab1:
  yyerrstatus = 3;      /* Each real token shifted decrements this.  */

  /* Pop stack until we find a state that shifts the error token.  */
  for (;;)
    {
      yyn = yypact[yystate];
      if (!yypact_value_is_default (yyn))
        {
          yyn += YYSYMBOL_YYerror;
          if (0 <= yyn && yyn <= YYLAST && yycheck[yyn] == YYSYMBOL_YYerror)
            {
              yyn = yytable[yyn];
              if (0 < yyn)
                break;
            }
        }

      /* Pop the current state because it cannot handle the error token.  */
      if (yyssp == yyss)
        YYABORT;

      yyerror_range[1] = *yylsp;
      yydestruct ("Error: popping",
                  YY_ACCESSING_SYMBOL (yystate), yyvsp, yylsp, lexer, instance, arg);
      YYPOPSTACK (1);
      yystate = *yyssp;
      YY_STACK_PRINT (yyss, yyssp);
    }

  YY_IGNORE_MAYBE_UNINITIALIZED_BEGIN
  *++yyvsp = yylval;
  YY_IGNORE_MAYBE_UNINITIALIZED_END

  yyerror_range[2] = yylloc;
  ++yylsp;
  YYLLOC_DEFAULT (*yylsp, yyerror_range, 2);

  /* Shift the error token.  */
  YY_SYMBOL_PRINT ("Shifting", YY_ACCESSING_SYMBOL (yyn), yyvsp, yylsp);

  yystate = yyn;
  goto yynewstate;


/*-------------------------------------.
| yyacceptlab -- YYACCEPT comes here.  |
`-------------------------------------*/
yyacceptlab:
  yyresult = 0;
  goto yyreturnlab;


/*-----------------------------------.
| yyabortlab -- YYABORT comes here.  |
`-----------------------------------*/
yyabortlab:
  yyresult = 1;
  goto yyreturnlab;


/*-----------------------------------------------------------.
| yyexhaustedlab -- YYNOMEM (memory exhaustion) comes here.  |
`-----------------------------------------------------------*/
yyexhaustedlab:
  yyerror (&yylloc, lexer, instance, arg, YY_("memory exhausted"));
  yyresult = 2;
  goto yyreturnlab;


/*----------------------------------------------------------.
| yyreturnlab -- parsing is finished, clean up and return.  |
`----------------------------------------------------------*/
yyreturnlab:
  if (yychar != LOKI_EMPTY)
    {
      /* Make sure we have latest lookahead translation.  See comments at
         user semantic actions for why this is necessary.  */
      yytoken = YYTRANSLATE (yychar);
      yydestruct ("Cleanup: discarding lookahead",
                  yytoken, &yylval, &yylloc, lexer, instance, arg);
    }
  /* Do not reclaim the symbols of the rule whose action triggered
     this YYABORT or YYACCEPT.  */
  YYPOPSTACK (yylen);
  YY_STACK_PRINT (yyss, yyssp);
  while (yyssp != yyss)
    {
      yydestruct ("Cleanup: popping",
                  YY_ACCESSING_SYMBOL (+*yyssp), yyvsp, yylsp, lexer, instance, arg);
      YYPOPSTACK (1);
    }
#ifndef yyoverflow
  if (yyss != yyssa)
    YYSTACK_FREE (yyss);
#endif
  if (yymsg != yymsgbuf)
    YYSTACK_FREE (yymsg);
  return yyresult;
}

#line 1779 "modules/grpc/loki/loki-grammar.y"

